{
"fr/functions/algebra.js": 
[{"locale":"fr"},{"category":"Algebra","mappings":{"default":{"default":"degré"}},"key":"deg","names":["deg"]},{"category":"Algebra","mappings":{"default":{"default":"déterminant"}},"key":"det","names":["det"]},{"category":"Algebra","mappings":{"default":{"default":"dimension"}},"key":"dim","names":["dim"]},{"category":"Algebra","mappings":{"default":{"default":"homomorphisme"}},"key":"hom","names":["hom","Hom"]},{"category":"Algebra","mappings":{"default":{"default":"noyau"}},"key":"ker","names":["ker"]},{"category":"Algebra","mappings":{"default":{"default":"trace"}},"key":"Tr","names":["Tr","tr"]}]
,
"fr/functions/elementary.js": 
[{"locale":"fr"},{"key":"log","mappings":{"default":{"default":"log"}},"category":"Logarithm","names":["log"]},{"key":"ln","mappings":{"default":{"default":"logarithme népérien"}},"category":"Logarithm","names":["ln"]},{"key":"lg","names":["lg"],"mappings":{"default":{"default":"logarithme décimal"}},"category":"Logarithm"},{"key":"exp","names":["exp","expt"],"mappings":{"default":{"default":"exponentielle"}},"category":"Elementary"},{"key":"gcd","names":["gcd","PGCD","pgcd"],"mappings":{"default":{"default":"plus grand commun diviseur"},"mathspeak":{"default":"pgcd"},"clearspeak":{"default":"pgcd"}},"category":"Elementary"},{"key":"lcm","names":["lcm","ppcm","PPCM","PPMC","ppmc"],"mappings":{"default":{"default":"plus petit commun multiple"},"mathspeak":{"default":"ppcm"},"clearspeak":{"default":"ppcm"}},"category":"Elementary"},{"key":"arg","names":["arg"],"mappings":{"default":{"default":"argument"}},"category":"Complex"},{"key":"im","names":["im"],"mappings":{"default":{"default":"partie imaginaire"}},"category":"Complex"},{"key":"re","names":["re"],"mappings":{"default":{"default":"partie réelle"}},"category":"Complex"},{"key":"inf","names":["inf"],"mappings":{"default":{"default":"borne inférieure"}},"category":"Limits"},{"key":"lim","mappings":{"default":{"default":"limite"}},"category":"Limits","names":["lim"]},{"key":"max","names":["max"],"mappings":{"default":{"default":"maximum"}},"category":"Limits"},{"key":"min","names":["min"],"mappings":{"default":{"default":"minimum"}},"category":"Limits"},{"key":"sup","names":["sup"],"mappings":{"default":{"default":"borne supérieure"}},"category":"Limits"},{"key":"lim inf","names":["lim inf","liminf"],"mappings":{"default":{"default":"limite inferior"}},"category":"Limits"},{"key":"lim sup","names":["lim sup","limsup"],"mappings":{"default":{"default":"limite superior"}},"category":"Limits"},{"key":"injlim","names":["injlim","inj lim"],"mappings":{"default":{"default":"limite inductive"}},"category":"Limits"},{"key":"projlim","names":["projlim","proj lim"],"mappings":{"default":{"default":"limite projective"}},"category":"Limits"},{"key":"mod","names":["mod"],"mappings":{"default":{"default":"modulo"}},"category":"Elementary"},{"key":"Pr","names":["Pr"],"mappings":{"default":{"default":"probabilité"}},"category":"Probability"}]
,
"fr/functions/hyperbolic.js": 
[{"locale":"fr"},{"key":"cosh","mappings":{"default":{"default":"cosinus hyperbolique"}},"category":"Hyperbolic","names":["cosh"]},{"key":"coth","mappings":{"default":{"default":"cotangente hyperbolique"}},"category":"Hyperbolic","names":["coth"]},{"key":"csch","mappings":{"default":{"default":"cosécante hyperbolique"}},"category":"Hyperbolic","names":["csch"]},{"key":"sech","mappings":{"default":{"default":"sécante hyperbolique"}},"category":"Hyperbolic","names":["sech"]},{"key":"sinh","mappings":{"default":{"default":"sinus hyperbolique"}},"category":"Hyperbolic","names":["sinh"]},{"key":"tanh","mappings":{"default":{"default":"tangente hyperbolique"}},"category":"Hyperbolic","names":["tanh"]},{"category":"Area","mappings":{"default":{"default":"argument cosinus hyperbolique"}},"key":"arcosh","names":["arcosh","arccosh","argch"]},{"category":"Area","mappings":{"default":{"default":"argument cotangente hyperbolique"}},"key":"arcoth","names":["arcoth","arccoth","argcoth"]},{"category":"Area","mappings":{"default":{"default":"argument cosécante hyperbolique"}},"key":"arcsch","names":["arcsch","arccsch","argcsch"]},{"category":"Area","mappings":{"default":{"default":"argument sécante hyperbolique"}},"key":"arsech","names":["arsech","arcsech","argsech"]},{"category":"Area","mappings":{"default":{"default":"argument sinus hyperbolique"}},"key":"arsinh","names":["arsinh","arcsinh","argsh"]},{"category":"Area","mappings":{"default":{"default":"argument tangente hyperbolique"}},"key":"artanh","names":["artanh","arctanh","argth"]}]
,
"fr/functions/trigonometry.js": 
[{"locale":"fr"},{"key":"cos","mappings":{"default":{"default":"cosinus"}},"category":"Trigonometric","names":["cos","cosine"]},{"key":"cot","mappings":{"default":{"default":"cotangente"}},"category":"Trigonometric","names":["cot"]},{"key":"csc","mappings":{"default":{"default":"cosécante"}},"category":"Trigonometric","names":["csc"]},{"key":"sec","mappings":{"default":{"default":"sécante"}},"category":"Trigonometric","names":["sec"]},{"key":"sin","mappings":{"default":{"default":"sinus"}},"category":"Trigonometric","names":["sin","sine"]},{"key":"tan","mappings":{"default":{"default":"tangente"}},"category":"Trigonometric","names":["tan"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc cosinus"}},"key":"arccos","names":["arccos"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc cotangente"}},"key":"arccot","names":["arccot"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc cosécante"}},"key":"arccsc","names":["arccsc"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc sécante"}},"key":"arcsec","names":["arcsec"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc sinus"}},"key":"arcsin","names":["arcsin"]},{"category":"Cyclometric","mappings":{"default":{"default":"arc tangente"}},"key":"arctan","names":["arctan"]}]
,
"fr/symbols/digits_rest.js": 
[{"locale":"fr"},{"key":"00B2","mappings":{"default":{"default":"au carré"},"mathspeak":{"default":"au carré"},"clearspeak":{"default":"au carré"}},"category":"No"},{"key":"00B3","mappings":{"default":{"default":"cubique"},"mathspeak":{"default":"cubique"},"clearspeak":{"default":"cubique"}},"category":"No"},{"key":"00BC","mappings":{"default":{"default":"un quart"}},"category":"No"},{"key":"00BD","mappings":{"default":{"default":"un demi"}},"category":"No"},{"key":"00BE","mappings":{"default":{"default":"trois quarts"}},"category":"No"},{"key":"2150","mappings":{"default":{"default":"un septième"}},"category":"No"},{"key":"2151","mappings":{"default":{"default":"un neuvième"}},"category":"No"},{"key":"2152","mappings":{"default":{"default":"un dixième"}},"category":"No"},{"key":"2153","mappings":{"default":{"default":"un tiers"}},"category":"No"},{"key":"2154","mappings":{"default":{"default":"deux tiers"}},"category":"No"},{"key":"2155","mappings":{"default":{"default":"un cinquième"}},"category":"No"},{"key":"2156","mappings":{"default":{"default":"deux cinquièmes"}},"category":"No"},{"key":"2157","mappings":{"default":{"default":"trois cinquièmes"}},"category":"No"},{"key":"2158","mappings":{"default":{"default":"quatre cinquièmes"}},"category":"No"},{"key":"2159","mappings":{"default":{"default":"un sixième"}},"category":"No"},{"key":"215A","mappings":{"default":{"default":"cinq sixièmes"}},"category":"No"},{"key":"215B","mappings":{"default":{"default":"un huitième"}},"category":"No"},{"key":"215C","mappings":{"default":{"default":"trois huitièmes"}},"category":"No"},{"key":"215D","mappings":{"default":{"default":"cinq huitièmes"}},"category":"No"},{"key":"215E","mappings":{"default":{"default":"sept huitièmes"}},"category":"No"},{"key":"215F","mappings":{"default":{"default":"numérateur un"}},"category":"No"},{"key":"2189","mappings":{"default":{"default":"zero tiers"}},"category":"No"},{"key":"3248","mappings":{"default":{"default":"dix cerclé sur carré noir"}},"category":"No"},{"key":"3249","mappings":{"default":{"default":"vingt cerclé sur carré noir"}},"category":"No"},{"key":"324A","mappings":{"default":{"default":"trente cerclé sur carré noir"}},"category":"No"},{"key":"324B","mappings":{"default":{"default":"quarante cerclé sur carré noir"}},"category":"No"},{"key":"324C","mappings":{"default":{"default":"cinquante cerclé sur carré noir"}},"category":"No"},{"key":"324D","mappings":{"default":{"default":"soixante cerclé sur carré noir"}},"category":"No"},{"key":"324E","mappings":{"default":{"default":"soixante dix cerclé sur carré noir"}},"category":"No"},{"key":"324F","mappings":{"default":{"default":"quatre vingts cerclé sur carré noir"}},"category":"No"}]
,
"fr/symbols/greek-rest.js": 
[{"locale":"fr"},{"category":"Lu","key":"0394","mappings":{"clearspeak":{"default":"triangle","TriangleSymbol_Delta":"Delta majuscule"}}}]
,
"fr/symbols/greek-scripts.js": 
[{"locale":"fr"},{"category":"Ll","key":"1D26","mappings":{"default":{"default":"petite gamma majuscule"}}},{"category":"Ll","key":"1D27","mappings":{"default":{"default":"petite lambda majuscule"}}},{"category":"Ll","key":"1D28","mappings":{"default":{"default":"petite pi majuscule"}}},{"category":"Ll","key":"1D29","mappings":{"default":{"default":"petite rhô majuscule"}}},{"category":"Ll","key":"1D2A","mappings":{"default":{"default":"petite psi majuscule"}}},{"category":"Lm","key":"1D5E","mappings":{"default":{"default":"gamma suscript"}}},{"category":"Lm","key":"1D60","mappings":{"default":{"default":"phi suscript"}}},{"category":"Lm","key":"1D66","mappings":{"default":{"default":"bêta souscrit"}}},{"category":"Lm","key":"1D67","mappings":{"default":{"default":"gamma souscrit"}}},{"category":"Lm","key":"1D68","mappings":{"default":{"default":"rhô souscrit"}}},{"category":"Lm","key":"1D69","mappings":{"default":{"default":"phi souscrit"}}},{"category":"Lm","key":"1D6A","mappings":{"default":{"default":"khi souscrit"}}}]
,
"fr/symbols/greek-symbols.js": 
[{"locale":"fr"},{"key":"03D0","mappings":{"default":{"default":"bêta grec"}},"category":"Ll"},{"key":"03D7","mappings":{"default":{"default":"ligature kai"}},"category":"Ll"},{"key":"03F6","mappings":{"default":{"default":"epsilon lunaire réfléchi"}},"category":"Sm"},{"category":"Lu","key":"1D7CA","mappings":{"default":{"default":"Digamma en gras"}}},{"category":"Ll","key":"1D7CB","mappings":{"default":{"default":"digamma en gras"}}}]
,
"fr/symbols/hebrew_letters.js": 
[{"locale":"fr"},{"key":"2135","mappings":{"default":{"default":"alef"}},"category":"Lo"},{"key":"2136","mappings":{"default":{"default":"bèt"}},"category":"Lo"},{"key":"2137","mappings":{"default":{"default":"guimel"}},"category":"Lo"},{"key":"2138","mappings":{"default":{"default":"dalèt"}},"category":"Lo"}]
,
"fr/symbols/latin-lower-double-accent.js": 
[{"locale":"fr"},{"category":"Ll","key":"01D6","mappings":{"default":{"default":"u trémaa et macron"}}},{"category":"Ll","key":"01D8","mappings":{"default":{"default":"u trémaa et accent aigu"}}},{"category":"Ll","key":"01DA","mappings":{"default":{"default":"u trémaa et caron"}}},{"category":"Ll","key":"01DC","mappings":{"default":{"default":"u trémaa et accent grave"}}},{"category":"Ll","key":"01DF","mappings":{"default":{"default":"a trémaa et macron"}}},{"category":"Ll","key":"01E1","mappings":{"default":{"default":"a point en chef et macron"}}},{"category":"Ll","key":"01ED","mappings":{"default":{"default":"o ogonek et macron"}}},{"category":"Ll","key":"01FB","mappings":{"default":{"default":"a rond en chef et accent aigu"}}},{"category":"Ll","key":"022B","mappings":{"default":{"default":"o tréma et macron"}}},{"category":"Ll","key":"022D","mappings":{"default":{"default":"o tilde et macron"}}},{"category":"Ll","key":"0231","mappings":{"default":{"default":"o point en chef et macron"}}},{"key":"1E09","mappings":{"default":{"default":"c cédille et accent aigu"}},"category":"Ll"},{"key":"1E15","mappings":{"default":{"default":"e macron et accent grave"}},"category":"Ll"},{"key":"1E17","mappings":{"default":{"default":"e macron et accent aigu"}},"category":"Ll"},{"key":"1E1D","mappings":{"default":{"default":"e cédille et brève"}},"category":"Ll"},{"key":"1E2F","mappings":{"default":{"default":"i tréma et accent aigu"}},"category":"Ll"},{"key":"1E39","mappings":{"default":{"default":"l point souscrit et macron"}},"category":"Ll"},{"key":"1E4D","mappings":{"default":{"default":"o tilde et accent aigu"}},"category":"Ll"},{"key":"1E4F","mappings":{"default":{"default":"o tilde et tréma"}},"category":"Ll"},{"key":"1E51","mappings":{"default":{"default":"o macron et accent grave"}},"category":"Ll"},{"key":"1E53","mappings":{"default":{"default":"o macron et accent aigu"}},"category":"Ll"},{"key":"1E5D","mappings":{"default":{"default":"r point souscrit et macron"}},"category":"Ll"},{"key":"1E65","mappings":{"default":{"default":"s accent aigu et point en chef"}},"category":"Ll"},{"key":"1E67","mappings":{"default":{"default":"s caron et point en chef"}},"category":"Ll"},{"key":"1E69","mappings":{"default":{"default":"s point souscrit et point en chef"}},"category":"Ll"},{"key":"1E79","mappings":{"default":{"default":"u tilde et accent aigu"}},"category":"Ll"},{"key":"1E7B","mappings":{"default":{"default":"u macron et tréma"}},"category":"Ll"},{"key":"1EA5","mappings":{"default":{"default":"a accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1EA7","mappings":{"default":{"default":"a accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1EA9","mappings":{"default":{"default":"a accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1EAB","mappings":{"default":{"default":"a accent circonflexe et tilde"}},"category":"Ll"},{"key":"1EAD","mappings":{"default":{"default":"a accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1EAF","mappings":{"default":{"default":"a brève et accent aigu"}},"category":"Ll"},{"key":"1EB1","mappings":{"default":{"default":"a brève et accent grave"}},"category":"Ll"},{"key":"1EB3","mappings":{"default":{"default":"a brève et crochet en chef"}},"category":"Ll"},{"key":"1EB5","mappings":{"default":{"default":"a brève et tilde"}},"category":"Ll"},{"key":"1EB7","mappings":{"default":{"default":"a brève et point souscrit"}},"category":"Ll"},{"key":"1EBF","mappings":{"default":{"default":"e accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1EC1","mappings":{"default":{"default":"e accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1EC3","mappings":{"default":{"default":"e accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1EC5","mappings":{"default":{"default":"e accent circonflexe et tilde"}},"category":"Ll"},{"key":"1EC7","mappings":{"default":{"default":"e accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1ED1","mappings":{"default":{"default":"o accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1ED3","mappings":{"default":{"default":"o accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1ED5","mappings":{"default":{"default":"o accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1ED7","mappings":{"default":{"default":"o accent circonflexe et tilde"}},"category":"Ll"},{"key":"1ED9","mappings":{"default":{"default":"o accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1EDB","mappings":{"default":{"default":"o cornu accent aigu"}},"category":"Ll"},{"key":"1EDD","mappings":{"default":{"default":"o cornu accent grave"}},"category":"Ll"},{"key":"1EDF","mappings":{"default":{"default":"o cornu crochet en chef"}},"category":"Ll"},{"key":"1EE1","mappings":{"default":{"default":"o cornu tilde"}},"category":"Ll"},{"key":"1EE3","mappings":{"default":{"default":"o cornu point souscrit"}},"category":"Ll"},{"key":"1EE9","mappings":{"default":{"default":"u cornu accent aigu"}},"category":"Ll"},{"key":"1EEB","mappings":{"default":{"default":"u cornu accent grave"}},"category":"Ll"},{"key":"1EED","mappings":{"default":{"default":"u cornu crochet en chef"}},"category":"Ll"},{"key":"1EEF","mappings":{"default":{"default":"u cornu tilde"}},"category":"Ll"},{"key":"1EF1","mappings":{"default":{"default":"u cornu point souscrit"}},"category":"Ll"}]
,
"fr/symbols/latin-lower-phonetic.js": 
[{"locale":"fr"},{"key":"00F8","mappings":{"default":{"default":"o barré"}},"category":"Ll"},{"key":"0111","mappings":{"default":{"default":"d barré"}},"category":"Ll"},{"key":"0127","mappings":{"default":{"default":"h barré"}},"category":"Ll"},{"key":"0142","mappings":{"default":{"default":"l barré"}},"category":"Ll"},{"key":"0167","mappings":{"default":{"default":"t barré"}},"category":"Ll"},{"category":"Ll","key":"0180","mappings":{"default":{"default":"b barré"}}},{"key":"019B","mappings":{"default":{"default":"lambda barré"}},"category":"Ll"},{"category":"Ll","key":"01B6","mappings":{"default":{"default":"z barré"}}},{"category":"Ll","key":"01BE","mappings":{"default":{"default":"coup de glotte barré culbuté"}}},{"category":"Ll","key":"01E5","mappings":{"default":{"default":"g barré"}}},{"category":"Ll","key":"01FF","mappings":{"default":{"default":"o barré accent aigu"}}},{"category":"Ll","key":"023C","mappings":{"default":{"default":"c barré"}}},{"category":"Ll","key":"0247","mappings":{"default":{"default":"e barré"}}},{"category":"Ll","key":"0249","mappings":{"default":{"default":"j barré"}}},{"category":"Ll","key":"024D","mappings":{"default":{"default":"r barré"}}},{"category":"Ll","key":"024F","mappings":{"default":{"default":"y barré"}}},{"category":"Ll","key":"025F","mappings":{"default":{"default":"j sans point barré"}}},{"category":"Ll","key":"0268","mappings":{"default":{"default":"i barré"}}},{"category":"Ll","key":"0284","mappings":{"default":{"default":"j sans point barré crosse"}}},{"category":"Ll","key":"02A1","mappings":{"default":{"default":"coup de glotte barré"}}},{"category":"Ll","key":"02A2","mappings":{"default":{"default":"coup de glotte barré réfléchi"}}},{"category":"Ll","key":"1D13","mappings":{"default":{"default":"o couché barré obliquement"}}},{"category":"Ll","key":"1D7C","mappings":{"default":{"default":"iota barré"}}},{"category":"Ll","key":"1D7D","mappings":{"default":{"default":"p barré"}}},{"category":"Ll","key":"1D7F","mappings":{"default":{"default":"upsilon barré"}}},{"category":"Ll","key":"1E9C","mappings":{"default":{"default":"s long à barre diagonale"}}},{"category":"Ll","key":"1E9D","mappings":{"default":{"default":"s long à barre haute"}}},{"category":"Ll","key":"018D","mappings":{"default":{"default":"delta culbutée"}}},{"key":"1E9B","mappings":{"default":{"default":"s long point en chef"}},"category":"Ll"},{"category":"Ll","key":"1E9F","mappings":{"default":{"default":"delta"}}},{"key":"0138","mappings":{"default":{"default":"kra"}},"category":"Ll"},{"category":"Ll","key":"017F","mappings":{"default":{"default":"s long"}}},{"category":"Ll","key":"0183","mappings":{"default":{"default":"b potence"}}},{"category":"Ll","key":"0185","mappings":{"default":{"default":"sixiéme ton"}}},{"category":"Ll","key":"0188","mappings":{"default":{"default":"c crosse"}}},{"category":"Ll","key":"018C","mappings":{"default":{"default":"d potence"}}},{"key":"0192","mappings":{"default":{"default":"f cursif"}},"category":"Ll"},{"category":"Ll","key":"0195","mappings":{"default":{"default":"hv (Hwair)"}}},{"category":"Ll","key":"0199","mappings":{"default":{"default":"k crosse"}}},{"key":"019A","mappings":{"default":{"default":"l rayé"}},"category":"Ll"},{"category":"Ll","key":"019E","mappings":{"default":{"default":"n à long jambage de droite"}}},{"category":"Ll","key":"01A1","mappings":{"default":{"default":"o cornu"}}},{"category":"Ll","key":"01A3","mappings":{"default":{"default":"gha"}}},{"category":"Ll","key":"01A5","mappings":{"default":{"default":"p crosse"}}},{"category":"Ll","key":"01A8","mappings":{"default":{"default":"deuxiéme ton"}}},{"category":"Ll","key":"01AA","mappings":{"default":{"default":"ech réfléchi bouclé"}}},{"category":"Ll","key":"01AB","mappings":{"default":{"default":"t hameçon palatal"}}},{"category":"Ll","key":"01AD","mappings":{"default":{"default":"t crosse"}}},{"category":"Ll","key":"01B0","mappings":{"default":{"default":"u cornu"}}},{"category":"Ll","key":"01B4","mappings":{"default":{"default":"y crosse"}}},{"category":"Ll","key":"01B9","mappings":{"default":{"default":"ej réfléchi"}}},{"category":"Ll","key":"01BA","mappings":{"default":{"default":"ej hameçon"}}},{"category":"Ll","key":"01BD","mappings":{"default":{"default":"cinquiéme tun"}}},{"category":"Ll","key":"01BF","mappings":{"default":{"default":"wynn"}}},{"category":"Ll","key":"01C6","mappings":{"default":{"default":"dz caron"}}},{"category":"Ll","key":"01C9","mappings":{"default":{"default":"lj"}}},{"category":"Ll","key":"01CC","mappings":{"default":{"default":"nj"}}},{"category":"Ll","key":"01E3","mappings":{"default":{"default":"ae macron"}}},{"category":"Ll","key":"01EF","mappings":{"default":{"default":"ej caron"}}},{"category":"Ll","key":"01F3","mappings":{"default":{"default":"dz"}}},{"category":"Ll","key":"021D","mappings":{"default":{"default":"yogh"}}},{"category":"Ll","key":"026E","mappings":{"default":{"default":"lej"}}},{"category":"Ll","key":"0292","mappings":{"default":{"default":"ej"}}},{"category":"Ll","key":"0293","mappings":{"default":{"default":"ej bouclé"}}},{"category":"Ll","key":"02A4","mappings":{"default":{"default":"digramme Dej"}}},{"category":"Ll","key":"01DD","mappings":{"default":{"default":"e culbuté"}}},{"category":"Ll","key":"01FD","mappings":{"default":{"default":"ae accent aigu (ash)"}}},{"category":"Ll","key":"0221","mappings":{"default":{"default":"d bouclé"}}},{"category":"Ll","key":"0223","mappings":{"default":{"default":"ou"}}},{"category":"Ll","key":"0225","mappings":{"default":{"default":"z crochet"}}},{"category":"Ll","key":"0234","mappings":{"default":{"default":"l bouclé"}}},{"category":"Ll","key":"0235","mappings":{"default":{"default":"n bouclé"}}},{"category":"Ll","key":"0236","mappings":{"default":{"default":"t bouclé"}}},{"category":"Ll","key":"0238","mappings":{"default":{"default":"Ligature minuscule latine Db"}}},{"category":"Ll","key":"0239","mappings":{"default":{"default":"Ligature minuscule latine Qp"}}},{"category":"Ll","key":"023F","mappings":{"default":{"default":"s à paraphe"}}},{"category":"Ll","key":"0240","mappings":{"default":{"default":"z à paraphe"}}},{"category":"Ll","key":"0242","mappings":{"default":{"default":"coup de glotte"}}},{"category":"Ll","key":"024B","mappings":{"default":{"default":"q avec hameçon"}}},{"category":"Ll","key":"0250","mappings":{"default":{"default":"a culbuté"}}},{"category":"Ll","key":"0251","mappings":{"default":{"default":"alpha"}}},{"category":"Ll","key":"0252","mappings":{"default":{"default":"alpha culbuté"}}},{"category":"Ll","key":"0253","mappings":{"default":{"default":"b crosse"}}},{"category":"Ll","key":"0254","mappings":{"default":{"default":"o ouvert"}}},{"category":"Ll","key":"0255","mappings":{"default":{"default":"c bouclé"}}},{"category":"Ll","key":"0256","mappings":{"default":{"default":"d hameçon rétroflexe"}}},{"category":"Ll","key":"0257","mappings":{"default":{"default":"d crosse"}}},{"category":"Ll","key":"0258","mappings":{"default":{"default":"e réfléchi"}}},{"category":"Ll","key":"0259","mappings":{"default":{"default":"schwa"}}},{"category":"Ll","key":"025A","mappings":{"default":{"default":"schwa crochet"}}},{"key":"025B","mappings":{"default":{"default":"e ouvert"}},"category":"Ll"},{"category":"Ll","key":"025C","mappings":{"default":{"default":"epsilon réfléchi"}}},{"category":"Ll","key":"025D","mappings":{"default":{"default":"epsilon réfléchi crochet"}}},{"category":"Ll","key":"025E","mappings":{"default":{"default":"epsilon réfléchi fermé"}}},{"category":"Ll","key":"0260","mappings":{"default":{"default":"g crosse"}}},{"category":"Ll","key":"0261","mappings":{"default":{"default":"g cursif"}}},{"category":"Ll","key":"0263","mappings":{"default":{"default":"gamma"}}},{"category":"Ll","key":"0264","mappings":{"default":{"default":"petit gamma"}}},{"category":"Ll","key":"0265","mappings":{"default":{"default":"h culbuté"}}},{"category":"Ll","key":"0266","mappings":{"default":{"default":"h crosse"}}},{"category":"Ll","key":"0267","mappings":{"default":{"default":"eng crosse"}}},{"category":"Ll","key":"0269","mappings":{"default":{"default":"iota"}}},{"category":"Ll","key":"026B","mappings":{"default":{"default":"l tilde médian"}}},{"category":"Ll","key":"026C","mappings":{"default":{"default":"l sanglé"}}},{"category":"Ll","key":"026D","mappings":{"default":{"default":"l hameçon rétroflexe"}}},{"category":"Ll","key":"026F","mappings":{"default":{"default":"m culbuté"}}},{"category":"Ll","key":"0270","mappings":{"default":{"default":"m hampé culbuté"}}},{"category":"Ll","key":"0271","mappings":{"default":{"default":"m hameçon"}}},{"category":"Ll","key":"0272","mappings":{"default":{"default":"n hameçon à gauche"}}},{"category":"Ll","key":"0273","mappings":{"default":{"default":"n hameçon rétroflexe"}}},{"category":"Ll","key":"0275","mappings":{"default":{"default":"o barré"}}},{"category":"Ll","key":"0277","mappings":{"default":{"default":"oméga fermé"}}},{"category":"Ll","key":"0278","mappings":{"default":{"default":"phi"}}},{"category":"Ll","key":"0279","mappings":{"default":{"default":"r culbuté"}}},{"category":"Ll","key":"027A","mappings":{"default":{"default":"r prolongé culbuté"}}},{"category":"Ll","key":"027B","mappings":{"default":{"default":"r crosse culbuté"}}},{"category":"Ll","key":"027C","mappings":{"default":{"default":"r prolongé"}}},{"category":"Ll","key":"027D","mappings":{"default":{"default":"r hameçon rétroflexe"}}},{"category":"Ll","key":"027E","mappings":{"default":{"default":"r sans obit"}}},{"category":"Ll","key":"027F","mappings":{"default":{"default":"r sans obit réfléchi"}}},{"category":"Ll","key":"0282","mappings":{"default":{"default":"s hameçon rétroflexe"}}},{"category":"Ll","key":"0283","mappings":{"default":{"default":"ech"}}},{"category":"Ll","key":"0285","mappings":{"default":{"default":"r sans obit réfléchi hameçon rétroflexe"}}},{"category":"Ll","key":"0286","mappings":{"default":{"default":"ech bouclé"}}},{"category":"Ll","key":"0287","mappings":{"default":{"default":"t culbuté"}}},{"category":"Ll","key":"0288","mappings":{"default":{"default":"t hameçon rétroflexe"}}},{"category":"Ll","key":"0289","mappings":{"default":{"default":"u barré"}}},{"category":"Ll","key":"028A","mappings":{"default":{"default":"upsilon"}}},{"category":"Ll","key":"028B","mappings":{"default":{"default":"v de ronde"}}},{"category":"Ll","key":"028C","mappings":{"default":{"default":"v culbuté"}}},{"category":"Ll","key":"028D","mappings":{"default":{"default":"w culbuté"}}},{"category":"Ll","key":"028E","mappings":{"default":{"default":"y culbuté"}}},{"category":"Ll","key":"0290","mappings":{"default":{"default":"z hameçon rétroflexe"}}},{"category":"Ll","key":"0291","mappings":{"default":{"default":"z bouclé"}}},{"category":"Ll","key":"0295","mappings":{"default":{"default":"coup de glotte réfléchi"}}},{"category":"Ll","key":"0296","mappings":{"default":{"default":"coup de glotte culbuté"}}},{"category":"Ll","key":"0297","mappings":{"default":{"default":"C étiré"}}},{"category":"Ll","key":"0298","mappings":{"default":{"default":"clic bilabial"}}},{"category":"Ll","key":"029A","mappings":{"default":{"default":"epsilon fermé"}}},{"category":"Ll","key":"029E","mappings":{"default":{"default":"k culbuté"}}},{"category":"Ll","key":"02A0","mappings":{"default":{"default":"q crosse"}}},{"category":"Ll","key":"02A3","mappings":{"default":{"default":"digramme Dz"}}},{"category":"Ll","key":"02A5","mappings":{"default":{"default":"digramme Dz bouclé"}}},{"category":"Ll","key":"02A6","mappings":{"default":{"default":"digramme Ts"}}},{"category":"Ll","key":"02A7","mappings":{"default":{"default":"digramme Tech"}}},{"category":"Ll","key":"02A8","mappings":{"default":{"default":"digramme Tc bouclé"}}},{"category":"Ll","key":"02A9","mappings":{"default":{"default":"digramme Feng"}}},{"category":"Ll","key":"02AA","mappings":{"default":{"default":"digramme Ls"}}},{"category":"Ll","key":"02AB","mappings":{"default":{"default":"digramme Lz"}}},{"category":"Ll","key":"02AC","mappings":{"default":{"default":"percussion bilabiale"}}},{"category":"Ll","key":"02AD","mappings":{"default":{"default":"percussion bidentale"}}},{"category":"Ll","key":"02AE","mappings":{"default":{"default":"h culbuté crosse réfléchie"}}},{"category":"Ll","key":"02AF","mappings":{"default":{"default":"h culbuté crosse réfléchie et hameçon rétroflexe"}}},{"category":"Ll","key":"1D02","mappings":{"default":{"default":"ae culbuté"}}},{"category":"Ll","key":"1D08","mappings":{"default":{"default":"epsilon culbuté"}}},{"category":"Ll","key":"1D09","mappings":{"default":{"default":"i culbuté"}}},{"category":"Ll","key":"1D11","mappings":{"default":{"default":"o couché"}}},{"category":"Ll","key":"1D12","mappings":{"default":{"default":"o ouvert couché"}}},{"category":"Ll","key":"1D14","mappings":{"default":{"default":"oe culbuté"}}},{"category":"Ll","key":"1D16","mappings":{"default":{"default":"moitié supérieure de o"}}},{"category":"Ll","key":"1D17","mappings":{"default":{"default":"moitié inférieure de o"}}},{"category":"Ll","key":"1D1D","mappings":{"default":{"default":"u couché"}}},{"category":"Ll","key":"1D1E","mappings":{"default":{"default":"u tréma couché"}}},{"category":"Ll","key":"1D1F","mappings":{"default":{"default":"m couché"}}},{"category":"Ll","key":"1D24","mappings":{"default":{"default":"fricative pharyngale voisée"}}},{"category":"Ll","key":"1D25","mappings":{"default":{"default":"aïn"}}},{"category":"Ll","key":"1D6B","mappings":{"default":{"default":"ue"}}},{"category":"Ll","key":"1D6C","mappings":{"default":{"default":"b tilde médian"}}},{"category":"Ll","key":"1D6D","mappings":{"default":{"default":"d tilde médian"}}},{"category":"Ll","key":"1D6E","mappings":{"default":{"default":"f tilde médian"}}},{"category":"Ll","key":"1D6F","mappings":{"default":{"default":"m tilde médian"}}},{"category":"Ll","key":"1D70","mappings":{"default":{"default":"n tilde médian"}}},{"category":"Ll","key":"1D71","mappings":{"default":{"default":"p tilde médian"}}},{"category":"Ll","key":"1D72","mappings":{"default":{"default":"r tilde médian"}}},{"category":"Ll","key":"1D73","mappings":{"default":{"default":"r sans obit tilde médian"}}},{"category":"Ll","key":"1D74","mappings":{"default":{"default":"s tilde médian"}}},{"category":"Ll","key":"1D75","mappings":{"default":{"default":"t tilde médian"}}},{"category":"Ll","key":"1D76","mappings":{"default":{"default":"z tilde médian"}}},{"category":"Ll","key":"1D77","mappings":{"default":{"default":"g culbuté"}}},{"category":"Ll","key":"1D79","mappings":{"default":{"default":"g insulaire"}}},{"category":"Ll","key":"1D7A","mappings":{"default":{"default":"th barré diagonalement"}}},{"category":"Ll","key":"1D80","mappings":{"default":{"default":"b hameçon palatal"}}},{"category":"Ll","key":"1D81","mappings":{"default":{"default":"d hameçon palatal"}}},{"category":"Ll","key":"1D82","mappings":{"default":{"default":"f hameçon palatal"}}},{"category":"Ll","key":"1D83","mappings":{"default":{"default":"g hameçon palatal"}}},{"category":"Ll","key":"1D84","mappings":{"default":{"default":"k hameçon palatal"}}},{"category":"Ll","key":"1D85","mappings":{"default":{"default":"l hameçon palatal"}}},{"category":"Ll","key":"1D86","mappings":{"default":{"default":"m hameçon palatal"}}},{"category":"Ll","key":"1D87","mappings":{"default":{"default":"n hameçon palatal"}}},{"category":"Ll","key":"1D88","mappings":{"default":{"default":"p hameçon palatal"}}},{"category":"Ll","key":"1D89","mappings":{"default":{"default":"r hameçon palatal"}}},{"category":"Ll","key":"1D8A","mappings":{"default":{"default":"s hameçon palatal"}}},{"category":"Ll","key":"1D8B","mappings":{"default":{"default":"ech hameçon palatal"}}},{"category":"Ll","key":"1D8C","mappings":{"default":{"default":"v hameçon palatal"}}},{"category":"Ll","key":"1D8D","mappings":{"default":{"default":"x hameçon palatal"}}},{"category":"Ll","key":"1D8E","mappings":{"default":{"default":"z hameçon palatal"}}},{"category":"Ll","key":"1D8F","mappings":{"default":{"default":"a hameçon rétroflexe"}}},{"category":"Ll","key":"1D90","mappings":{"default":{"default":"alpha hameçon rétroflexe"}}},{"category":"Ll","key":"1D91","mappings":{"default":{"default":"d crosse et hameçon rétroflexe"}}},{"category":"Ll","key":"1D92","mappings":{"default":{"default":"e hameçon rétroflexe"}}},{"category":"Ll","key":"1D93","mappings":{"default":{"default":"epsilon hameçon rétroflexe"}}},{"category":"Ll","key":"1D94","mappings":{"default":{"default":"epsilon réfléchi hameçon rétroflexe"}}},{"category":"Ll","key":"1D95","mappings":{"default":{"default":"schwa hameçon rétroflexe"}}},{"category":"Ll","key":"1D96","mappings":{"default":{"default":"i hameçon rétroflexe"}}},{"category":"Ll","key":"1D97","mappings":{"default":{"default":"o ouvert hameçon rétroflexe"}}},{"category":"Ll","key":"1D98","mappings":{"default":{"default":"ech hameçon rétroflexe"}}},{"category":"Ll","key":"1D99","mappings":{"default":{"default":"u hameçon rétroflexe"}}},{"category":"Ll","key":"1D9A","mappings":{"default":{"default":"ej hameçon rétroflexe"}}},{"key":"0149","mappings":{"default":{"default":"n précédée d'une apostrophe"}},"category":"Ll"},{"key":"014B","mappings":{"default":{"default":"eng"}},"category":"Ll"}]
,
"fr/symbols/latin-lower-single-accent.js": 
[{"locale":"fr"},{"key":"00E0","mappings":{"default":{"default":"a accent grave"}},"category":"Ll"},{"key":"00E1","mappings":{"default":{"default":"a accent aigu"}},"category":"Ll"},{"key":"00E2","mappings":{"default":{"default":"a accent circonflexe"}},"category":"Ll"},{"key":"00E3","mappings":{"default":{"default":"a tilde"}},"category":"Ll"},{"key":"00E4","mappings":{"default":{"default":"a tréma"}},"category":"Ll"},{"key":"00E5","mappings":{"default":{"default":"a rond en chef"}},"category":"Ll"},{"key":"00E7","mappings":{"default":{"default":"c cédille"}},"category":"Ll"},{"key":"00E8","mappings":{"default":{"default":"e accent grave"}},"category":"Ll"},{"key":"00E9","mappings":{"default":{"default":"e accent aigu"}},"category":"Ll"},{"key":"00EA","mappings":{"default":{"default":"e accent circonflexe"}},"category":"Ll"},{"key":"00EB","mappings":{"default":{"default":"e tréma"}},"category":"Ll"},{"key":"00EC","mappings":{"default":{"default":"i accent grave"}},"category":"Ll"},{"key":"00ED","mappings":{"default":{"default":"i accent aigu"}},"category":"Ll"},{"key":"00EE","mappings":{"default":{"default":"i accent circonflexe"}},"category":"Ll"},{"key":"00EF","mappings":{"default":{"default":"i tréma"}},"category":"Ll"},{"key":"00F1","mappings":{"default":{"default":"n tilde"}},"category":"Ll"},{"key":"00F2","mappings":{"default":{"default":"o accent grave"}},"category":"Ll"},{"key":"00F3","mappings":{"default":{"default":"o accent aigu"}},"category":"Ll"},{"key":"00F4","mappings":{"default":{"default":"o accent circonflexe"}},"category":"Ll"},{"key":"00F5","mappings":{"default":{"default":"o tilde"}},"category":"Ll"},{"key":"00F6","mappings":{"default":{"default":"o tréma"}},"category":"Ll"},{"key":"00F9","mappings":{"default":{"default":"u accent grave"}},"category":"Ll"},{"key":"00FA","mappings":{"default":{"default":"u accent aigu"}},"category":"Ll"},{"key":"00FB","mappings":{"default":{"default":"u accent circonflexe"}},"category":"Ll"},{"key":"00FC","mappings":{"default":{"default":"u tréma"}},"category":"Ll"},{"key":"00FD","mappings":{"default":{"default":"y accent aigu"}},"category":"Ll"},{"key":"00FF","mappings":{"default":{"default":"y tréma"}},"category":"Ll"},{"key":"0101","mappings":{"default":{"default":"a macron"}},"category":"Ll"},{"key":"0103","mappings":{"default":{"default":"a brève"}},"category":"Ll"},{"key":"0105","mappings":{"default":{"default":"a ogonek"}},"category":"Ll"},{"key":"0107","mappings":{"default":{"default":"c accent aigu"}},"category":"Ll"},{"key":"0109","mappings":{"default":{"default":"c accent circonflexe"}},"category":"Ll"},{"key":"010B","mappings":{"default":{"default":"c point en chef"}},"category":"Ll"},{"key":"010D","mappings":{"default":{"default":"c caron"}},"category":"Ll"},{"key":"010F","mappings":{"default":{"default":"d caron"}},"category":"Ll"},{"key":"0113","mappings":{"default":{"default":"e macron"}},"category":"Ll"},{"category":"Ll","key":"0115","mappings":{"default":{"default":"e brève"}}},{"key":"0117","mappings":{"default":{"default":"e point en chef"}},"category":"Ll"},{"key":"0119","mappings":{"default":{"default":"e ogonek"}},"category":"Ll"},{"key":"011B","mappings":{"default":{"default":"e caron"}},"category":"Ll"},{"key":"011D","mappings":{"default":{"default":"g accent circonflexe"}},"category":"Ll"},{"key":"011F","mappings":{"default":{"default":"g brève"}},"category":"Ll"},{"key":"0121","mappings":{"default":{"default":"g point en chef"}},"category":"Ll"},{"category":"Ll","key":"0123","mappings":{"default":{"default":"g cédille"}}},{"key":"0125","mappings":{"default":{"default":"h accent circonflexe"}},"category":"Ll"},{"key":"0129","mappings":{"default":{"default":"i tilde"}},"category":"Ll"},{"key":"012B","mappings":{"default":{"default":"i macron"}},"category":"Ll"},{"category":"Ll","key":"012D","mappings":{"default":{"default":"i brève"}}},{"key":"012F","mappings":{"default":{"default":"i ogonek"}},"category":"Ll"},{"key":"0131","mappings":{"default":{"default":"i sans point"}},"category":"Ll"},{"key":"0135","mappings":{"default":{"default":"j accent circonflexe"}},"category":"Ll"},{"key":"0137","mappings":{"default":{"default":"k cédille"}},"category":"Ll"},{"key":"013A","mappings":{"default":{"default":"l accent aigu"}},"category":"Ll"},{"key":"013C","mappings":{"default":{"default":"l cédille"}},"category":"Ll"},{"key":"013E","mappings":{"default":{"default":"l caron"}},"category":"Ll"},{"key":"0140","mappings":{"default":{"default":"l point médian"}},"category":"Ll"},{"key":"0144","mappings":{"default":{"default":"n accent aigu"}},"category":"Ll"},{"key":"0146","mappings":{"default":{"default":"n cédille"}},"category":"Ll"},{"key":"0148","mappings":{"default":{"default":"n caron"}},"category":"Ll"},{"key":"014D","mappings":{"default":{"default":"o macron"}},"category":"Ll"},{"category":"Ll","key":"014F","mappings":{"default":{"default":"o brève"}}},{"key":"0151","mappings":{"default":{"default":"o avec double accent aigu"}},"category":"Ll"},{"key":"0155","mappings":{"default":{"default":"r accent aigu"}},"category":"Ll"},{"key":"0157","mappings":{"default":{"default":"r cédille"}},"category":"Ll"},{"key":"0159","mappings":{"default":{"default":"r caron"}},"category":"Ll"},{"key":"015B","mappings":{"default":{"default":"s accent aigu"}},"category":"Ll"},{"key":"015D","mappings":{"default":{"default":"s accent circonflexe"}},"category":"Ll"},{"key":"015F","mappings":{"default":{"default":"s cédille"}},"category":"Ll"},{"key":"0161","mappings":{"default":{"default":"s caron"}},"category":"Ll"},{"key":"0163","mappings":{"default":{"default":"t cédille"}},"category":"Ll"},{"key":"0165","mappings":{"default":{"default":"t caron"}},"category":"Ll"},{"key":"0169","mappings":{"default":{"default":"u tilde"}},"category":"Ll"},{"key":"016B","mappings":{"default":{"default":"u macron"}},"category":"Ll"},{"key":"016D","mappings":{"default":{"default":"u brève"}},"category":"Ll"},{"key":"016F","mappings":{"default":{"default":"u rond en chef"}},"category":"Ll"},{"key":"0171","mappings":{"default":{"default":"u avec double accent aigu"}},"category":"Ll"},{"key":"0173","mappings":{"default":{"default":"u ogonek"}},"category":"Ll"},{"key":"0175","mappings":{"default":{"default":"w accent circonflexe"}},"category":"Ll"},{"key":"0177","mappings":{"default":{"default":"y accent circonflexe"}},"category":"Ll"},{"key":"017A","mappings":{"default":{"default":"z accent aigu"}},"category":"Ll"},{"key":"017C","mappings":{"default":{"default":"z point en chef"}},"category":"Ll"},{"key":"017E","mappings":{"default":{"default":"z caron"}},"category":"Ll"},{"category":"Ll","key":"01CE","mappings":{"default":{"default":"a caron"}}},{"category":"Ll","key":"01D0","mappings":{"default":{"default":"i caron"}}},{"category":"Ll","key":"01D2","mappings":{"default":{"default":"o caron"}}},{"category":"Ll","key":"01D4","mappings":{"default":{"default":"u caron"}}},{"category":"Ll","key":"01E7","mappings":{"default":{"default":"g caron"}}},{"category":"Ll","key":"01E9","mappings":{"default":{"default":"k caron"}}},{"category":"Ll","key":"01EB","mappings":{"default":{"default":"o ogonek"}}},{"category":"Ll","key":"01F0","mappings":{"default":{"default":"j caron"}}},{"key":"01F5","mappings":{"default":{"default":"g accent aigu"}},"category":"Ll"},{"category":"Ll","key":"01F9","mappings":{"default":{"default":"n grave"}}},{"category":"Ll","key":"0201","mappings":{"default":{"default":"a double accent grave"}}},{"category":"Ll","key":"0203","mappings":{"default":{"default":"a brève renversée"}}},{"category":"Ll","key":"0205","mappings":{"default":{"default":"e double accent grave"}}},{"category":"Ll","key":"0207","mappings":{"default":{"default":"e brève renversée"}}},{"category":"Ll","key":"0209","mappings":{"default":{"default":"i double accent grave"}}},{"category":"Ll","key":"020B","mappings":{"default":{"default":"i brève renversée"}}},{"category":"Ll","key":"020D","mappings":{"default":{"default":"o double accent grave"}}},{"category":"Ll","key":"020F","mappings":{"default":{"default":"o brève renversée"}}},{"category":"Ll","key":"0211","mappings":{"default":{"default":"r double accent grave"}}},{"category":"Ll","key":"0213","mappings":{"default":{"default":"r brève renversée"}}},{"category":"Ll","key":"0215","mappings":{"default":{"default":"u double accent grave"}}},{"category":"Ll","key":"0217","mappings":{"default":{"default":"u brève renversée"}}},{"category":"Ll","key":"0219","mappings":{"default":{"default":"s virgule souscrite *"}}},{"category":"Ll","key":"021B","mappings":{"default":{"default":"t virgule souscrite *"}}},{"category":"Ll","key":"021F","mappings":{"default":{"default":"h caron"}}},{"category":"Ll","key":"0227","mappings":{"default":{"default":"a point en chef"}}},{"category":"Ll","key":"0229","mappings":{"default":{"default":"e cédille"}}},{"category":"Ll","key":"022F","mappings":{"default":{"default":"o point en chef"}}},{"category":"Ll","key":"0233","mappings":{"default":{"default":"y macron"}}},{"category":"Ll","key":"0237","mappings":{"default":{"default":"j sans point"}}},{"key":"1E01","mappings":{"default":{"default":"a à rond souscrit"}},"category":"Ll"},{"key":"1E03","mappings":{"default":{"default":"b point en chef"}},"category":"Ll"},{"key":"1E05","mappings":{"default":{"default":"b point souscrit"}},"category":"Ll"},{"key":"1E07","mappings":{"default":{"default":"b ligne souscrite"}},"category":"Ll"},{"key":"1E0B","mappings":{"default":{"default":"d point en chef"}},"category":"Ll"},{"key":"1E0D","mappings":{"default":{"default":"d point souscrit"}},"category":"Ll"},{"key":"1E0F","mappings":{"default":{"default":"d ligne souscrite"}},"category":"Ll"},{"key":"1E11","mappings":{"default":{"default":"d cédille"}},"category":"Ll"},{"key":"1E13","mappings":{"default":{"default":"d accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E19","mappings":{"default":{"default":"e accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E1B","mappings":{"default":{"default":"e tilde souscrit"}},"category":"Ll"},{"key":"1E1F","mappings":{"default":{"default":"f point en chef"}},"category":"Ll"},{"key":"1E21","mappings":{"default":{"default":"g macron"}},"category":"Ll"},{"key":"1E23","mappings":{"default":{"default":"h point en chef"}},"category":"Ll"},{"key":"1E25","mappings":{"default":{"default":"h point souscrit"}},"category":"Ll"},{"key":"1E27","mappings":{"default":{"default":"h tréma"}},"category":"Ll"},{"key":"1E29","mappings":{"default":{"default":"h cédille"}},"category":"Ll"},{"key":"1E2B","mappings":{"default":{"default":"h brève souscrit"}},"category":"Ll"},{"key":"1E2D","mappings":{"default":{"default":"i tilde souscrit"}},"category":"Ll"},{"key":"1E31","mappings":{"default":{"default":"k accent aigu"}},"category":"Ll"},{"key":"1E33","mappings":{"default":{"default":"k point souscrit"}},"category":"Ll"},{"key":"1E35","mappings":{"default":{"default":"k ligne souscrite"}},"category":"Ll"},{"key":"1E37","mappings":{"default":{"default":"l point souscrit"}},"category":"Ll"},{"key":"1E3B","mappings":{"default":{"default":"l ligne souscrite"}},"category":"Ll"},{"key":"1E3D","mappings":{"default":{"default":"l accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E3F","mappings":{"default":{"default":"m accent aigu"}},"category":"Ll"},{"key":"1E41","mappings":{"default":{"default":"m point en chef"}},"category":"Ll"},{"key":"1E43","mappings":{"default":{"default":"m point souscrit"}},"category":"Ll"},{"key":"1E45","mappings":{"default":{"default":"n point en chef"}},"category":"Ll"},{"key":"1E47","mappings":{"default":{"default":"n point souscrit"}},"category":"Ll"},{"key":"1E49","mappings":{"default":{"default":"n ligne souscrite"}},"category":"Ll"},{"key":"1E4B","mappings":{"default":{"default":"n accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E55","mappings":{"default":{"default":"p accent aigu"}},"category":"Ll"},{"key":"1E57","mappings":{"default":{"default":"p point en chef"}},"category":"Ll"},{"key":"1E59","mappings":{"default":{"default":"r point en chef"}},"category":"Ll"},{"key":"1E5B","mappings":{"default":{"default":"r point souscrit"}},"category":"Ll"},{"key":"1E5F","mappings":{"default":{"default":"r ligne souscrite"}},"category":"Ll"},{"key":"1E61","mappings":{"default":{"default":"s point en chef"}},"category":"Ll"},{"key":"1E63","mappings":{"default":{"default":"s point souscrit"}},"category":"Ll"},{"key":"1E6B","mappings":{"default":{"default":"t point en chef"}},"category":"Ll"},{"key":"1E6D","mappings":{"default":{"default":"t point souscrit"}},"category":"Ll"},{"key":"1E6F","mappings":{"default":{"default":"t ligne souscrite"}},"category":"Ll"},{"key":"1E71","mappings":{"default":{"default":"t accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E73","mappings":{"default":{"default":"u tréma souscrit"}},"category":"Ll"},{"key":"1E75","mappings":{"default":{"default":"u tilde souscrit"}},"category":"Ll"},{"key":"1E77","mappings":{"default":{"default":"u accent circonflexe souscrit"}},"category":"Ll"},{"key":"1E7D","mappings":{"default":{"default":"v tilde"}},"category":"Ll"},{"key":"1E7F","mappings":{"default":{"default":"v point souscrit"}},"category":"Ll"},{"key":"1E81","mappings":{"default":{"default":"w accent grave"}},"category":"Ll"},{"key":"1E83","mappings":{"default":{"default":"w accent aigu"}},"category":"Ll"},{"key":"1E85","mappings":{"default":{"default":"w tréma"}},"category":"Ll"},{"key":"1E87","mappings":{"default":{"default":"w point en chef"}},"category":"Ll"},{"key":"1E89","mappings":{"default":{"default":"w point souscrit"}},"category":"Ll"},{"key":"1E8B","mappings":{"default":{"default":"x point en chef"}},"category":"Ll"},{"key":"1E8D","mappings":{"default":{"default":"x tréma"}},"category":"Ll"},{"key":"1E8F","mappings":{"default":{"default":"y point en chef"}},"category":"Ll"},{"key":"1E91","mappings":{"default":{"default":"z accent circonflexe"}},"category":"Ll"},{"key":"1E93","mappings":{"default":{"default":"z point souscrit"}},"category":"Ll"},{"key":"1E95","mappings":{"default":{"default":"z ligne souscrite"}},"category":"Ll"},{"key":"1E96","mappings":{"default":{"default":"h ligne souscrite"}},"category":"Ll"},{"key":"1E97","mappings":{"default":{"default":"t tréma"}},"category":"Ll"},{"key":"1E98","mappings":{"default":{"default":"w rond en chef"}},"category":"Ll"},{"key":"1E99","mappings":{"default":{"default":"y rond en chef"}},"category":"Ll"},{"key":"1E9A","mappings":{"default":{"default":"a demi rond à droite"}},"category":"Ll"},{"key":"1EA1","mappings":{"default":{"default":"a point souscrit"}},"category":"Ll"},{"key":"1EA3","mappings":{"default":{"default":"a crochet en chef"}},"category":"Ll"},{"key":"1EB9","mappings":{"default":{"default":"e point souscrit"}},"category":"Ll"},{"key":"1EBB","mappings":{"default":{"default":"e crochet en chef"}},"category":"Ll"},{"key":"1EBD","mappings":{"default":{"default":"e tilde"}},"category":"Ll"},{"key":"1EC9","mappings":{"default":{"default":"i crochet en chef"}},"category":"Ll"},{"key":"1ECB","mappings":{"default":{"default":"i point souscrit"}},"category":"Ll"},{"key":"1ECD","mappings":{"default":{"default":"o point souscrit"}},"category":"Ll"},{"key":"1ECF","mappings":{"default":{"default":"o crochet en chef"}},"category":"Ll"},{"key":"1EE5","mappings":{"default":{"default":"u point souscrit"}},"category":"Ll"},{"key":"1EE7","mappings":{"default":{"default":"u crochet en chef"}},"category":"Ll"},{"key":"1EF3","mappings":{"default":{"default":"y accent grave"}},"category":"Ll"},{"key":"1EF5","mappings":{"default":{"default":"y point souscrit"}},"category":"Ll"},{"key":"1EF7","mappings":{"default":{"default":"y crochet en chef"}},"category":"Ll"},{"key":"1EF9","mappings":{"default":{"default":"y tilde"}},"category":"Ll"}]
,
"fr/symbols/latin-rest.js": 
[{"locale":"fr"},{"category":"Ll","key":"210E","mappings":{"default":{"default":"constante de planck"}}},{"category":"Mn","key":"0363","mappings":{"default":{"default":"diacritique a"}}},{"category":"Mn","key":"0364","mappings":{"default":{"default":"diacritique e"}}},{"category":"Mn","key":"0365","mappings":{"default":{"default":"diacritique i"}}},{"category":"Mn","key":"0366","mappings":{"default":{"default":"diacritique o"}}},{"category":"Mn","key":"0367","mappings":{"default":{"default":"diacritique u"}}},{"category":"Mn","key":"0368","mappings":{"default":{"default":"diacritique c"}}},{"category":"Mn","key":"0369","mappings":{"default":{"default":"diacritique d"}}},{"category":"Mn","key":"036A","mappings":{"default":{"default":"diacritique h"}}},{"category":"Mn","key":"036B","mappings":{"default":{"default":"diacritique m"}}},{"category":"Mn","key":"036C","mappings":{"default":{"default":"diacritique r"}}},{"category":"Mn","key":"036D","mappings":{"default":{"default":"diacritique t"}}},{"category":"Mn","key":"036E","mappings":{"default":{"default":"diacritique v"}}},{"category":"Mn","key":"036F","mappings":{"default":{"default":"diacritique x"}}},{"category":"Lm","key":"1D62","mappings":{"default":{"default":"i souscrit"}}},{"category":"Lm","key":"1D63","mappings":{"default":{"default":"r souscrit"}}},{"category":"Lm","key":"1D64","mappings":{"default":{"default":"u souscrit"}}},{"category":"Lm","key":"1D65","mappings":{"default":{"default":"v souscrit"}}},{"category":"Mn","key":"1DCA","mappings":{"default":{"default":"diacritique r souscrite"}}},{"category":"Mn","key":"1DD3","mappings":{"default":{"default":"diacritique a ouvert aplati suscrit"}}},{"category":"Mn","key":"1DD4","mappings":{"default":{"default":"diacritique ae"}}},{"category":"Mn","key":"1DD5","mappings":{"default":{"default":"diacritique ao"}}},{"category":"Mn","key":"1DD6","mappings":{"default":{"default":"diacritique av"}}},{"category":"Mn","key":"1DD7","mappings":{"default":{"default":"diacritique c cédille"}}},{"category":"Mn","key":"1DD8","mappings":{"default":{"default":"diacritique d insulaire"}}},{"category":"Mn","key":"1DD9","mappings":{"default":{"default":"diacritique eth"}}},{"category":"Mn","key":"1DDA","mappings":{"default":{"default":"diacritique g"}}},{"category":"Mn","key":"1DDB","mappings":{"default":{"default":"diacritique petite g majuscule"}}},{"category":"Mn","key":"1DDC","mappings":{"default":{"default":"diacritique k"}}},{"category":"Mn","key":"1DDD","mappings":{"default":{"default":"diacritique l"}}},{"category":"Mn","key":"1DDE","mappings":{"default":{"default":"diacritique petite l majuscule"}}},{"category":"Mn","key":"1DDF","mappings":{"default":{"default":"diacritique petite m majuscule"}}},{"category":"Mn","key":"1DE0","mappings":{"default":{"default":"diacritique n"}}},{"category":"Mn","key":"1DE1","mappings":{"default":{"default":"diacritique petite n majuscule"}}},{"category":"Mn","key":"1DE2","mappings":{"default":{"default":"diacritique petite r majuscule"}}},{"category":"Mn","key":"1DE3","mappings":{"default":{"default":"diacritique r rotunda"}}},{"category":"Mn","key":"1DE4","mappings":{"default":{"default":"diacritique s"}}},{"category":"Mn","key":"1DE5","mappings":{"default":{"default":"diacritique s long"}}},{"category":"Mn","key":"1DE6","mappings":{"default":{"default":"diacritique z"}}},{"category":"Lm","key":"2071","mappings":{"default":{"default":"exposant i"}}},{"category":"Lm","key":"207F","mappings":{"default":{"default":"exposant n"}}},{"category":"Lm","key":"2090","mappings":{"default":{"default":"indice a"}}},{"category":"Lm","key":"2091","mappings":{"default":{"default":"indice e"}}},{"category":"Lm","key":"2092","mappings":{"default":{"default":"indice o"}}},{"category":"Lm","key":"2093","mappings":{"default":{"default":"indice x"}}},{"category":"Lm","key":"2094","mappings":{"default":{"default":"indice schwa"}}},{"category":"Lm","key":"2095","mappings":{"default":{"default":"souscrite h"}}},{"category":"Lm","key":"2096","mappings":{"default":{"default":"souscrite k"}}},{"category":"Lm","key":"2097","mappings":{"default":{"default":"souscrite l"}}},{"category":"Lm","key":"2098","mappings":{"default":{"default":"souscrite m"}}},{"category":"Lm","key":"2099","mappings":{"default":{"default":"souscrite n"}}},{"category":"Lm","key":"209A","mappings":{"default":{"default":"souscrite p"}}},{"category":"Lm","key":"209B","mappings":{"default":{"default":"souscrite s"}}},{"category":"Lm","key":"209C","mappings":{"default":{"default":"souscrite t"}}},{"category":"Lm","key":"2C7C","mappings":{"default":{"default":"j souscrite"}}},{"category":"So","key":"1F12A","mappings":{"default":{"default":"s majuscule en écaille crochetée"}}},{"category":"So","key":"1F12B","mappings":{"default":{"default":"c majuscule en italique cerclée"}}},{"category":"So","key":"1F12C","mappings":{"default":{"default":"r majuscule en italique cerclée"}}},{"category":"So","key":"1F18A","mappings":{"default":{"default":"P majuscule encadrée et en inversion avec croix"}}}]
,
"fr/symbols/latin-upper-double-accent.js": 
[{"locale":"fr"},{"category":"Lu","key":"01D5","mappings":{"default":{"default":"U majuscule trémaa et macron"}}},{"category":"Lu","key":"01D7","mappings":{"default":{"default":"U majuscule trémaa et accent aigu"}}},{"category":"Lu","key":"01D9","mappings":{"default":{"default":"U majuscule trémaa et caron"}}},{"category":"Lu","key":"01DB","mappings":{"default":{"default":"U majuscule trémaa et accent grave"}}},{"category":"Lu","key":"01DE","mappings":{"default":{"default":"A majuscule trémaa et macron"}}},{"category":"Lu","key":"01E0","mappings":{"default":{"default":"A majuscule point en chef et macron"}}},{"category":"Lu","key":"01EC","mappings":{"default":{"default":"O majuscule ogonek et macron"}}},{"category":"Lu","key":"01FA","mappings":{"default":{"default":"A majuscule rond en chef et accent aigu"}}},{"category":"Lu","key":"022A","mappings":{"default":{"default":"O majuscule tréma et macron"}}},{"category":"Lu","key":"022C","mappings":{"default":{"default":"O majuscule tilde et macron"}}},{"category":"Lu","key":"0230","mappings":{"default":{"default":"O majuscule point en chef et macron"}}},{"key":"1E08","mappings":{"default":{"default":"C cédille et accent aigu majuscule"}},"category":"Lu"},{"key":"1E14","mappings":{"default":{"default":"E macron et accent grave majuscule"}},"category":"Lu"},{"key":"1E16","mappings":{"default":{"default":"E macron et accent aigu majuscule"}},"category":"Lu"},{"key":"1E1C","mappings":{"default":{"default":"E cédille et brève majuscule"}},"category":"Lu"},{"key":"1E2E","mappings":{"default":{"default":"I tréma et accent aigu majuscule"}},"category":"Lu"},{"key":"1E38","mappings":{"default":{"default":"L point souscrit et macron majuscule"}},"category":"Lu"},{"key":"1E4C","mappings":{"default":{"default":"O tilde et accent aigu majuscule"}},"category":"Lu"},{"key":"1E4E","mappings":{"default":{"default":"O tilde et tréma majuscule"}},"category":"Lu"},{"key":"1E50","mappings":{"default":{"default":"O macron et accent grave majuscule"}},"category":"Lu"},{"key":"1E52","mappings":{"default":{"default":"O macron et accent aigu majuscule"}},"category":"Lu"},{"key":"1E5C","mappings":{"default":{"default":"R point souscrit et macron majuscule"}},"category":"Lu"},{"key":"1E64","mappings":{"default":{"default":"S accent aigu et point en chef majuscule"}},"category":"Lu"},{"key":"1E66","mappings":{"default":{"default":"S caron et point en chef majuscule"}},"category":"Lu"},{"key":"1E68","mappings":{"default":{"default":"S point souscrit et point en chef majuscule"}},"category":"Lu"},{"key":"1E78","mappings":{"default":{"default":"U tilde et accent aigu majuscule"}},"category":"Lu"},{"key":"1E7A","mappings":{"default":{"default":"U macron et tréma majuscule"}},"category":"Lu"},{"key":"1EA4","mappings":{"default":{"default":"A accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1EA6","mappings":{"default":{"default":"A accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1EA8","mappings":{"default":{"default":"A accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EAA","mappings":{"default":{"default":"A accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1EAC","mappings":{"default":{"default":"A accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1EAE","mappings":{"default":{"default":"A brève et accent aigu majuscule"}},"category":"Lu"},{"key":"1EB0","mappings":{"default":{"default":"A brève et accent grave majuscule"}},"category":"Lu"},{"key":"1EB2","mappings":{"default":{"default":"A brève et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EB4","mappings":{"default":{"default":"A brève et tilde majuscule"}},"category":"Lu"},{"key":"1EB6","mappings":{"default":{"default":"A brève et point souscrit majuscule"}},"category":"Lu"},{"key":"1EBE","mappings":{"default":{"default":"E accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1EC0","mappings":{"default":{"default":"E accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1EC2","mappings":{"default":{"default":"E accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EC4","mappings":{"default":{"default":"E accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1EC6","mappings":{"default":{"default":"E accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1ED0","mappings":{"default":{"default":"O accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1ED2","mappings":{"default":{"default":"O accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1ED4","mappings":{"default":{"default":"O accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1ED6","mappings":{"default":{"default":"O accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1ED8","mappings":{"default":{"default":"O accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1EDA","mappings":{"default":{"default":"O cornu accent aigu majuscule"}},"category":"Lu"},{"key":"1EDC","mappings":{"default":{"default":"O cornu accent grave majuscule"}},"category":"Lu"},{"key":"1EDE","mappings":{"default":{"default":"O cornu crochet en chef majuscule"}},"category":"Lu"},{"key":"1EE0","mappings":{"default":{"default":"O cornu tilde majuscule"}},"category":"Lu"},{"key":"1EE2","mappings":{"default":{"default":"O cornu point souscrit majuscule"}},"category":"Lu"},{"key":"1EE8","mappings":{"default":{"default":"U cornu accent aigu majuscule"}},"category":"Lu"},{"key":"1EEA","mappings":{"default":{"default":"U cornu accent grave majuscule"}},"category":"Lu"},{"key":"1EEC","mappings":{"default":{"default":"U cornu crochet en chef majuscule"}},"category":"Lu"},{"key":"1EEE","mappings":{"default":{"default":"U cornu tilde majuscule"}},"category":"Lu"},{"key":"1EF0","mappings":{"default":{"default":"U cornu point souscrit majuscule"}},"category":"Lu"}]
,
"fr/symbols/latin-upper-single-accent.js": 
[{"locale":"fr"},{"key":"00C0","mappings":{"default":{"default":"A accent grave majuscule"}},"category":"Lu"},{"key":"00C1","mappings":{"default":{"default":"A accent aigu majuscule"}},"category":"Lu"},{"key":"00C2","mappings":{"default":{"default":"A accent circonflexe majuscule"}},"category":"Lu"},{"key":"00C3","mappings":{"default":{"default":"A tilde majuscule"}},"category":"Lu"},{"key":"00C4","mappings":{"default":{"default":"A tréma majuscule"}},"category":"Lu"},{"key":"00C5","mappings":{"default":{"default":"angstrom"}},"category":"Lu"},{"key":"00C7","mappings":{"default":{"default":"C cédille majuscule"}},"category":"Lu"},{"key":"00C8","mappings":{"default":{"default":"E accent grave majuscule"}},"category":"Lu"},{"key":"00C9","mappings":{"default":{"default":"E accent aigu majuscule"}},"category":"Lu"},{"key":"00CA","mappings":{"default":{"default":"E accent circonflexe majuscule"}},"category":"Lu"},{"key":"00CB","mappings":{"default":{"default":"E tréma majuscule"}},"category":"Lu"},{"key":"00CC","mappings":{"default":{"default":"I accent grave majuscule"}},"category":"Lu"},{"key":"00CD","mappings":{"default":{"default":"I accent aigu majuscule"}},"category":"Lu"},{"key":"00CE","mappings":{"default":{"default":"I accent circonflexe majuscule"}},"category":"Lu"},{"key":"00CF","mappings":{"default":{"default":"I tréma majuscule"}},"category":"Lu"},{"key":"00D1","mappings":{"default":{"default":"N tilde majuscule"}},"category":"Lu"},{"key":"00D2","mappings":{"default":{"default":"O accent grave majuscule"}},"category":"Lu"},{"key":"00D3","mappings":{"default":{"default":"O accent aigu majuscule"}},"category":"Lu"},{"key":"00D4","mappings":{"default":{"default":"O accent circonflexe majuscule"}},"category":"Lu"},{"key":"00D5","mappings":{"default":{"default":"O tilde majuscule"}},"category":"Lu"},{"key":"00D6","mappings":{"default":{"default":"O tréma majuscule"}},"category":"Lu"},{"key":"00D9","mappings":{"default":{"default":"U accent grave majuscule"}},"category":"Lu"},{"key":"00DA","mappings":{"default":{"default":"U accent aigu majuscule"}},"category":"Lu"},{"key":"00DB","mappings":{"default":{"default":"U accent circonflexe majuscule"}},"category":"Lu"},{"key":"00DC","mappings":{"default":{"default":"U tréma majuscule"}},"category":"Lu"},{"key":"00DD","mappings":{"default":{"default":"Y accent aigu majuscule"}},"category":"Lu"},{"key":"0100","mappings":{"default":{"default":"A macron majuscule"}},"category":"Lu"},{"key":"0102","mappings":{"default":{"default":"A brève majuscule"}},"category":"Lu"},{"key":"0104","mappings":{"default":{"default":"A ogonek majuscule"}},"category":"Lu"},{"key":"0106","mappings":{"default":{"default":"C accent aigu majuscule"}},"category":"Lu"},{"key":"0108","mappings":{"default":{"default":"C accent circonflexe majuscule"}},"category":"Lu"},{"key":"010A","mappings":{"default":{"default":"C point en chef majuscule"}},"category":"Lu"},{"key":"010C","mappings":{"default":{"default":"C caron majuscule"}},"category":"Lu"},{"key":"010E","mappings":{"default":{"default":"D caron majuscule"}},"category":"Lu"},{"key":"0112","mappings":{"default":{"default":"E macron majuscule"}},"category":"Lu"},{"category":"Lu","key":"0114","mappings":{"default":{"default":"E brève majuscule"}}},{"key":"0116","mappings":{"default":{"default":"E point en chef majuscule"}},"category":"Lu"},{"key":"0118","mappings":{"default":{"default":"E ogonek majuscule"}},"category":"Lu"},{"key":"011A","mappings":{"default":{"default":"E caron majuscule"}},"category":"Lu"},{"key":"011C","mappings":{"default":{"default":"G accent circonflexe majuscule"}},"category":"Lu"},{"key":"011E","mappings":{"default":{"default":"G brève majuscule"}},"category":"Lu"},{"key":"0120","mappings":{"default":{"default":"G point en chef majuscule"}},"category":"Lu"},{"key":"0122","mappings":{"default":{"default":"G cédille majuscule"}},"category":"Lu"},{"key":"0124","mappings":{"default":{"default":"H accent circonflexe majuscule"}},"category":"Lu"},{"key":"0128","mappings":{"default":{"default":"I tilde majuscule"}},"category":"Lu"},{"key":"012A","mappings":{"default":{"default":"I macron majuscule"}},"category":"Lu"},{"category":"Lu","key":"012C","mappings":{"default":{"default":"I brève majuscule"}}},{"key":"012E","mappings":{"default":{"default":"I ogonek majuscule"}},"category":"Lu"},{"key":"0130","mappings":{"default":{"default":"I point en chef majuscule"}},"category":"Lu"},{"key":"0134","mappings":{"default":{"default":"J accent circonflexe majuscule"}},"category":"Lu"},{"key":"0136","mappings":{"default":{"default":"K cédille majuscule"}},"category":"Lu"},{"key":"0139","mappings":{"default":{"default":"L accent aigu majuscule"}},"category":"Lu"},{"key":"013B","mappings":{"default":{"default":"L cédille majuscule"}},"category":"Lu"},{"key":"013D","mappings":{"default":{"default":"L caron majuscule"}},"category":"Lu"},{"key":"013F","mappings":{"default":{"default":"L point médian majuscule"}},"category":"Lu"},{"key":"0143","mappings":{"default":{"default":"N accent aigu majuscule"}},"category":"Lu"},{"key":"0145","mappings":{"default":{"default":"N cédille majuscule"}},"category":"Lu"},{"key":"0147","mappings":{"default":{"default":"N caron majuscule"}},"category":"Lu"},{"key":"014C","mappings":{"default":{"default":"O macron majuscule"}},"category":"Lu"},{"category":"Lu","key":"014E","mappings":{"default":{"default":"O brève majuscule"}}},{"key":"0150","mappings":{"default":{"default":"O avec double accent aigu majuscule"}},"category":"Lu"},{"key":"0154","mappings":{"default":{"default":"R accent aigu majuscule"}},"category":"Lu"},{"key":"0156","mappings":{"default":{"default":"R cédille majuscule"}},"category":"Lu"},{"key":"0158","mappings":{"default":{"default":"R caron majuscule"}},"category":"Lu"},{"key":"015A","mappings":{"default":{"default":"S accent aigu majuscule"}},"category":"Lu"},{"key":"015C","mappings":{"default":{"default":"S accent circonflexe majuscule"}},"category":"Lu"},{"key":"015E","mappings":{"default":{"default":"S cédille majuscule"}},"category":"Lu"},{"key":"0160","mappings":{"default":{"default":"S caron majuscule"}},"category":"Lu"},{"key":"0162","mappings":{"default":{"default":"T cédille majuscule"}},"category":"Lu"},{"key":"0164","mappings":{"default":{"default":"T caron majuscule"}},"category":"Lu"},{"key":"0168","mappings":{"default":{"default":"U tilde majuscule"}},"category":"Lu"},{"key":"016A","mappings":{"default":{"default":"U macron majuscule"}},"category":"Lu"},{"key":"016C","mappings":{"default":{"default":"U brève majuscule"}},"category":"Lu"},{"key":"016E","mappings":{"default":{"default":"U rond en chef majuscule"}},"category":"Lu"},{"key":"0170","mappings":{"default":{"default":"U avec double accent aigu majuscule"}},"category":"Lu"},{"key":"0172","mappings":{"default":{"default":"U ogonek majuscule"}},"category":"Lu"},{"key":"0174","mappings":{"default":{"default":"W accent circonflexe majuscule"}},"category":"Lu"},{"key":"0176","mappings":{"default":{"default":"Y accent circonflexe majuscule"}},"category":"Lu"},{"key":"0178","mappings":{"default":{"default":"Y tréma majuscule"}},"category":"Lu"},{"key":"0179","mappings":{"default":{"default":"Z accent aigu majuscule"}},"category":"Lu"},{"key":"017B","mappings":{"default":{"default":"Z point en chef majuscule"}},"category":"Lu"},{"key":"017D","mappings":{"default":{"default":"Z caron majuscule"}},"category":"Lu"},{"category":"Lu","key":"01CD","mappings":{"default":{"default":"A caron majuscule"}}},{"category":"Lu","key":"01CF","mappings":{"default":{"default":"I caron majuscule"}}},{"category":"Lu","key":"01D1","mappings":{"default":{"default":"O caron majuscule"}}},{"category":"Lu","key":"01D3","mappings":{"default":{"default":"U caron majuscule"}}},{"category":"Lu","key":"01E6","mappings":{"default":{"default":"G caron majuscule"}}},{"category":"Lu","key":"01E8","mappings":{"default":{"default":"K caron majuscule"}}},{"category":"Lu","key":"01EA","mappings":{"default":{"default":"O ogonek majuscule"}}},{"category":"Lu","key":"01F4","mappings":{"default":{"default":"G accent aigu majuscule"}}},{"category":"Lu","key":"01F8","mappings":{"default":{"default":"N grave majuscule"}}},{"category":"Lu","key":"0200","mappings":{"default":{"default":"A double accent grave majuscule"}}},{"category":"Lu","key":"0202","mappings":{"default":{"default":"A brève renversée majuscule"}}},{"category":"Lu","key":"0204","mappings":{"default":{"default":"E double accent grave majuscule"}}},{"category":"Lu","key":"0206","mappings":{"default":{"default":"E brève renversée majuscule"}}},{"category":"Lu","key":"0208","mappings":{"default":{"default":"I double accent grave majuscule"}}},{"category":"Lu","key":"020A","mappings":{"default":{"default":"I brève renversée majuscule"}}},{"category":"Lu","key":"020C","mappings":{"default":{"default":"O double accent grave majuscule"}}},{"category":"Lu","key":"020E","mappings":{"default":{"default":"O brève renversée majuscule"}}},{"category":"Lu","key":"0210","mappings":{"default":{"default":"R double accent grave majuscule"}}},{"category":"Lu","key":"0212","mappings":{"default":{"default":"R brève renversée majuscule"}}},{"category":"Lu","key":"0214","mappings":{"default":{"default":"U double accent grave majuscule"}}},{"category":"Lu","key":"0216","mappings":{"default":{"default":"U brève renversée majuscule"}}},{"category":"Lu","key":"0218","mappings":{"default":{"default":"S virgule souscrite * majuscule"}}},{"category":"Lu","key":"021A","mappings":{"default":{"default":"T virgule souscrite * majuscule"}}},{"category":"Lu","key":"021E","mappings":{"default":{"default":"H caron majuscule"}}},{"category":"Lu","key":"0226","mappings":{"default":{"default":"A point en chef majuscule"}}},{"category":"Lu","key":"0228","mappings":{"default":{"default":"E cédille majuscule"}}},{"category":"Lu","key":"022E","mappings":{"default":{"default":"O point en chef majuscule"}}},{"category":"Lu","key":"0232","mappings":{"default":{"default":"Y macron majuscule"}}},{"key":"1E00","mappings":{"default":{"default":"A à rond souscrit majuscule"}},"category":"Lu"},{"key":"1E02","mappings":{"default":{"default":"B point en chef majuscule"}},"category":"Lu"},{"key":"1E04","mappings":{"default":{"default":"B point souscrit majuscule"}},"category":"Lu"},{"key":"1E06","mappings":{"default":{"default":"B ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E0A","mappings":{"default":{"default":"D point en chef majuscule"}},"category":"Lu"},{"key":"1E0C","mappings":{"default":{"default":"D point souscrit majuscule"}},"category":"Lu"},{"key":"1E0E","mappings":{"default":{"default":"D ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E10","mappings":{"default":{"default":"D cédille majuscule"}},"category":"Lu"},{"key":"1E12","mappings":{"default":{"default":"D accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E18","mappings":{"default":{"default":"E accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E1A","mappings":{"default":{"default":"E tilde souscrit majuscule"}},"category":"Lu"},{"key":"1E1E","mappings":{"default":{"default":"F point en chef majuscule"}},"category":"Lu"},{"key":"1E20","mappings":{"default":{"default":"G macron majuscule"}},"category":"Lu"},{"key":"1E22","mappings":{"default":{"default":"H point en chef majuscule"}},"category":"Lu"},{"key":"1E24","mappings":{"default":{"default":"H point souscrit majuscule"}},"category":"Lu"},{"key":"1E26","mappings":{"default":{"default":"H tréma majuscule"}},"category":"Lu"},{"key":"1E28","mappings":{"default":{"default":"H cédille majuscule"}},"category":"Lu"},{"key":"1E2A","mappings":{"default":{"default":"H brève souscrit majuscule"}},"category":"Lu"},{"key":"1E2C","mappings":{"default":{"default":"I tilde souscrit majuscule"}},"category":"Lu"},{"key":"1E30","mappings":{"default":{"default":"K accent aigu majuscule"}},"category":"Lu"},{"key":"1E32","mappings":{"default":{"default":"K point souscrit majuscule"}},"category":"Lu"},{"key":"1E34","mappings":{"default":{"default":"K ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E36","mappings":{"default":{"default":"L point souscrit majuscule"}},"category":"Lu"},{"key":"1E3A","mappings":{"default":{"default":"L ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E3C","mappings":{"default":{"default":"L accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E3E","mappings":{"default":{"default":"M accent aigu majuscule"}},"category":"Lu"},{"key":"1E40","mappings":{"default":{"default":"M point en chef majuscule"}},"category":"Lu"},{"key":"1E42","mappings":{"default":{"default":"M point souscrit majuscule"}},"category":"Lu"},{"key":"1E44","mappings":{"default":{"default":"N point en chef majuscule"}},"category":"Lu"},{"key":"1E46","mappings":{"default":{"default":"N point souscrit majuscule"}},"category":"Lu"},{"key":"1E48","mappings":{"default":{"default":"N ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E4A","mappings":{"default":{"default":"N accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E54","mappings":{"default":{"default":"P accent aigu majuscule"}},"category":"Lu"},{"key":"1E56","mappings":{"default":{"default":"P point en chef majuscule"}},"category":"Lu"},{"key":"1E58","mappings":{"default":{"default":"R point en chef majuscule"}},"category":"Lu"},{"key":"1E5A","mappings":{"default":{"default":"R point souscrit majuscule"}},"category":"Lu"},{"key":"1E5E","mappings":{"default":{"default":"R ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E60","mappings":{"default":{"default":"S point en chef majuscule"}},"category":"Lu"},{"key":"1E62","mappings":{"default":{"default":"S point souscrit majuscule"}},"category":"Lu"},{"key":"1E6A","mappings":{"default":{"default":"T point en chef majuscule"}},"category":"Lu"},{"key":"1E6C","mappings":{"default":{"default":"T point souscrit majuscule"}},"category":"Lu"},{"key":"1E6E","mappings":{"default":{"default":"T ligne souscrite majuscule"}},"category":"Lu"},{"key":"1E70","mappings":{"default":{"default":"T accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E72","mappings":{"default":{"default":"U tréma souscrit majuscule"}},"category":"Lu"},{"key":"1E74","mappings":{"default":{"default":"U tilde souscrit majuscule"}},"category":"Lu"},{"key":"1E76","mappings":{"default":{"default":"U accent circonflexe souscrit majuscule"}},"category":"Lu"},{"key":"1E7C","mappings":{"default":{"default":"V tilde majuscule"}},"category":"Lu"},{"key":"1E7E","mappings":{"default":{"default":"V point souscrit majuscule"}},"category":"Lu"},{"key":"1E80","mappings":{"default":{"default":"W accent grave majuscule"}},"category":"Lu"},{"key":"1E82","mappings":{"default":{"default":"W accent aigu majuscule"}},"category":"Lu"},{"key":"1E84","mappings":{"default":{"default":"W tréma majuscule"}},"category":"Lu"},{"key":"1E86","mappings":{"default":{"default":"W point en chef majuscule"}},"category":"Lu"},{"key":"1E88","mappings":{"default":{"default":"W point souscrit majuscule"}},"category":"Lu"},{"key":"1E8A","mappings":{"default":{"default":"X point en chef majuscule"}},"category":"Lu"},{"key":"1E8C","mappings":{"default":{"default":"X tréma majuscule"}},"category":"Lu"},{"key":"1E8E","mappings":{"default":{"default":"Y point en chef majuscule"}},"category":"Lu"},{"key":"1E90","mappings":{"default":{"default":"Z accent circonflexe majuscule"}},"category":"Lu"},{"key":"1E92","mappings":{"default":{"default":"Z point souscrit majuscule"}},"category":"Lu"},{"key":"1E94","mappings":{"default":{"default":"Z ligne souscrite majuscule"}},"category":"Lu"},{"key":"1EA0","mappings":{"default":{"default":"A point souscrit majuscule"}},"category":"Lu"},{"key":"1EA2","mappings":{"default":{"default":"A crochet en chef majuscule"}},"category":"Lu"},{"key":"1EB8","mappings":{"default":{"default":"E point souscrit majuscule"}},"category":"Lu"},{"key":"1EBA","mappings":{"default":{"default":"E crochet en chef majuscule"}},"category":"Lu"},{"key":"1EBC","mappings":{"default":{"default":"E tilde majuscule"}},"category":"Lu"},{"key":"1EC8","mappings":{"default":{"default":"I crochet en chef majuscule"}},"category":"Lu"},{"key":"1ECA","mappings":{"default":{"default":"I point souscrit majuscule"}},"category":"Lu"},{"key":"1ECC","mappings":{"default":{"default":"O point souscrit majuscule"}},"category":"Lu"},{"key":"1ECE","mappings":{"default":{"default":"O crochet en chef majuscule"}},"category":"Lu"},{"key":"1EE4","mappings":{"default":{"default":"U point souscrit majuscule"}},"category":"Lu"},{"key":"1EE6","mappings":{"default":{"default":"U crochet en chef majuscule"}},"category":"Lu"},{"key":"1EF2","mappings":{"default":{"default":"Y accent grave majuscule"}},"category":"Lu"},{"key":"1EF4","mappings":{"default":{"default":"Y point souscrit majuscule"}},"category":"Lu"},{"key":"1EF6","mappings":{"default":{"default":"Y crochet en chef majuscule"}},"category":"Lu"},{"key":"1EF8","mappings":{"default":{"default":"Y tilde majuscule"}},"category":"Lu"}]
,
"fr/symbols/math_angles.js": 
[{"locale":"fr"},{"key":"22BE","mappings":{"default":{"default":"angle droit avec arc"}},"category":"Sm"},{"key":"237C","mappings":{"default":{"default":"angle droit avec flèche en zigzag vers le bas"}},"category":"Sm"},{"key":"27C0","mappings":{"default":{"default":"angle tridimensionnel"}},"category":"Sm"},{"category":"Sm","key":"299B","mappings":{"default":{"default":"angle mesuré s'ouvrant vers la gauche"}}},{"category":"Sm","key":"299C","mappings":{"default":{"default":"variante d'angle avec carré"}}},{"key":"299D","mappings":{"default":{"default":"angle droit mesuré pointé"}},"category":"Sm"},{"category":"Sm","key":"299E","mappings":{"default":{"default":"angle avec s inscrit"}}},{"category":"Sm","key":"299F","mappings":{"default":{"default":"angle aigu"}}},{"category":"Sm","key":"29A0","mappings":{"default":{"default":"angle sphérique s'ouvrant vers la gauche"}}},{"category":"Sm","key":"29A1","mappings":{"default":{"default":"angle sphérique s'ouvrant vers le haut"}}},{"category":"Sm","key":"29A2","mappings":{"default":{"default":"angle culbuté"}}},{"category":"Sm","key":"29A3","mappings":{"default":{"default":"angle réfléchi"}}},{"key":"29A4","mappings":{"default":{"default":"angle à barre souscrite"}},"category":"Sm"},{"key":"29A5","mappings":{"default":{"default":"angle à barre souscrite réfléchie"}},"category":"Sm"},{"key":"29A6","mappings":{"default":{"default":"angle oblique s'ouvrant vers le haut"}},"category":"Sm"},{"key":"29A7","mappings":{"default":{"default":"angle oblique s'ouvrant vers le bas"}},"category":"Sm"},{"key":"29A8","mappings":{"default":{"default":"angle calculé à bras vers l'est et bras fléché vers le nord est"}},"category":"Sm"},{"key":"29A9","mappings":{"default":{"default":"angle calculé à bras vers l'ouest et bras fléché vers le nord ouest"}},"category":"Sm"},{"key":"29AA","mappings":{"default":{"default":"angle calculé à bras vers l'est et bras fléché vers le sud est"}},"category":"Sm"},{"key":"29AB","mappings":{"default":{"default":"angle calculé à bras vers l'ouest et bras fléché vers le sud ouest"}},"category":"Sm"},{"key":"29AC","mappings":{"default":{"default":"angle calculé à bras vers le nord et bras fléché vers le nord est"}},"category":"Sm"},{"key":"29AD","mappings":{"default":{"default":"angle calculé à bras vers le nord et bras fléché vers le nord ouest"}},"category":"Sm"},{"key":"29AE","mappings":{"default":{"default":"angle calculé à bras vers le sud et bras fléché vers le sud est"}},"category":"Sm"},{"key":"29AF","mappings":{"default":{"default":"angle calculé à bras vers le sud et bras fléché vers le sud ouest"}},"category":"Sm"}]
,
"fr/symbols/math_arrows.js": 
[{"locale":"fr"},{"key":"2190","mappings":{"default":{"default":"flèche gauche"}},"category":"Sm"},{"key":"2191","mappings":{"default":{"default":"flèche vers le haut"}},"category":"Sm"},{"key":"2192","mappings":{"default":{"default":"flèche droite"}},"category":"Sm"},{"key":"2193","mappings":{"default":{"default":"flèche vers le bas"}},"category":"Sm"},{"key":"2194","mappings":{"default":{"default":"flèche bilatérale"}},"category":"Sm"},{"key":"2195","mappings":{"default":{"default":"flèche haut et bas"}},"category":"So"},{"key":"2196","mappings":{"default":{"default":"flèche nord ouest"}},"category":"So"},{"key":"2197","mappings":{"default":{"default":"flèche nord est"}},"category":"So"},{"key":"2198","mappings":{"default":{"default":"flèche sud est"}},"category":"So"},{"key":"2199","mappings":{"default":{"default":"flèche sud ouest"}},"category":"So"},{"key":"219A","mappings":{"default":{"default":"flèche barrée gauche"}},"category":"Sm"},{"key":"219B","mappings":{"default":{"default":"flèche barrée droite"}},"category":"Sm"},{"key":"219C","mappings":{"default":{"default":"flèche ondulée gauche"}},"category":"So"},{"key":"219D","mappings":{"default":{"default":"flèche ondulée droite"}},"category":"So"},{"key":"219E","mappings":{"default":{"default":"flèche à deux pointes gauche"}},"category":"So"},{"key":"219F","mappings":{"default":{"default":"flèche à deux pointes vers le haut"}},"category":"So"},{"key":"21A0","mappings":{"default":{"default":"flèche à deux pointes droite"}},"category":"Sm"},{"key":"21A1","mappings":{"default":{"default":"flèche à deux pointes vers le bas"}},"category":"So"},{"key":"21A2","mappings":{"default":{"default":"flèche empennée gauche"}},"category":"So"},{"key":"21A3","mappings":{"default":{"default":"flèche empennée droite"}},"category":"Sm"},{"key":"21A4","mappings":{"default":{"default":"flèche d'un taquet gauche"}},"category":"So"},{"key":"21A5","mappings":{"default":{"default":"flèche d'un taquet vers le haut"}},"category":"So"},{"key":"21A6","mappings":{"default":{"default":"flèche d'un taquet droite"}},"category":"Sm"},{"key":"21A7","mappings":{"default":{"default":"flèche d'un taquet vers le bas"}},"category":"So"},{"key":"21A8","mappings":{"default":{"default":"flèche haut bas sur base"}},"category":"So"},{"key":"21A9","mappings":{"default":{"default":"flèche avec crochet gauche"}},"category":"So"},{"key":"21AA","mappings":{"default":{"default":"flèche avec crochet droite"}},"category":"So"},{"key":"21AB","mappings":{"default":{"default":"flèche avec boucle gauche"}},"category":"So"},{"key":"21AC","mappings":{"default":{"default":"flèche avec boucle droite"}},"category":"So"},{"key":"21AD","mappings":{"default":{"default":"flèche ondulée bilatérale"}},"category":"So"},{"key":"21AE","mappings":{"default":{"default":"flèche barrée bilatérale"}},"category":"Sm"},{"key":"21AF","mappings":{"default":{"default":"flèche vers le bas en zigzag"}},"category":"So"},{"key":"21B0","mappings":{"default":{"default":"flèche vers le haut avec pointe gauche"}},"category":"So"},{"key":"21B1","mappings":{"default":{"default":"flèche vers le haut avec pointe droite"}},"category":"So"},{"key":"21B2","mappings":{"default":{"default":"flèche vers le bas avec pointe gauche"}},"category":"So"},{"key":"21B3","mappings":{"default":{"default":"flèche vers le bas avec pointe droite"}},"category":"So"},{"key":"21B4","mappings":{"default":{"default":"flèche vers le bas avec coin droit"}},"category":"So"},{"key":"21B5","mappings":{"default":{"default":"flèche vers le bas avec coin gauche"}},"category":"So"},{"key":"21B6","mappings":{"default":{"default":"flèche semi circulaire en sens positif"}},"category":"So"},{"key":"21B7","mappings":{"default":{"default":"flèche semi circulaire en sens négatif"}},"category":"So"},{"key":"21B8","mappings":{"default":{"default":"flèche nord ouest vers une barre horizontale longue"}},"category":"So"},{"key":"21B9","mappings":{"default":{"default":"flèche gauche vers un taquet sur flèche droite vers un taquet"}},"category":"So"},{"key":"21BA","mappings":{"default":{"default":"flèche en sens positif à cercle ouvert"}},"category":"So"},{"key":"21BB","mappings":{"default":{"default":"flèche en sens négatif à cercle ouvert"}},"category":"So"},{"key":"21C4","mappings":{"default":{"default":"flèche vers le haut par dessus flèche gauche"}},"category":"So"},{"key":"21C5","mappings":{"default":{"default":"flèche vers le haut à gauche d'une flèche vers le bas"}},"category":"So"},{"key":"21C6","mappings":{"default":{"default":"flèche gauche par dessus flèche droite"}},"category":"So"},{"key":"21C7","mappings":{"default":{"default":"paire de flèches gauche"}},"category":"So"},{"key":"21C8","mappings":{"default":{"default":"paire de flèches vers le haut"}},"category":"So"},{"key":"21C9","mappings":{"default":{"default":"paire de flèches droite"}},"category":"So"},{"key":"21CA","mappings":{"default":{"default":"paire de flèches vers le bas"}},"category":"So"},{"key":"21CD","mappings":{"default":{"default":"double flèche barrée gauche"}},"category":"So"},{"key":"21CE","mappings":{"default":{"default":"double flèche barrée bilatérale"}},"category":"Sm"},{"key":"21CF","mappings":{"default":{"default":"double flèche barrée droite"}},"category":"Sm"},{"key":"21D0","mappings":{"default":{"default":"double flèche gauche"}},"category":"So"},{"key":"21D1","mappings":{"default":{"default":"double flèche vers le haut"}},"category":"So"},{"key":"21D2","mappings":{"default":{"default":"double flèche droite"}},"category":"Sm"},{"key":"21D3","mappings":{"default":{"default":"double flèche vers le bas"}},"category":"So"},{"key":"21D4","mappings":{"default":{"default":"double flèche bilatérale"}},"category":"Sm"},{"key":"21D5","mappings":{"default":{"default":"double flèche haut bas"}},"category":"So"},{"key":"21D6","mappings":{"default":{"default":"double flèche nord ouest"}},"category":"So"},{"key":"21D7","mappings":{"default":{"default":"double flèche nord est"}},"category":"So"},{"key":"21D8","mappings":{"default":{"default":"double flèche sud est"}},"category":"So"},{"key":"21D9","mappings":{"default":{"default":"double flèche sud ouest"}},"category":"So"},{"key":"21DA","mappings":{"default":{"default":"triple flèche gauche"}},"category":"So"},{"key":"21DB","mappings":{"default":{"default":"triple flèche droite"}},"category":"So"},{"key":"21DC","mappings":{"default":{"default":"flèche en tire bouchon gauche"}},"category":"So"},{"key":"21DD","mappings":{"default":{"default":"flèche en tire bouchon droite"}},"category":"So"},{"key":"21DE","mappings":{"default":{"default":"flèche vers le haut avec double barre"}},"category":"So"},{"key":"21DF","mappings":{"default":{"default":"flèche vers le bas avec double barre"}},"category":"So"},{"key":"21E0","mappings":{"default":{"default":"flèche pointillée gauche"}},"category":"So"},{"key":"21E1","mappings":{"default":{"default":"flèche pointillée vers le haut"}},"category":"So"},{"key":"21E2","mappings":{"default":{"default":"flèche pointillée droite"}},"category":"So"},{"key":"21E3","mappings":{"default":{"default":"flèche pointillée vers le bas"}},"category":"So"},{"key":"21E4","mappings":{"default":{"default":"flèche gauche vers un taquet"}},"category":"So"},{"key":"21E5","mappings":{"default":{"default":"flèche droite vers un taquet"}},"category":"So"},{"key":"21E6","mappings":{"default":{"default":"flèche blanche gauche"}},"category":"So"},{"key":"21E7","mappings":{"default":{"default":"flèche blanche vers le haut"}},"category":"So"},{"key":"21E8","mappings":{"default":{"default":"flèche blanche droite"}},"category":"So"},{"key":"21E9","mappings":{"default":{"default":"flèche blanche vers le bas"}},"category":"So"},{"key":"21EA","mappings":{"default":{"default":"flèche blanche vers le haut à partir d'un taquet"}},"category":"So"},{"category":"So","key":"21EB","mappings":{"default":{"default":"flèche blanche vers le haut sur socle"}}},{"category":"So","key":"21EC","mappings":{"default":{"default":"flèche blanche vers le haut sur socle et trait horizontal"}}},{"category":"So","key":"21ED","mappings":{"default":{"default":"flèche blanche vers le haut sur socle et barre verticale"}}},{"category":"So","key":"21EE","mappings":{"default":{"default":"double flèche blanche vers le haut"}}},{"category":"So","key":"21EF","mappings":{"default":{"default":"double flèche blanche vers le haut sur socle"}}},{"category":"So","key":"21F0","mappings":{"default":{"default":"flèche blanche vers la droite appuyée sur mur"}}},{"category":"So","key":"21F1","mappings":{"default":{"default":"flèche nord ouest en encoignure"}}},{"category":"So","key":"21F2","mappings":{"default":{"default":"flèche sud est en encoignure"}}},{"category":"So","key":"21F3","mappings":{"default":{"default":"flèche blanche vers le haut et le bas"}}},{"category":"Sm","key":"21F4","mappings":{"default":{"default":"flèche vers la droite à petit cercle"}}},{"key":"21F5","mappings":{"default":{"default":"flèche descendante à gauche d'une flèche montante"}},"category":"Sm"},{"category":"Sm","key":"21F6","mappings":{"default":{"default":"trois flèches vers la droite"}}},{"category":"Sm","key":"21F7","mappings":{"default":{"default":"flèche vers la gauche barrée verticalement"}}},{"category":"Sm","key":"21F8","mappings":{"default":{"default":"flèche vers la droite barrée verticalement"}}},{"category":"Sm","key":"21F9","mappings":{"default":{"default":"flèche vers la droite et la gauche barrée verticalement"}}},{"category":"Sm","key":"21FA","mappings":{"default":{"default":"flèche vers la gauche barrée deux fois verticalement"}}},{"category":"Sm","key":"21FB","mappings":{"default":{"default":"flèche vers la droite barrée deux fois verticalement"}}},{"category":"Sm","key":"21FC","mappings":{"default":{"default":"flèche bilatérale barrée deux fois verticalement"}}},{"key":"21FD","mappings":{"default":{"default":"flèche à tête creuse gauche"}},"category":"Sm"},{"key":"21FE","mappings":{"default":{"default":"flèche à tête creuse droite"}},"category":"Sm"},{"key":"21FF","mappings":{"default":{"default":"flèche à tête creuse bilatérale"}},"category":"Sm"},{"category":"So","key":"2301","mappings":{"default":{"default":"flèche électrique"}}},{"category":"So","key":"2303","mappings":{"default":{"default":"pointe de flèche vers le haut"}}},{"category":"So","key":"2304","mappings":{"default":{"default":"pointe de flèche vers le bas"}}},{"category":"So","key":"2324","mappings":{"default":{"default":"pointe de flèche vers le haut entre deux traits horizontaux"}}},{"category":"So","key":"238B","mappings":{"default":{"default":"cercle brisé à flèche nord ouest (échappement)"}}},{"category":"So","key":"2794","mappings":{"default":{"default":"flèche grasse vers la droite à pointe large"}}},{"category":"So","key":"2798","mappings":{"default":{"default":"flèche grasse sud est"}}},{"category":"So","key":"2799","mappings":{"default":{"default":"flèche grasse vers la droite grasse"}}},{"category":"So","key":"279A","mappings":{"default":{"default":"flèche grasse nord est"}}},{"category":"So","key":"279B","mappings":{"default":{"default":"flèche de traçage vers la droite"}}},{"category":"So","key":"279C","mappings":{"default":{"default":"flèche grasse à pointe arrondie vers la droite"}}},{"category":"So","key":"279D","mappings":{"default":{"default":"flèche à pointe en triangle vers la droite"}}},{"category":"So","key":"279E","mappings":{"default":{"default":"flèche grasse à pointe en triangle vers la droite"}}},{"category":"So","key":"279F","mappings":{"default":{"default":"flèche avec pointillés à pointe en triangle vers la droite"}}},{"category":"So","key":"27A0","mappings":{"default":{"default":"flèche grasse avec pointillés à pointe en triangle vers la droite"}}},{"category":"So","key":"27A1","mappings":{"default":{"default":"flèche noire vers la droite"}}},{"category":"So","key":"27A2","mappings":{"default":{"default":"pointe de flèche vers la droite en trompe l'œil éclairée par le haut"}}},{"category":"So","key":"27A3","mappings":{"default":{"default":"pointe de flèche vers la droite en trompe l'œil éclairée par le bas"}}},{"category":"So","key":"27A4","mappings":{"default":{"default":"pointe de flèche noire vers la droite"}}},{"category":"So","key":"27A5","mappings":{"default":{"default":"flèche noire grasse courbée vers le bas et vers la droite"}}},{"category":"So","key":"27A6","mappings":{"default":{"default":"flèche noire courbée vers le haut et vers la droite"}}},{"category":"So","key":"27A7","mappings":{"default":{"default":"flèche noire trapue vers la droite"}}},{"category":"So","key":"27A8","mappings":{"default":{"default":"flèche noire grasse à pointe concave vers la droite"}}},{"category":"So","key":"27A9","mappings":{"default":{"default":"flèche blanche vers la droite ombrée à l'avant"}}},{"category":"So","key":"27AA","mappings":{"default":{"default":"flèche blanche vers la droite ombrée à l'arrière"}}},{"category":"So","key":"27AB","mappings":{"default":{"default":"flèche blanche vers la droite penchée vers l'arrière et ombrée"}}},{"category":"So","key":"27AC","mappings":{"default":{"default":"flèche blanche vers la droite penchée vers l'avant et ombrée"}}},{"category":"So","key":"27AD","mappings":{"default":{"default":"flèche blanche grasse vers la droite à ombre inférieure droite"}}},{"category":"So","key":"27AE","mappings":{"default":{"default":"flèche blanche grasse vers la droite à ombre supérieure droite"}}},{"category":"So","key":"27AF","mappings":{"default":{"default":"flèche encochée blanche vers la droite ombrée à l'avant et par dessous"}}},{"category":"So","key":"27B1","mappings":{"default":{"default":"flèche encochée blanche vers la droite ombrée à l'avant et par dessus"}}},{"category":"So","key":"27B2","mappings":{"default":{"default":"flèche blanche grasse vers la droite à contour circulaire"}}},{"category":"So","key":"27B3","mappings":{"default":{"default":"flèche empennée blanche vers la droite"}}},{"category":"So","key":"27B4","mappings":{"default":{"default":"flèche empennée noir sud est"}}},{"category":"So","key":"27B5","mappings":{"default":{"default":"flèche empennée noir vers la droite"}}},{"category":"So","key":"27B6","mappings":{"default":{"default":"flèche empennée noir nord est"}}},{"category":"So","key":"27B7","mappings":{"default":{"default":"flèche empennée gras noire sud est"}}},{"category":"So","key":"27B8","mappings":{"default":{"default":"flèche empennée gras noire vers la droite"}}},{"category":"So","key":"27B9","mappings":{"default":{"default":"flèche empennée gras noire nord est"}}},{"category":"So","key":"27BA","mappings":{"default":{"default":"flèche vers la droite à pointe larmée"}}},{"category":"So","key":"27BB","mappings":{"default":{"default":"flèche vers la droite à hampe larmée"}}},{"category":"So","key":"27BC","mappings":{"default":{"default":"flèche vers la droite à queue en forme de coin"}}},{"category":"So","key":"27BD","mappings":{"default":{"default":"flèche grasse vers la droite à queue en forme de coin"}}},{"category":"So","key":"27BE","mappings":{"default":{"default":"flèche vers la droite à contour ouvert"}}},{"category":"Sm","key":"27F0","mappings":{"default":{"default":"quadruple flèche vers le haut"}}},{"category":"Sm","key":"27F1","mappings":{"default":{"default":"quadruple flèche vers le bas"}}},{"category":"Sm","key":"27F2","mappings":{"default":{"default":"flèche sens antihoraire entrouverte"}}},{"category":"Sm","key":"27F3","mappings":{"default":{"default":"flèche sens horaire entrouverte"}}},{"category":"Sm","key":"27F4","mappings":{"default":{"default":"flèche vers la droite à signe plus cerclé"}}},{"key":"27F5","mappings":{"default":{"default":"longue flèche gauche"}},"category":"Sm"},{"key":"27F6","mappings":{"default":{"default":"longue flèche droite"}},"category":"Sm"},{"key":"27F7","mappings":{"default":{"default":"longue flèche bilatérale"}},"category":"Sm"},{"key":"27F8","mappings":{"default":{"default":"longue double flèche gauche"}},"category":"Sm"},{"key":"27F9","mappings":{"default":{"default":"longue double flèche droite"}},"category":"Sm"},{"key":"27FA","mappings":{"default":{"default":"longue double flèche bilatérale"}},"category":"Sm"},{"category":"Sm","key":"27FB","mappings":{"default":{"default":"longue flèche d'un taquet vers la gauche"}}},{"key":"27FC","mappings":{"default":{"default":"longue flèche d'un taquet droite"}},"category":"Sm"},{"category":"Sm","key":"27FD","mappings":{"default":{"default":"longue double flèche d'un taquet vers la gauche"}}},{"category":"Sm","key":"27FE","mappings":{"default":{"default":"longue double flèche d'un taquet vers la droite"}}},{"key":"27FF","mappings":{"default":{"default":"longue flèche en tire bouchon droite"}},"category":"Sm"},{"category":"Sm","key":"2900","mappings":{"default":{"default":"flèche à deux pointes vers la droite barrée verticalement"}}},{"category":"Sm","key":"2901","mappings":{"default":{"default":"flèche à deux pointes vers la droite barrée deux fois verticalement"}}},{"category":"Sm","key":"2902","mappings":{"default":{"default":"double flèche vers la gauche barrée verticalement"}}},{"category":"Sm","key":"2903","mappings":{"default":{"default":"double flèche vers la droite barrée verticalement"}}},{"category":"Sm","key":"2904","mappings":{"default":{"default":"flèche bilatérale double barrée verticalement"}}},{"key":"2905","mappings":{"default":{"default":"flèche à deux têtes d'un taquet droite"}},"category":"Sm"},{"category":"Sm","key":"2906","mappings":{"default":{"default":"double flèche d'un taquet vers la gauche"}}},{"category":"Sm","key":"2907","mappings":{"default":{"default":"double flèche d'un taquet vers la droite"}}},{"category":"Sm","key":"2908","mappings":{"default":{"default":"flèche vers le bas barrée horizontalement"}}},{"category":"Sm","key":"2909","mappings":{"default":{"default":"flèche vers le haut barrée horizontalement"}}},{"category":"Sm","key":"290A","mappings":{"default":{"default":"triple flèche vers le haut"}}},{"category":"Sm","key":"290B","mappings":{"default":{"default":"triple flèche vers le bas"}}},{"key":"290C","mappings":{"default":{"default":"flèche à deux traits gauche"}},"category":"Sm"},{"key":"290D","mappings":{"default":{"default":"flèche à deux traits droite"}},"category":"Sm"},{"key":"290E","mappings":{"default":{"default":"flèche à trois traits gauche"}},"category":"Sm"},{"key":"290F","mappings":{"default":{"default":"flèche à trois traits droite"}},"category":"Sm"},{"key":"2910","mappings":{"default":{"default":"flèche à trois traits et à deux têtes droite"}},"category":"Sm"},{"key":"2911","mappings":{"default":{"default":"flèche à fût pointillé droite"}},"category":"Sm"},{"key":"2912","mappings":{"default":{"default":"flèche jusqu'à taquet vers le haut"}},"category":"Sm"},{"key":"2913","mappings":{"default":{"default":"flèche jusqu'à taquet vers le bas"}},"category":"Sm"},{"category":"Sm","key":"2914","mappings":{"default":{"default":"flèche empennée vers la droite barrée verticalement"}}},{"category":"Sm","key":"2915","mappings":{"default":{"default":"flèche empennée vers la droite barrée deux fois verticalement"}}},{"key":"2916","mappings":{"default":{"default":"flèche empennée à deux têtes droite"}},"category":"Sm"},{"category":"Sm","key":"2917","mappings":{"default":{"default":"flèche empennée à deux têtes vers la droite barrée verticalement"}}},{"category":"Sm","key":"2918","mappings":{"default":{"default":"flèche empennée à deux têtes vers la droite barrée deux fois verticalement"}}},{"key":"2919","mappings":{"default":{"default":"empenne gauche"}},"category":"Sm"},{"category":"Sm","key":"291A","mappings":{"default":{"default":"empenne vers la droite"}}},{"key":"291B","mappings":{"default":{"default":"double empenne gauche"}},"category":"Sm"},{"key":"291C","mappings":{"default":{"default":"double empenne droite"}},"category":"Sm"},{"key":"291D","mappings":{"default":{"default":"flèche vers un losange noir à gauche"}},"category":"Sm"},{"key":"291E","mappings":{"default":{"default":"flèche vers un losange noir à droite"}},"category":"Sm"},{"key":"291F","mappings":{"default":{"default":"flèche d'un taquet vers un losange noir à gauche"}},"category":"Sm"},{"key":"2920","mappings":{"default":{"default":"flèche d'un taquet vers un losange noir à droite"}},"category":"Sm"},{"category":"Sm","key":"2921","mappings":{"default":{"default":"flèche nord ouest et sud est"}}},{"category":"Sm","key":"2922","mappings":{"default":{"default":"flèche nord est et sud ouest"}}},{"key":"2923","mappings":{"default":{"default":"flèche nord ouest à crochet"}},"category":"Sm"},{"key":"2924","mappings":{"default":{"default":"flèche nord est à crochet"}},"category":"Sm"},{"key":"2925","mappings":{"default":{"default":"flèche sud est à crochet"}},"category":"Sm"},{"key":"2926","mappings":{"default":{"default":"flèche sud ouest à crochet"}},"category":"Sm"},{"key":"2927","mappings":{"default":{"default":"flèches nord ouest et nord est"}},"category":"Sm"},{"key":"2928","mappings":{"default":{"default":"flèches nord est et sud est"}},"category":"Sm"},{"key":"2929","mappings":{"default":{"default":"flèches sud est et sud ouest"}},"category":"Sm"},{"key":"292A","mappings":{"default":{"default":"flèches sud ouest et nord ouest"}},"category":"Sm"},{"category":"Sm","key":"292D","mappings":{"default":{"default":"flèche sud est sur flèche nord est"}}},{"category":"Sm","key":"292E","mappings":{"default":{"default":"flèche nord est sur flèche sud est"}}},{"category":"Sm","key":"292F","mappings":{"default":{"default":"diagonale descendante sur flèche nord est"}}},{"category":"Sm","key":"2930","mappings":{"default":{"default":"diagonale montante sur flèche sud est"}}},{"category":"Sm","key":"2931","mappings":{"default":{"default":"flèche nord est sur flèche nord ouest"}}},{"category":"Sm","key":"2932","mappings":{"default":{"default":"flèche nord ouest sur flèche nord est"}}},{"key":"2933","mappings":{"default":{"default":"flèche bossue droite"}},"category":"Sm"},{"category":"Sm","key":"2934","mappings":{"default":{"default":"flèche courbe vers la droite puis le haut"}}},{"key":"2935","mappings":{"default":{"default":"flèche courbe vers la droite puis le bas"}},"category":"Sm"},{"key":"2936","mappings":{"default":{"default":"flèche courbe vers le bas puis la gauche"}},"category":"Sm"},{"key":"2937","mappings":{"default":{"default":"flèche courbe vers le bas puis la droite"}},"category":"Sm"},{"key":"2938","mappings":{"default":{"default":"côté droit d'arc fléché sens horaire"}},"category":"Sm"},{"key":"2939","mappings":{"default":{"default":"côté gauche d'arc fléché sens antihoraire"}},"category":"Sm"},{"category":"Sm","key":"293A","mappings":{"default":{"default":"arc supérieur fléché sens antihoraire"}}},{"category":"Sm","key":"293B","mappings":{"default":{"default":"arc inférieur fléché sens antihoraire"}}},{"key":"293C","mappings":{"default":{"default":"arc fléché sens horaire et signe moins souscrit"}},"category":"Sm"},{"key":"293D","mappings":{"default":{"default":"arc fléché sens antihoraire et signe plus souscrit"}},"category":"Sm"},{"category":"Sm","key":"293E","mappings":{"default":{"default":"demi cercle fléché inférieur droit sens horaire"}}},{"category":"Sm","key":"293F","mappings":{"default":{"default":"demi cercle fléché inférieur gauche sens antihoraire"}}},{"category":"Sm","key":"2940","mappings":{"default":{"default":"cercle fléché sens antihoraire"}}},{"category":"Sm","key":"2941","mappings":{"default":{"default":"cercle fléché sens horaire"}}},{"category":"Sm","key":"2942","mappings":{"default":{"default":"flèche vers la droite surmontant fléchette vers la gauche"}}},{"category":"Sm","key":"2943","mappings":{"default":{"default":"flèche vers la gauche surmontant fléchette vers la droite"}}},{"category":"Sm","key":"2944","mappings":{"default":{"default":"fléchette vers la droite surmontant flèche vers la gauche"}}},{"key":"2945","mappings":{"default":{"default":"flèche droite surmontant signe moins"}},"category":"Sm"},{"category":"Sm","key":"2946","mappings":{"default":{"default":"flèche vers la gauche surmontant signe plus"}}},{"category":"Sm","key":"2947","mappings":{"default":{"default":"flèche vers la droite au travers un x"}}},{"key":"2948","mappings":{"default":{"default":"petit cercle traversé d'une flèche bilatérale"}},"category":"Sm"},{"key":"2949","mappings":{"default":{"default":"petit cercle surmonté d'une flèche montante à deux têtes"}},"category":"Sm"},{"key":"2970","mappings":{"default":{"default":"flèche en épingle à cheveu droite"}},"category":"Sm"},{"key":"2971","mappings":{"default":{"default":"flèche droite surmontée d'un égal"}},"category":"Sm"},{"key":"2972","mappings":{"default":{"default":"flèche droite surmontée d'un tilde"}},"category":"Sm"},{"key":"2973","mappings":{"default":{"default":"tilde surmonté d'une flèche gauche"}},"category":"Sm"},{"key":"2974","mappings":{"default":{"default":"tilde surmonté d'une flèche droite"}},"category":"Sm"},{"key":"2975","mappings":{"default":{"default":"presque égal à surmonté d'une flèche droite"}},"category":"Sm"},{"key":"2976","mappings":{"default":{"default":"inférieur à surmonté d'une flèche gauche"}},"category":"Sm"},{"category":"Sm","key":"2977","mappings":{"default":{"default":"flèche vers la gauche à travers un inférieur à"}}},{"key":"2978","mappings":{"default":{"default":"flèche droite surmontée d'un supérieur à"}},"category":"Sm"},{"key":"2979","mappings":{"default":{"default":"flèche droite surmontée d'un sous ensemble de"}},"category":"Sm"},{"category":"Sm","key":"297A","mappings":{"default":{"default":"flèche vers la gauche au travers d'un sous ensemble de"}}},{"key":"297B","mappings":{"default":{"default":"flèche gauche surmontée d'un sur ensemble de"}},"category":"Sm"},{"key":"29B3","mappings":{"default":{"default":"ensemble vide flèche droite en chef"}},"category":"Sm"},{"key":"29B4","mappings":{"default":{"default":"ensemble vide flèche gauche en chef"}},"category":"Sm"},{"category":"Sm","key":"29BD","mappings":{"default":{"default":"cercle traversé d'une flèche montante"}}},{"category":"Sm","key":"29EA","mappings":{"default":{"default":"losange noir à flèche vers le bas"}}},{"category":"Sm","key":"29EC","mappings":{"default":{"default":"cercle blanc à flèche vers le bas"}}},{"category":"Sm","key":"29ED","mappings":{"default":{"default":"cercle noir à flèche vers le bas"}}},{"key":"2A17","mappings":{"default":{"default":"intégrale à crosse fléchée gauche"}},"category":"Sm"},{"category":"So","key":"2B00","mappings":{"default":{"default":"flèche blanche nord est"}}},{"category":"So","key":"2B01","mappings":{"default":{"default":"flèche blanche nord ouest"}}},{"category":"So","key":"2B02","mappings":{"default":{"default":"flèche blanche sud est"}}},{"category":"So","key":"2B03","mappings":{"default":{"default":"flèche blanche sud ouest"}}},{"category":"So","key":"2B04","mappings":{"default":{"default":"flèche blanche bilatérale"}}},{"category":"So","key":"2B05","mappings":{"default":{"default":"flèche noire vers la gauche"}}},{"category":"So","key":"2B06","mappings":{"default":{"default":"flèche noire vers le haut"}}},{"category":"So","key":"2B07","mappings":{"default":{"default":"flèche noire vers le bas"}}},{"category":"So","key":"2B08","mappings":{"default":{"default":"flèche noire nord est"}}},{"category":"So","key":"2B09","mappings":{"default":{"default":"flèche noire nord ouest"}}},{"category":"So","key":"2B0A","mappings":{"default":{"default":"flèche noire sud est"}}},{"category":"So","key":"2B0B","mappings":{"default":{"default":"flèche noire sud ouest"}}},{"category":"So","key":"2B0C","mappings":{"default":{"default":"flèche noire bilatérale"}}},{"category":"So","key":"2B0D","mappings":{"default":{"default":"flèche noire haut et bas"}}},{"category":"So","key":"2B0E","mappings":{"default":{"default":"flèche vers la droite à pointe pliée vers le bas"}}},{"category":"So","key":"2B0F","mappings":{"default":{"default":"flèche vers la droite à pointe pliée vers le haut"}}},{"category":"So","key":"2B10","mappings":{"default":{"default":"flèche vers la gauche à pointe pliée vers le bas"}}},{"category":"So","key":"2B11","mappings":{"default":{"default":"flèche vers la gauche à pointe pliée vers le haut"}}},{"category":"Sm","key":"2B30","mappings":{"default":{"default":"flèche vers la gauche à petit cercle"}}},{"category":"Sm","key":"2B31","mappings":{"default":{"default":"trois flèches vers la gauche"}}},{"category":"Sm","key":"2B32","mappings":{"default":{"default":"flèche vers la gauche à signe plus cerclé"}}},{"category":"Sm","key":"2B33","mappings":{"default":{"default":"longue flèche vers la gauche en tire bouchon"}}},{"category":"Sm","key":"2B34","mappings":{"default":{"default":"flèche à deux pointes vers la gauche barrée verticalement"}}},{"category":"Sm","key":"2B35","mappings":{"default":{"default":"flèche à deux pointes vers la gauche barrée deux fois verticalement"}}},{"category":"Sm","key":"2B36","mappings":{"default":{"default":"flèche à deux têtes d'un taquet vers la gauche"}}},{"category":"Sm","key":"2B37","mappings":{"default":{"default":"flèche à trois traits et à deux têtes vers la gauche"}}},{"category":"Sm","key":"2B38","mappings":{"default":{"default":"flèche vers la gauche à fût pointillé"}}},{"category":"Sm","key":"2B39","mappings":{"default":{"default":"flèche empennée vers la gauche barrée verticalement"}}},{"category":"Sm","key":"2B3A","mappings":{"default":{"default":"flèche empennée vers la gauche barrée deux fois verticalement"}}},{"category":"Sm","key":"2B3B","mappings":{"default":{"default":"flèche empennée à deux têtes vers la gauche"}}},{"category":"Sm","key":"2B3C","mappings":{"default":{"default":"flèche empennée à deux têtes vers la gauche barrée verticalement"}}},{"category":"Sm","key":"2B3D","mappings":{"default":{"default":"flèche empennée à deux têtes vers la gauche barrée deux fois verticalement"}}},{"category":"Sm","key":"2B3E","mappings":{"default":{"default":"flèche vers la gauche au travers un x"}}},{"category":"Sm","key":"2B3F","mappings":{"default":{"default":"flèche vers la gauche bossue"}}},{"category":"Sm","key":"2B40","mappings":{"default":{"default":"flèche vers la gauche surmontée d'un égal"}}},{"category":"Sm","key":"2B41","mappings":{"default":{"default":"flèche vers la gauche surmontée d'un tilde"}}},{"category":"Sm","key":"2B42","mappings":{"default":{"default":"presque égal à réfléchi surmonté d'une flèche vers la gauche"}}},{"category":"Sm","key":"2B43","mappings":{"default":{"default":"flèche vers la droite à travers un inférieur à"}}},{"category":"Sm","key":"2B44","mappings":{"default":{"default":"flèche vers la droite au travers d'un sous ensemble de"}}},{"category":"So","key":"2B45","mappings":{"default":{"default":"quadruple flèche vers la gauche"}}},{"category":"So","key":"2B46","mappings":{"default":{"default":"quadruple flèche vers la droite"}}},{"category":"Sm","key":"2B47","mappings":{"default":{"default":"flèche vers la droite surmontée d'un opérateur tilde réfléchi"}}},{"category":"Sm","key":"2B48","mappings":{"default":{"default":"presque égal à réfléchi surmonté d'une flèche vers la droite"}}},{"category":"Sm","key":"2B49","mappings":{"default":{"default":"flèche vers la gauche surmontée de l'opérateur tilde"}}},{"category":"Sm","key":"2B4A","mappings":{"default":{"default":"flèche vers la gauche par dessus presque égal à"}}},{"category":"Sm","key":"2B4B","mappings":{"default":{"default":"tilde réfléchi surmonté d'une flèche vers la gauche"}}},{"category":"Sm","key":"2B4C","mappings":{"default":{"default":"ilde surmonté d'une flèche vers la droite"}}},{"category":"Sm","key":"FFE9","mappings":{"default":{"default":"flèche vers la gauche demi chasse"}}},{"category":"Sm","key":"FFEA","mappings":{"default":{"default":"flèche vers le haut demi chasse"}}},{"category":"Sm","key":"FFEB","mappings":{"default":{"default":"flèche vers la droite demi chasse"}}},{"category":"Sm","key":"FFEC","mappings":{"default":{"default":"flèche vers le bas demi chasse"}}}]
,
"fr/symbols/math_characters.js": 
[{"locale":"fr"},{"key":"2113","mappings":{"default":{"default":"l minuscule en script"}},"category":"Ll"},{"key":"2118","mappings":{"default":{"default":"fonction elliptique de weierstrass"}},"category":"Sm"},{"category":"Ll","key":"213C","mappings":{"default":{"default":"pi ajouré"}}},{"category":"Ll","key":"213D","mappings":{"default":{"default":"gamma ajouré"}}},{"category":"Lu","key":"213E","mappings":{"default":{"default":"Gamma majuscule ajouré"}}},{"category":"Lu","key":"213F","mappings":{"default":{"default":"Pi majuscule ajouré"}}},{"category":"Sm","key":"2140","mappings":{"default":{"default":"sommation de la famille ajouré"}}},{"key":"2145","mappings":{"default":{"default":"D majuscule"}},"category":"Lu"},{"key":"2146","mappings":{"default":{"default":"d ajouré en italique"}},"category":"Ll"},{"key":"2147","mappings":{"default":{"default":"e ajouré en italique"}},"category":"Ll"},{"key":"2148","mappings":{"default":{"default":"i ajouré en italique"}},"category":"Ll"},{"category":"Ll","key":"2149","mappings":{"default":{"default":"j ajouré en italique"}}},{"key":"1D6A4","mappings":{"default":{"default":"dotless i"}},"category":"Ll"},{"key":"1D6A5","mappings":{"default":{"default":"dotless j"}},"category":"Ll"}]
,
"fr/symbols/math_delimiters.js": 
[{"locale":"fr"},{"key":"0028","mappings":{"default":{"default":"parenthèse gauche","alternative":"parenthèse ouvrante"}},"category":"Ps"},{"key":"0029","mappings":{"default":{"default":"parenthèse droite","alternative":"parenthèse fermante"}},"category":"Pe"},{"key":"005B","mappings":{"default":{"default":"crochet gauche","alternative":"crochet ouvrant"}},"category":"Ps"},{"key":"005D","mappings":{"default":{"default":"crochet droit","alternative":"crochet fermant"}},"category":"Pe"},{"key":"007B","mappings":{"default":{"default":"accolade gauche","alternative":"accolade ouvrante"}},"category":"Ps"},{"key":"007D","mappings":{"default":{"default":"accolade droite","alternative":"accolade fermante"}},"category":"Pe"},{"category":"Ps","key":"2045","mappings":{"default":{"default":"crochet gauche avec pique"}}},{"category":"Pe","key":"2046","mappings":{"default":{"default":"crochet droit avec pique"}}},{"key":"2308","mappings":{"default":{"default":"plafond à gauche"}},"category":"Sm"},{"key":"2309","mappings":{"default":{"default":"plafond à droite"}},"category":"Sm"},{"key":"230A","mappings":{"default":{"default":"plancher à gauche"}},"category":"Sm"},{"key":"230B","mappings":{"default":{"default":"plancher à droite"}},"category":"Sm"},{"key":"230C","mappings":{"default":{"default":"repère sud est"}},"category":"So"},{"key":"230D","mappings":{"default":{"default":"repère sud ouest"}},"category":"So"},{"key":"230E","mappings":{"default":{"default":"repère nord est"}},"category":"So"},{"key":"230F","mappings":{"default":{"default":"repère nord ouest"}},"category":"So"},{"key":"231C","mappings":{"default":{"default":"coin nord ouest"}},"category":"So"},{"key":"231D","mappings":{"default":{"default":"coin nord est"}},"category":"So"},{"key":"231E","mappings":{"default":{"default":"coin sud ouest"}},"category":"So"},{"key":"231F","mappings":{"default":{"default":"coin sud est"}},"category":"So"},{"key":"2320","mappings":{"default":{"default":"moitié supérieure d'intégrale"}},"category":"Sm"},{"key":"2321","mappings":{"default":{"default":"moitié inférieure d'intégrale"}},"category":"Sm"},{"key":"2329","mappings":{"default":{"default":"chevron gauche"}},"category":"Ps"},{"key":"232A","mappings":{"default":{"default":"chevron droite"}},"category":"Pe"},{"category":"Sm","key":"239B","mappings":{"default":{"default":"arc supérieur de parenthèse gauche"}}},{"category":"Sm","key":"239C","mappings":{"default":{"default":"rallonge de parenthèse gauche"}}},{"category":"Sm","key":"239D","mappings":{"default":{"default":"arc inférieur de parenthèse gauche"}}},{"category":"Sm","key":"239E","mappings":{"default":{"default":"arc supérieur de parenthèse droite"}}},{"category":"Sm","key":"239F","mappings":{"default":{"default":"rallonge de parenthèse droite"}}},{"category":"Sm","key":"23A0","mappings":{"default":{"default":"arc inférieur de parenthèse droite"}}},{"category":"Sm","key":"23A1","mappings":{"default":{"default":"coin supérieur de crochet gauche"}}},{"category":"Sm","key":"23A2","mappings":{"default":{"default":"rallonge de crochet gauche"}}},{"category":"Sm","key":"23A3","mappings":{"default":{"default":"coin inférieur de crochet gauche"}}},{"category":"Sm","key":"23A4","mappings":{"default":{"default":"coin supérieur de crochet droit"}}},{"category":"Sm","key":"23A5","mappings":{"default":{"default":"rallonge de crochet droit"}}},{"category":"Sm","key":"23A6","mappings":{"default":{"default":"coin inférieur de crochet droit"}}},{"category":"Sm","key":"23A7","mappings":{"default":{"default":"arc supérieur d'accolade gauche"}}},{"category":"Sm","key":"23A8","mappings":{"default":{"default":"milieu d'accolade gauche"}}},{"category":"Sm","key":"23A9","mappings":{"default":{"default":"arc inférieur d'accolade gauche"}}},{"category":"Sm","key":"23AA","mappings":{"default":{"default":"rallonge d'accolade"}}},{"category":"Sm","key":"23AB","mappings":{"default":{"default":"arc supérieur d'accolade droite"}}},{"category":"Sm","key":"23AC","mappings":{"default":{"default":"milieu d'accolade droite"}}},{"category":"Sm","key":"23AD","mappings":{"default":{"default":"arc inférieur d'accolade droite"}}},{"category":"Sm","key":"23AE","mappings":{"default":{"default":"rallonge d'intégrale"}}},{"category":"Sm","key":"23AF","mappings":{"default":{"default":"rallonge de ligne horizontale"}}},{"key":"23B0","mappings":{"default":{"default":"moitié supérieure gauche ou inférieure droite d'accolade"}},"category":"Sm"},{"key":"23B1","mappings":{"default":{"default":"moitié supérieure droite ou inférieure gauche d'accolade"}},"category":"Sm"},{"category":"Sm","key":"23B2","mappings":{"default":{"default":"haut du signe de somme"}}},{"category":"Sm","key":"23B3","mappings":{"default":{"default":"bas du signe de somme"}}},{"key":"23B4","mappings":{"default":{"default":"crochet vertical supérieur"}},"category":"So"},{"key":"23B5","mappings":{"default":{"default":"crochet vertical inférieur"}},"category":"So"},{"category":"So","key":"23B6","mappings":{"default":{"default":"crochet verticaux en défilé"}}},{"category":"So","key":"23B7","mappings":{"default":{"default":"bas du radical"}}},{"category":"So","key":"23B8","mappings":{"default":{"default":"filet vertical gauche"}}},{"category":"So","key":"23B9","mappings":{"default":{"default":"filet vertical droit"}}},{"key":"23DC","mappings":{"default":{"default":"parenthèse supérieure"}},"category":"Sm"},{"key":"23DD","mappings":{"default":{"default":"parenthèse inférieure"}},"category":"Sm"},{"key":"23DE","mappings":{"default":{"default":"accolade supérieure"}},"category":"Sm"},{"key":"23DF","mappings":{"default":{"default":"accolade inférieure"}},"category":"Sm"},{"key":"23E0","mappings":{"default":{"default":"crochet en écaille supérieur"}},"category":"Sm"},{"key":"23E1","mappings":{"default":{"default":"crochet en écaille inférieur"}},"category":"Sm"},{"category":"Ps","key":"2768","mappings":{"default":{"default":"parenthèse de fantaisie gauche demi grasse"}}},{"category":"Pe","key":"2769","mappings":{"default":{"default":"parenthèse de fantaisie droite demi grasse"}}},{"category":"Ps","key":"276A","mappings":{"default":{"default":"parenthèse de fantaisie gauche demi grasse aplatie"}}},{"category":"Pe","key":"276B","mappings":{"default":{"default":"parenthèse de fantaisie droite demi grasse aplatie"}}},{"category":"Ps","key":"276C","mappings":{"default":{"default":"chevron de fantaisie vers la gauche demi gras"}}},{"category":"Pe","key":"276D","mappings":{"default":{"default":"chevron de fantaisie vers la droite demi gras"}}},{"category":"Ps","key":"276E","mappings":{"default":{"default":"guillemet de fantaisie vers la gauche gras"}}},{"category":"Pe","key":"276F","mappings":{"default":{"default":"guillemet de fantaisie vers la droite gras"}}},{"category":"Ps","key":"2770","mappings":{"default":{"default":"crochet de fantaisie vers la gauche gras"}}},{"category":"Pe","key":"2771","mappings":{"default":{"default":"crochet de fantaisie vers la droite gras"}}},{"category":"Ps","key":"2772","mappings":{"default":{"default":"crochet de fantaisie gauche maigre en écaille"}}},{"category":"Pe","key":"2773","mappings":{"default":{"default":"crochet de fantaisie droit maigre en écaille"}}},{"category":"Ps","key":"2774","mappings":{"default":{"default":"accolade de fantaisie gauche moyenne"}}},{"category":"Pe","key":"2775","mappings":{"default":{"default":"accolade de fantaisie droite moyenne"}}},{"key":"27C5","mappings":{"default":{"default":"délimiteur de sac en s gauche"}},"category":"Ps"},{"key":"27C6","mappings":{"default":{"default":"délimiteur de sac en s droite"}},"category":"Pe"},{"key":"27E6","mappings":{"default":{"default":"crochet blanc gauche"}},"category":"Ps"},{"key":"27E7","mappings":{"default":{"default":"crochet blanc droit"}},"category":"Pe"},{"key":"27E8","mappings":{"default":{"default":"chevron mathématique gauche"}},"category":"Ps"},{"key":"27E9","mappings":{"default":{"default":"chevron droit"}},"category":"Pe"},{"key":"27EA","mappings":{"default":{"default":"double chevron gauche"}},"category":"Ps"},{"key":"27EB","mappings":{"default":{"default":"double chevron droit"}},"category":"Pe"},{"key":"27EC","mappings":{"default":{"default":"crochet gauche en écaille blanche"}},"category":"Ps"},{"key":"27ED","mappings":{"default":{"default":"crochet droit en écaille blanche"}},"category":"Pe"},{"key":"27EE","mappings":{"default":{"default":"parenthèse gauche aplatie"}},"category":"Ps"},{"key":"27EF","mappings":{"default":{"default":"parenthèse droite aplatie"}},"category":"Pe"},{"category":"Ps","key":"2983","mappings":{"default":{"default":"accolade gauche ajourée"}}},{"category":"Pe","key":"2984","mappings":{"default":{"default":"accolade droite ajourée"}}},{"key":"2985","mappings":{"default":{"default":"parenthèse gauche ajourée"}},"category":"Ps"},{"key":"2986","mappings":{"default":{"default":"parenthèse droite ajourée"}},"category":"Pe"},{"category":"Ps","key":"2987","mappings":{"default":{"default":"parenthèse image de gauche en notation z"}}},{"category":"Pe","key":"2988","mappings":{"default":{"default":"parenthèse image de droite en notation z"}}},{"key":"2989","mappings":{"default":{"default":"z notation left binding bracket"}},"category":"Ps"},{"key":"298A","mappings":{"default":{"default":"z notation right binding bracket"}},"category":"Pe"},{"key":"298B","mappings":{"default":{"default":"crochet gauche avec barre souscrite"}},"category":"Ps"},{"key":"298C","mappings":{"default":{"default":"crochet droit avec barre souscrite"}},"category":"Pe"},{"key":"298D","mappings":{"default":{"default":"crochet gauche avec trait dans le coin supérieur"}},"category":"Ps"},{"key":"298E","mappings":{"default":{"default":"crochet droit avec trait dans le coin inférieur"}},"category":"Pe"},{"key":"298F","mappings":{"default":{"default":"crochet gauche avec trait dans le coin inférieur"}},"category":"Ps"},{"key":"2990","mappings":{"default":{"default":"crochet droit avec trait dans le coin supérieur"}},"category":"Pe"},{"key":"2991","mappings":{"default":{"default":"chevron gauche pointé"}},"category":"Ps"},{"key":"2992","mappings":{"default":{"default":"chevron droit pointé"}},"category":"Pe"},{"key":"2993","mappings":{"default":{"default":"parenthèse arc gauche et inférieur à"}},"category":"Ps"},{"key":"2994","mappings":{"default":{"default":"parenthèse arc droite et supérieur à"}},"category":"Pe"},{"key":"2995","mappings":{"default":{"default":"parenthèse double arc droite et supérieur à"}},"category":"Ps"},{"key":"2996","mappings":{"default":{"default":"parenthèse double arc gauche et inférieur à"}},"category":"Pe"},{"category":"Ps","key":"2997","mappings":{"default":{"default":"crochet noir gauche en écaille"}}},{"category":"Pe","key":"2998","mappings":{"default":{"default":"crochet noir droite en écaille"}}},{"category":"Ps","key":"29D8","mappings":{"default":{"default":"clôture dentelée gauche"}}},{"category":"Pe","key":"29D9","mappings":{"default":{"default":"clôture dentelée droite"}}},{"key":"29DA","mappings":{"default":{"default":"double clôture dentelée gauche"}},"category":"Ps"},{"key":"29DB","mappings":{"default":{"default":"right double wiggly fence"}},"category":"Pe"},{"category":"Ps","key":"29FC","mappings":{"default":{"default":"chevron vers la gauche courbé"}}},{"category":"Pe","key":"29FD","mappings":{"default":{"default":"chevron vers la droite courbé"}}},{"category":"Ps","key":"2E22","mappings":{"default":{"default":"anglet supérieur gauche"}}},{"category":"Pe","key":"2E23","mappings":{"default":{"default":"anglet supérieur droit"}}},{"category":"Ps","key":"2E24","mappings":{"default":{"default":"anglet inférieur gauche"}}},{"category":"Pe","key":"2E25","mappings":{"default":{"default":"anglet inférieur droit"}}},{"category":"Ps","key":"2E26","mappings":{"default":{"default":"crampillon couché gauche"}}},{"category":"Pe","key":"2E27","mappings":{"default":{"default":"crampillon couché droit"}}},{"category":"Ps","key":"2E28","mappings":{"default":{"default":"double parenthèse gauche"}}},{"category":"Pe","key":"2E29","mappings":{"default":{"default":"double parenthèse droite"}}},{"category":"Ps","key":"3008","mappings":{"default":{"default":"chevron gauche"}}},{"category":"Pe","key":"3009","mappings":{"default":{"default":"chevron droit"}}},{"key":"300A","mappings":{"default":{"default":"double chevron gauche"}},"category":"Ps"},{"key":"300B","mappings":{"default":{"default":"double chevron droit"}},"category":"Pe"},{"category":"Ps","key":"300C","mappings":{"default":{"default":"anglet gauche"}}},{"category":"Pe","key":"300D","mappings":{"default":{"default":"anglet droit"}}},{"category":"Ps","key":"300E","mappings":{"default":{"default":"anglet ajouré gauche"}}},{"category":"Pe","key":"300F","mappings":{"default":{"default":"anglet ajouré droit"}}},{"category":"Ps","key":"3010","mappings":{"default":{"default":"crochet noir lenticulaire gauche"}}},{"category":"Pe","key":"3011","mappings":{"default":{"default":"crochet noir lenticulaire droit"}}},{"key":"3014","mappings":{"default":{"default":"crochet gauche en écaille"}},"category":"Ps"},{"key":"3015","mappings":{"default":{"default":"crochet droit en écaille"}},"category":"Pe"},{"category":"Ps","key":"3016","mappings":{"default":{"default":"crochet blanc lenticulaire gauche"}}},{"category":"Pe","key":"3017","mappings":{"default":{"default":"crochet blanc lenticulaire droit"}}},{"category":"Ps","key":"3018","mappings":{"default":{"default":"crochet blanc gauche en écaille"}}},{"category":"Pe","key":"3019","mappings":{"default":{"default":"crochet blanc droit en écaille"}}},{"key":"301A","mappings":{"default":{"default":"crochet blanc gauche"}},"category":"Ps"},{"key":"301B","mappings":{"default":{"default":"crochet blanc droit"}},"category":"Pe"},{"category":"Ps","key":"301D","mappings":{"default":{"default":"guillemet double prime réfléchi"}}},{"key":"301E","mappings":{"default":{"default":"guillemet double prime"}},"category":"Pe"},{"category":"Pe","key":"301F","mappings":{"default":{"default":"guillemet double prime inférieur"}}},{"category":"Ps","key":"FD3E","mappings":{"default":{"default":"parenthèse gauche ornée"}}},{"category":"Pe","key":"FD3F","mappings":{"default":{"default":"parenthèse droite ornée"}}},{"category":"Ps","key":"FE17","mappings":{"default":{"default":"forme de présentation de crochet blanc lenticulaire gauche vertical"}}},{"category":"Pe","key":"FE18","mappings":{"default":{"default":"forme de présentation de crochet blanc lenticulaire droit vertical"}}},{"key":"FE35","mappings":{"default":{"default":"forme de présentation de parenthèse gauche verticale"}},"category":"Ps"},{"key":"FE36","mappings":{"default":{"default":"forme de présentation de parenthèse droite verticale"}},"category":"Pe"},{"key":"FE37","mappings":{"default":{"default":"forme de présentation d'accolade gauche verticale"}},"category":"Ps"},{"key":"FE38","mappings":{"default":{"default":"forme de présentation d'accolade droite verticale"}},"category":"Pe"},{"category":"Ps","key":"FE39","mappings":{"default":{"default":"forme de présentation de crochet gauche vertical en écaille"}}},{"category":"Pe","key":"FE3A","mappings":{"default":{"default":"forme de présentation de crochet droit vertical en écaille"}}},{"category":"Ps","key":"FE3B","mappings":{"default":{"default":"forme de présentation de crochet gauche lenticulaire noir vertical"}}},{"category":"Pe","key":"FE3C","mappings":{"default":{"default":"forme de présentation de crochet droit lenticulaire noir vertical"}}},{"category":"Ps","key":"FE3D","mappings":{"default":{"default":"forme de présentation de crochet double gauche vertical"}}},{"category":"Pe","key":"FE3E","mappings":{"default":{"default":"forme de présentation de crochet double droit vertical"}}},{"key":"FE3F","mappings":{"default":{"default":"over angle bracket"}},"category":"Ps"},{"key":"FE40","mappings":{"default":{"default":"under angle bracket"}},"category":"Pe"},{"category":"Ps","key":"FE41","mappings":{"default":{"default":"forme de présentation de crochet vertical gauche en coin"}}},{"category":"Pe","key":"FE42","mappings":{"default":{"default":"forme de présentation de crochet vertical droit en coin"}}},{"category":"Ps","key":"FE43","mappings":{"default":{"default":"forme de présentation de crochet blanc vertical gauche en coin"}}},{"category":"Pe","key":"FE44","mappings":{"default":{"default":"forme de présentation de crochet blanc vertical droit en coin"}}},{"category":"Ps","key":"FE47","mappings":{"default":{"default":"forme de présentation de crochet gauche vertical"}}},{"category":"Pe","key":"FE48","mappings":{"default":{"default":"forme de présentation de crochet droit vertical"}}},{"category":"Ps","key":"FE59","mappings":{"default":{"default":"parenthèse gauche minuscule"}}},{"category":"Pe","key":"FE5A","mappings":{"default":{"default":"parenthèse droite minuscule"}}},{"category":"Ps","key":"FE5B","mappings":{"default":{"default":"accolade gauche minuscule"}}},{"category":"Pe","key":"FE5C","mappings":{"default":{"default":"accolade droite minuscule"}}},{"category":"Ps","key":"FE5D","mappings":{"default":{"default":"crochet gauche en écaille minuscule"}}},{"category":"Pe","key":"FE5E","mappings":{"default":{"default":"crochet droit en écaille minuscule"}}},{"category":"Ps","key":"FF08","mappings":{"default":{"default":"parenthèse gauche pleine chasse"}}},{"category":"Pe","key":"FF09","mappings":{"default":{"default":"parenthèse droite pleine chasse"}}},{"category":"Ps","key":"FF3B","mappings":{"default":{"default":"crochet gauche pleine chasse"}}},{"category":"Pe","key":"FF3D","mappings":{"default":{"default":"crochet droit pleine chasse"}}},{"category":"Ps","key":"FF5B","mappings":{"default":{"default":"accolade gauche pleine chasse"}}},{"category":"Pe","key":"FF5D","mappings":{"default":{"default":"accolade droite pleine chasse"}}},{"category":"Ps","key":"FF5F","mappings":{"default":{"default":"parenthèse gauche ajourée pleine chasse *"}}},{"category":"Pe","key":"FF60","mappings":{"default":{"default":"parenthèse droite ajourée pleine chasse *"}}},{"category":"Ps","key":"FF62","mappings":{"default":{"default":"crochet gauche en coin demi chasse"}}},{"category":"Pe","key":"FF63","mappings":{"default":{"default":"crochet droit en coin demi chasse"}}}]
,
"fr/symbols/math_geometry.js": 
[{"locale":"fr"},{"key":"2500","mappings":{"default":{"default":"filet horizontal fin"}},"category":"So"},{"category":"So","key":"2501","mappings":{"default":{"default":"filet horizontal gras"}}},{"key":"2502","mappings":{"default":{"default":"filet vertical fin"}},"category":"So"},{"category":"So","key":"2503","mappings":{"default":{"default":"filet vertical gras"}}},{"category":"So","key":"2504","mappings":{"default":{"default":"filet brisé triple horizontal fin"}}},{"category":"So","key":"2505","mappings":{"default":{"default":"filet brisé triple horizontal gras"}}},{"category":"So","key":"2506","mappings":{"default":{"default":"filet brisé triple vertical fin"}}},{"category":"So","key":"2507","mappings":{"default":{"default":"filet brisé triple vertical gras"}}},{"category":"So","key":"2508","mappings":{"default":{"default":"filet brisé quadruple horizontal fin"}}},{"category":"So","key":"2509","mappings":{"default":{"default":"filet brisé quadruple horizontal gras"}}},{"category":"So","key":"250A","mappings":{"default":{"default":"filet brisé quadruple vertical fin"}}},{"category":"So","key":"250B","mappings":{"default":{"default":"filet brisé quadruple vertical gras"}}},{"key":"250C","mappings":{"default":{"default":"filet fin vers le bas et vers la droite"}},"category":"So"},{"category":"So","key":"250D","mappings":{"default":{"default":"filet fin vers le bas et gras vers la droite"}}},{"category":"So","key":"250E","mappings":{"default":{"default":"filet gras vers le bas et fin vers la droite"}}},{"category":"So","key":"250F","mappings":{"default":{"default":"filet gras vers le bas et vers la droite"}}},{"key":"2510","mappings":{"default":{"default":"filet fin vers le bas et vers la gauche"}},"category":"So"},{"category":"So","key":"2511","mappings":{"default":{"default":"filet fin vers le bas et gras vers la gauche"}}},{"category":"So","key":"2512","mappings":{"default":{"default":"filet gras vers le bas et fin vers la gauche"}}},{"category":"So","key":"2513","mappings":{"default":{"default":"filet gras vers le bas et vers la gauche"}}},{"key":"2514","mappings":{"default":{"default":"filet fin vers le haut et vers la droite"}},"category":"So"},{"category":"So","key":"2515","mappings":{"default":{"default":"filet fin vers le haut et gras vers la droite"}}},{"category":"So","key":"2516","mappings":{"default":{"default":"filet gras vers le haut et fin vers la droite"}}},{"category":"So","key":"2517","mappings":{"default":{"default":"filet gras vers le haut et vers la droite"}}},{"key":"2518","mappings":{"default":{"default":"filet fin vers le haut et vers la gauche"}},"category":"So"},{"category":"So","key":"2519","mappings":{"default":{"default":"filet fin vers le haut et gras vers la gauche"}}},{"category":"So","key":"251A","mappings":{"default":{"default":"filet gras vers le haut et fin vers la gauche"}}},{"category":"So","key":"251B","mappings":{"default":{"default":"filet gras vers le haut et vers la gauche"}}},{"key":"251C","mappings":{"default":{"default":"filet fin vertical et vers la droite"}},"category":"So"},{"category":"So","key":"251D","mappings":{"default":{"default":"filet fin vertical et gras vers la droite"}}},{"category":"So","key":"251E","mappings":{"default":{"default":"filet gras vers le haut et fin vers la droite et vers le bas"}}},{"category":"So","key":"251F","mappings":{"default":{"default":"filet gras vers le bas et fin vers la droite et vers le haut"}}},{"category":"So","key":"2520","mappings":{"default":{"default":"filet gras vertical et fin vers la droite"}}},{"category":"So","key":"2521","mappings":{"default":{"default":"filet fin vers le bas et gras vers la droite et vers le haut"}}},{"category":"So","key":"2522","mappings":{"default":{"default":"filet fin vers le haut et gras vers la droite et vers le bas"}}},{"category":"So","key":"2523","mappings":{"default":{"default":"filet gras vertical et vers la droite"}}},{"key":"2524","mappings":{"default":{"default":"filet fin vertical et vers la gauche"}},"category":"So"},{"category":"So","key":"2525","mappings":{"default":{"default":"filet fin vertical et gras vers la gauche"}}},{"category":"So","key":"2526","mappings":{"default":{"default":"filet gras vers le haut et fin vers la gauche et vers le bas"}}},{"category":"So","key":"2527","mappings":{"default":{"default":"filet gras vers le bas et fin vers la gauche et vers le haut"}}},{"category":"So","key":"2528","mappings":{"default":{"default":"filet gras vertical et fin vers la gauche"}}},{"category":"So","key":"2529","mappings":{"default":{"default":"filet fin vers le bas et gras vers la gauche et vers le haut"}}},{"category":"So","key":"252A","mappings":{"default":{"default":"filet fin vers le haut et gras vers la gauche et vers le bas"}}},{"category":"So","key":"252B","mappings":{"default":{"default":"filet gras vertical et vers la gauche"}}},{"key":"252C","mappings":{"default":{"default":"filet fin vers le bas et horizontal"}},"category":"So"},{"category":"So","key":"252D","mappings":{"default":{"default":"filet gras vers la gauche et fin vers la droite et vers le bas"}}},{"category":"So","key":"252E","mappings":{"default":{"default":"filet gras vers la droite et fin vers la gauche et vers le bas"}}},{"category":"So","key":"252F","mappings":{"default":{"default":"filet fin vers le bas et gras horizontal"}}},{"category":"So","key":"2530","mappings":{"default":{"default":"filet gras vers le bas et fin horizontal"}}},{"category":"So","key":"2531","mappings":{"default":{"default":"filet fin vers la droite et gras vers la gauche et vers le bas"}}},{"category":"So","key":"2532","mappings":{"default":{"default":"filet fin vers la gauche et gras vers la droite et vers le bas"}}},{"category":"So","key":"2533","mappings":{"default":{"default":"filet gras vers le bas et horizontal"}}},{"key":"2534","mappings":{"default":{"default":"filet fin vers le haut et horizontal"}},"category":"So"},{"category":"So","key":"2535","mappings":{"default":{"default":"filet gras vers la gauche et fin vers la droite et vers le haut"}}},{"category":"So","key":"2536","mappings":{"default":{"default":"filet gras vers la droite et fin vers la gauche et vers le haut"}}},{"category":"So","key":"2537","mappings":{"default":{"default":"filet fin vers le haut et gras horizontal"}}},{"category":"So","key":"2538","mappings":{"default":{"default":"filet gras vers le haut et fin horizontal"}}},{"category":"So","key":"2539","mappings":{"default":{"default":"filet fin vers la droite et gras vers la gauche et vers le haut"}}},{"category":"So","key":"253A","mappings":{"default":{"default":"filet fin vers la gauche et gras vers la droite et vers le haut"}}},{"category":"So","key":"253B","mappings":{"default":{"default":"filet gras vers le haut et horizontal"}}},{"key":"253C","mappings":{"default":{"default":"filet fin vertical et horizontal"}},"category":"So"},{"category":"So","key":"253D","mappings":{"default":{"default":"filet gras vers la gauche et fin vers la droite et vertical"}}},{"category":"So","key":"253E","mappings":{"default":{"default":"filet gras vers la droite et fin vers la gauche et vertical"}}},{"category":"So","key":"253F","mappings":{"default":{"default":"filet vertical fin et horizontal gras"}}},{"category":"So","key":"2540","mappings":{"default":{"default":"filet gras vers le haut et fin vers le bas et horizontal"}}},{"category":"So","key":"2541","mappings":{"default":{"default":"filet gras vers le bas et fin vers le haut et horizontal"}}},{"category":"So","key":"2542","mappings":{"default":{"default":"filet vertical gras et horizontal fin"}}},{"category":"So","key":"2543","mappings":{"default":{"default":"filet gras vers la gauche et vers le haut et fin vers la droite et vers le bas"}}},{"category":"So","key":"2544","mappings":{"default":{"default":"filet gras vers la droite et vers le haut et fin vers la gauche et vers le bas"}}},{"category":"So","key":"2545","mappings":{"default":{"default":"filet gras vers la gauche et vers le bas et fin vers la droite et vers le haut"}}},{"category":"So","key":"2546","mappings":{"default":{"default":"filet gras vers la droite et vers le bas et fin vers la gauche et vers le haut"}}},{"category":"So","key":"2547","mappings":{"default":{"default":"filet fin vers le bas et gras vers le haut et horizontal"}}},{"category":"So","key":"2548","mappings":{"default":{"default":"filet fin vers le haut et gras vers le bas et horizontal"}}},{"category":"So","key":"2549","mappings":{"default":{"default":"filet fin vers la droite et gras vers la gauche et vertical"}}},{"category":"So","key":"254A","mappings":{"default":{"default":"filet fin vers la gauche et gras vers la droite et vertical"}}},{"category":"So","key":"254B","mappings":{"default":{"default":"filet vertical et horizontal gras"}}},{"category":"So","key":"254C","mappings":{"default":{"default":"filet brisé double horizontal fin"}}},{"category":"So","key":"254D","mappings":{"default":{"default":"filet brisé double horizontal gras"}}},{"category":"So","key":"254E","mappings":{"default":{"default":"filet brisé double vertical fin"}}},{"category":"So","key":"254F","mappings":{"default":{"default":"filet brisé double vertical gras"}}},{"key":"2550","mappings":{"default":{"default":"filet double horizontal"}},"category":"So"},{"key":"2551","mappings":{"default":{"default":"filet double vertical"}},"category":"So"},{"key":"2552","mappings":{"default":{"default":"filet simple le bas et double vers la droite"}},"category":"So"},{"key":"2553","mappings":{"default":{"default":"filet double vers le bas et simple vers la droite"}},"category":"So"},{"key":"2554","mappings":{"default":{"default":"filet double vers le bas et vers la droite"}},"category":"So"},{"key":"2555","mappings":{"default":{"default":"filet simple vers le bas et double vers la gauche"}},"category":"So"},{"key":"2556","mappings":{"default":{"default":"filet double vers le bas et simple vers la gauche"}},"category":"So"},{"key":"2557","mappings":{"default":{"default":"filet double vers le bas et vers la gauche"}},"category":"So"},{"key":"2558","mappings":{"default":{"default":"filet simple vers le haut et double vers la droite"}},"category":"So"},{"key":"2559","mappings":{"default":{"default":"filet double vers le haut et simple vers la droite"}},"category":"So"},{"key":"255A","mappings":{"default":{"default":"filet double vers le haut et vers la droite"}},"category":"So"},{"key":"255B","mappings":{"default":{"default":"filet simple vers le haut et double vers la gauche"}},"category":"So"},{"key":"255C","mappings":{"default":{"default":"filet double vers le haut et simple vers la gauche"}},"category":"So"},{"key":"255D","mappings":{"default":{"default":"filet double vers le haut et vers la gauche"}},"category":"So"},{"key":"255E","mappings":{"default":{"default":"filet vertical simple et droit double"}},"category":"So"},{"key":"255F","mappings":{"default":{"default":"filet vertical double et droit simple"}},"category":"So"},{"key":"2560","mappings":{"default":{"default":"filet double vertical et vers la droite"}},"category":"So"},{"key":"2561","mappings":{"default":{"default":"filet vertical simple et gauche double"}},"category":"So"},{"key":"2562","mappings":{"default":{"default":"filet vertical double et gauche simple"}},"category":"So"},{"key":"2563","mappings":{"default":{"default":"filet double vertical et vers la gauche"}},"category":"So"},{"key":"2564","mappings":{"default":{"default":"filet vers le bas simple et horizontal double"}},"category":"So"},{"key":"2565","mappings":{"default":{"default":"filet vers le bas double et horizontal simple"}},"category":"So"},{"key":"2566","mappings":{"default":{"default":"filet double vers le bas et horizontal"}},"category":"So"},{"key":"2567","mappings":{"default":{"default":"filet vers le haut simple et horizontal double"}},"category":"So"},{"key":"2568","mappings":{"default":{"default":"filet vers le haut double et horizontal simple"}},"category":"So"},{"key":"2569","mappings":{"default":{"default":"filet double vers le haut et horizontal"}},"category":"So"},{"key":"256A","mappings":{"default":{"default":"filet vertical simple et horizontal double"}},"category":"So"},{"key":"256B","mappings":{"default":{"default":"filet vertical double et horizontal simple"}},"category":"So"},{"key":"256C","mappings":{"default":{"default":"filet double vertical et horizontall"}},"category":"So"},{"category":"So","key":"256D","mappings":{"default":{"default":"filet fin arc vers le bas et vers la droite"}}},{"category":"So","key":"256E","mappings":{"default":{"default":"filet fin arc vers le bas et vers la gauche"}}},{"category":"So","key":"256F","mappings":{"default":{"default":"filet fin arc vers le haut et vers la gauche"}}},{"category":"So","key":"2570","mappings":{"default":{"default":"filet fin arc vers le haut et vers la droite"}}},{"category":"So","key":"2571","mappings":{"default":{"default":"filet diagonal fin du coin supérieur droit au coin inférieur gauche"}}},{"category":"So","key":"2572","mappings":{"default":{"default":"filet diagonal fin du coin supérieur gauche vers le coin inférieur droit"}}},{"category":"So","key":"2573","mappings":{"default":{"default":"filet diagonal fin en croix"}}},{"category":"So","key":"2574","mappings":{"default":{"default":"filet fin vers la gauche"}}},{"category":"So","key":"2575","mappings":{"default":{"default":"filet fin vers le haut"}}},{"category":"So","key":"2576","mappings":{"default":{"default":"filet fin vers la droite"}}},{"category":"So","key":"2577","mappings":{"default":{"default":"filet fin vers le bas"}}},{"category":"So","key":"2578","mappings":{"default":{"default":"filet gras vers la gauche"}}},{"category":"So","key":"2579","mappings":{"default":{"default":"filet gras vers le haut"}}},{"category":"So","key":"257A","mappings":{"default":{"default":"filet gras vers la droite"}}},{"category":"So","key":"257B","mappings":{"default":{"default":"filet gras vers le bas"}}},{"category":"So","key":"257C","mappings":{"default":{"default":"filet fin vers la gauche et gras vers la droite"}}},{"category":"So","key":"257D","mappings":{"default":{"default":"filet fin vers le haut et gras vers le bas"}}},{"category":"So","key":"257E","mappings":{"default":{"default":"filet gras vers la gauche et fin vers la droite"}}},{"category":"So","key":"257F","mappings":{"default":{"default":"filet gras vers le haut et fin vers le bas"}}},{"key":"2580","mappings":{"default":{"default":"moitié supérieure de pavé"}},"category":"So"},{"category":"So","key":"2581","mappings":{"default":{"default":"huitième inférieur de pavé"}}},{"category":"So","key":"2582","mappings":{"default":{"default":"quart inférieur de pavé"}}},{"category":"So","key":"2583","mappings":{"default":{"default":"trois huitièmes inférieurs de pavé"}}},{"key":"2584","mappings":{"default":{"default":"moitié inférieure de pavé"}},"category":"So"},{"category":"So","key":"2585","mappings":{"default":{"default":"cinq huitièmes inférieurs de pavé"}}},{"category":"So","key":"2586","mappings":{"default":{"default":"trois quarts inférieurs de pavé"}}},{"category":"So","key":"2587","mappings":{"default":{"default":"sept huitièmes inférieurs de pavé"}}},{"key":"2588","mappings":{"default":{"default":"pavé plein"}},"category":"So"},{"category":"So","key":"2589","mappings":{"default":{"default":"sept huitièmes gauches de pavé"}}},{"category":"So","key":"258A","mappings":{"default":{"default":"trois quarts gauches de pavé"}}},{"category":"So","key":"258B","mappings":{"default":{"default":"cinq huitièmes gauches de pavé"}}},{"category":"So","key":"258C","mappings":{"default":{"default":"moitié gauche de pavé"}}},{"category":"So","key":"258D","mappings":{"default":{"default":"trois huitièmes gauches de pavé"}}},{"category":"So","key":"258E","mappings":{"default":{"default":"un quart gauche de pavé"}}},{"category":"So","key":"258F","mappings":{"default":{"default":"un huitième gauche de pavé"}}},{"category":"So","key":"2590","mappings":{"default":{"default":"moitié droite de pavé"}}},{"key":"2591","mappings":{"default":{"default":"ombre légère"}},"category":"So"},{"key":"2592","mappings":{"default":{"default":"ombre moyenne"}},"category":"So"},{"key":"2593","mappings":{"default":{"default":"ombre foncée"}},"category":"So"},{"category":"So","key":"2594","mappings":{"default":{"default":"huitième supérieur de pavé"}}},{"category":"So","key":"2595","mappings":{"default":{"default":"huitième droit de pavé"}}},{"category":"So","key":"2596","mappings":{"default":{"default":"quadrant inférieur gauche"}}},{"category":"So","key":"2597","mappings":{"default":{"default":"quadrant inférieur droit"}}},{"category":"So","key":"2598","mappings":{"default":{"default":"quadrant supérieur gauche"}}},{"category":"So","key":"2599","mappings":{"default":{"default":"quadrant supérieur gauche inférieur gauche et inférieur droit"}}},{"category":"So","key":"259A","mappings":{"default":{"default":"quadrant supérieur gauche et inférieur droit"}}},{"category":"So","key":"259B","mappings":{"default":{"default":"quadrant supérieur gauche supérieur droit et inférieur gauche"}}},{"category":"So","key":"259C","mappings":{"default":{"default":"quadrant supérieur gauche supérieur droit et inférieur droit"}}},{"category":"So","key":"259D","mappings":{"default":{"default":"quadrant supérieur droit"}}},{"category":"So","key":"259E","mappings":{"default":{"default":"quadrant supérieur droit et inférieur gauche"}}},{"category":"So","key":"259F","mappings":{"default":{"default":"quadrant supérieur droit inférieur gauche et inférieur droit"}}},{"key":"25A0","mappings":{"default":{"default":"petit carré noir"}},"category":"So"},{"key":"25A1","mappings":{"default":{"default":"carré blanc"}},"category":"So"},{"category":"So","key":"25A2","mappings":{"default":{"default":"carré blanc aux coins arrondis"}}},{"category":"So","key":"25A3","mappings":{"default":{"default":"petit carré noir inscrit dans un carré blanc"}}},{"category":"So","key":"25A4","mappings":{"default":{"default":"carré hachuré horizontalement"}}},{"category":"So","key":"25A5","mappings":{"default":{"default":"carré hachuré verticalement"}}},{"category":"So","key":"25A6","mappings":{"default":{"default":"carré quadrillé"}}},{"category":"So","key":"25A7","mappings":{"default":{"default":"carré hachuré du haut à gauche vers le bas à droite"}}},{"category":"So","key":"25A8","mappings":{"default":{"default":"carré hachuré du haut à droite vers le bas à gauche"}}},{"category":"So","key":"25A9","mappings":{"default":{"default":"carré quadrillé en diagonale"}}},{"key":"25AA","mappings":{"default":{"default":"petit carré noir"}},"category":"So"},{"key":"25AB","mappings":{"default":{"default":"petit carré blanc"}},"category":"So"},{"category":"So","key":"25AC","mappings":{"default":{"default":"rectangle noir"}}},{"key":"25AD","mappings":{"default":{"default":"rectangle blanc"}},"category":"So"},{"key":"25AE","mappings":{"default":{"default":"rectangle vertical noir"}},"category":"So"},{"key":"25AF","mappings":{"default":{"default":"white vertical rectangle"}},"category":"So"},{"category":"So","key":"25B0","mappings":{"default":{"default":"parallélogramme noir"}}},{"key":"25B1","mappings":{"default":{"default":"parallélogramme blanc"}},"category":"So"},{"key":"25B2","mappings":{"default":{"default":"petit triangle noir pointant vers le haut"}},"category":"So"},{"key":"25B3","mappings":{"default":{"default":"triangle blanc pointant vers le haut"}},"category":"So"},{"key":"25B4","mappings":{"default":{"default":"petit triangle noir pointant vers le haut"}},"category":"So"},{"key":"25B5","mappings":{"default":{"default":"petit triangle blanc pointant vers le haut"}},"category":"So"},{"key":"25B6","mappings":{"default":{"default":"petit triangle noir pointant vers la droite"}},"category":"So"},{"key":"25B7","mappings":{"default":{"default":"triangle blanc pointant vers la droite"}},"category":"Sm"},{"key":"25B8","mappings":{"default":{"default":"petit triangle noir pointant vers la droite"}},"category":"So"},{"key":"25B9","mappings":{"default":{"default":"petit triangle blanc pointant vers la droite"}},"category":"So"},{"category":"So","key":"25BA","mappings":{"default":{"default":"pointeur noir vers la droite"}}},{"category":"So","key":"25BB","mappings":{"default":{"default":"pointeur blanc vers la droite"}}},{"key":"25BC","mappings":{"default":{"default":"petit triangle noir pointant vers le bas"}},"category":"So"},{"key":"25BD","mappings":{"default":{"default":"triangle blanc pointant vers le bas"}},"category":"So"},{"key":"25BE","mappings":{"default":{"default":"petit triangle noir pointant vers le bas"}},"category":"So"},{"key":"25BF","mappings":{"default":{"default":"petit triangle blanc pointant vers le bas"}},"category":"So"},{"key":"25C0","mappings":{"default":{"default":"petit triangle noir pointant vers la gauche"}},"category":"So"},{"key":"25C1","mappings":{"default":{"default":"petit triangle blanc pointant vers la gauche"}},"category":"Sm"},{"key":"25C2","mappings":{"default":{"default":"petit triangle noir pointant vers la gauche"}},"category":"So"},{"key":"25C3","mappings":{"default":{"default":"petit triangle blanc pointant vers la gauche"}},"category":"So"},{"key":"25C4","mappings":{"default":{"default":"pointeur noir vers la gauche"}},"category":"So"},{"key":"25C5","mappings":{"default":{"default":"pointeur blanc vers la gauche"}},"category":"So"},{"key":"25C6","mappings":{"default":{"default":"losange noir"}},"category":"So"},{"key":"25C7","mappings":{"default":{"default":"losange blanc"}},"category":"So"},{"key":"25C8","mappings":{"default":{"default":"losange blanc évidé"}},"category":"So"},{"key":"25C9","mappings":{"default":{"default":"cercle blanc évidé"}},"category":"So"},{"key":"25CA","mappings":{"default":{"default":"losange"}},"category":"So"},{"key":"25CB","mappings":{"default":{"default":"cercle blanc"}},"category":"So"},{"key":"25CC","mappings":{"default":{"default":"cercle en pointillés"}},"category":"So"},{"key":"25CD","mappings":{"default":{"default":"cercle hachuré verticalement"}},"category":"So"},{"key":"25CE","mappings":{"default":{"default":"deux cercles concentriques"}},"category":"So"},{"key":"25CF","mappings":{"default":{"default":"cercle noir"}},"category":"So"},{"key":"25D0","mappings":{"default":{"default":"cercle avec moitié gauche noire"}},"category":"So"},{"key":"25D1","mappings":{"default":{"default":"cercle avec moitié droite noire"}},"category":"So"},{"key":"25D2","mappings":{"default":{"default":"cercle avec moitié inférieure"}},"category":"So"},{"key":"25D3","mappings":{"default":{"default":"cercle avec moitié supérieure"}},"category":"So"},{"key":"25D4","mappings":{"default":{"default":"cercle avec quadrant supérieur droit noir"}},"category":"So"},{"key":"25D5","mappings":{"default":{"default":"disque avec quadrant supérieur gauche blanc"}},"category":"So"},{"key":"25D6","mappings":{"default":{"default":"demi disque gauche noir"}},"category":"So"},{"key":"25D7","mappings":{"default":{"default":"demi disque droite noir"}},"category":"So"},{"key":"25D8","mappings":{"default":{"default":"point noir au blanc"}},"category":"So"},{"key":"25D9","mappings":{"default":{"default":"cercle noir au blanc"}},"category":"So"},{"key":"25DA","mappings":{"default":{"default":"demi cercle supérieur noir au  blanc"}},"category":"So"},{"key":"25DB","mappings":{"default":{"default":"demi cercle inférieur noir au  blanc"}},"category":"So"},{"key":"25DC","mappings":{"default":{"default":"arc de cercle dans le quadrant supérieur gauchearc de cercle dans le quadrant supérieur gauche"}},"category":"So"},{"key":"25DD","mappings":{"default":{"default":"arc de cercle dans le quadrant supérieur droit"}},"category":"So"},{"key":"25DE","mappings":{"default":{"default":"arc de cercle dans le quadrant inférieur droit"}},"category":"So"},{"key":"25DF","mappings":{"default":{"default":"arc de cercle dans le quadrant inférieur gauche"}},"category":"So"},{"key":"25E0","mappings":{"default":{"default":"demi cercle supérieur"}},"category":"So"},{"key":"25E1","mappings":{"default":{"default":"demi cercle inférieur"}},"category":"So"},{"key":"25E2","mappings":{"default":{"default":"coin triangulaire noir inférieur droit"}},"category":"So"},{"key":"25E3","mappings":{"default":{"default":"coin triangulaire noir inférieur gauche"}},"category":"So"},{"key":"25E4","mappings":{"default":{"default":"coin triangulaire noir supérieur gauche"}},"category":"So"},{"key":"25E5","mappings":{"default":{"default":"coin triangulaire noir supérieur droit"}},"category":"So"},{"key":"25E6","mappings":{"default":{"default":"opérateur rond"}},"category":"So"},{"key":"25E7","mappings":{"default":{"default":"carré à moitié gauche noire"}},"category":"So"},{"key":"25E8","mappings":{"default":{"default":"carré à moitié droite noire"}},"category":"So"},{"key":"25E9","mappings":{"default":{"default":"carré à moitié supérieure gauche noire"}},"category":"So"},{"key":"25EA","mappings":{"default":{"default":"carré à moitié inférieure droite noire"}},"category":"So"},{"key":"25EB","mappings":{"default":{"default":"carré blanc à ligne bissectrice verticale"}},"category":"So"},{"key":"25EC","mappings":{"default":{"default":"triangle blanc pointant vers le haut pointé"}},"category":"So"},{"key":"25ED","mappings":{"default":{"default":"triangle pointe vers le haut À moitié gauche noire"}},"category":"So"},{"key":"25EE","mappings":{"default":{"default":"triangle pointe vers le haut À moitié droite noire"}},"category":"So"},{"key":"25EF","mappings":{"default":{"default":"grand cercle"}},"category":"So"},{"category":"So","key":"25F0","mappings":{"default":{"default":"carré blanc à quartier supérieur gauche"}}},{"category":"So","key":"25F1","mappings":{"default":{"default":"carré blanc à quartier inférieur gauche"}}},{"category":"So","key":"25F2","mappings":{"default":{"default":"carré blanc à quartier inférieur droit"}}},{"category":"So","key":"25F3","mappings":{"default":{"default":"carré blanc à quartier supérieur droit"}}},{"category":"So","key":"25F4","mappings":{"default":{"default":"cercle blanc à quartier supérieur gauche"}}},{"category":"So","key":"25F5","mappings":{"default":{"default":"cercle blanc à quartier inférieur gauche"}}},{"category":"So","key":"25F6","mappings":{"default":{"default":"cercle blanc à quartier inférieur droit"}}},{"category":"So","key":"25F7","mappings":{"default":{"default":"cercle blanc à quartier supérieur droit"}}},{"key":"25F8","mappings":{"default":{"default":"triangle rectangle supérieur gauche"}},"category":"Sm"},{"key":"25F9","mappings":{"default":{"default":"triangle rectangle supérieur droit"}},"category":"Sm"},{"key":"25FA","mappings":{"default":{"default":"triangle rectangle inférieur gauche"}},"category":"Sm"},{"key":"25FB","mappings":{"default":{"default":"carré moyen blanc"}},"category":"Sm"},{"key":"25FC","mappings":{"default":{"default":"carré moyen noir"}},"category":"Sm"},{"key":"25FD","mappings":{"default":{"default":"carré moyen blanc"}},"category":"Sm"},{"key":"25FE","mappings":{"default":{"default":"carré moyen noir"}},"category":"Sm"},{"key":"25FF","mappings":{"default":{"default":"triangle rectangle inférieur droit"}},"category":"Sm"},{"category":"So","key":"2B12","mappings":{"default":{"default":"carré à moitié supérieure noire"}}},{"category":"So","key":"2B13","mappings":{"default":{"default":"carré à moitié inférieure noire"}}},{"category":"So","key":"2B14","mappings":{"default":{"default":"carré à moitié diagonale supérieure droite noire"}}},{"category":"So","key":"2B15","mappings":{"default":{"default":"carré à moitié diagonale inférieure droite noire"}}},{"category":"So","key":"2B16","mappings":{"default":{"default":"losange à moitié gauche noire"}}},{"category":"So","key":"2B17","mappings":{"default":{"default":"losange à moitié droite noire"}}},{"category":"So","key":"2B18","mappings":{"default":{"default":"losange à moitié supérieure noire"}}},{"category":"So","key":"2B19","mappings":{"default":{"default":"losange à moitié inférieure noire"}}},{"category":"So","key":"2B1A","mappings":{"default":{"default":"carré en pointillés"}}},{"category":"So","key":"2B1B","mappings":{"default":{"default":"grand carré noir"}}},{"category":"So","key":"2B1C","mappings":{"default":{"default":"grand carré blanc"}}},{"category":"So","key":"2B1D","mappings":{"default":{"default":"très petit carré noir"}}},{"category":"So","key":"2B1E","mappings":{"default":{"default":"très petit carré blanc"}}},{"category":"So","key":"2B1F","mappings":{"default":{"default":"pentagone noir"}}},{"category":"So","key":"2B20","mappings":{"default":{"default":"pentagone blanc"}}},{"category":"So","key":"2B21","mappings":{"default":{"default":"hexagone blanc"}}},{"category":"So","key":"2B22","mappings":{"default":{"default":"hexagone noir"}}},{"category":"So","key":"2B23","mappings":{"default":{"default":"hexagone noir posé sur un côté"}}},{"category":"So","key":"2B24","mappings":{"default":{"default":"grand cercle noir"}}},{"category":"So","key":"2B25","mappings":{"default":{"default":"losange moyen noir"}}},{"category":"So","key":"2B26","mappings":{"default":{"default":"losange moyen blanc"}}},{"category":"So","key":"2B27","mappings":{"default":{"default":"rhombe moyen noir"}}},{"category":"So","key":"2B28","mappings":{"default":{"default":"rhombe moyen blanc"}}},{"category":"So","key":"2B29","mappings":{"default":{"default":"petit losange noir"}}},{"category":"So","key":"2B2A","mappings":{"default":{"default":"petit rhombe noir"}}},{"category":"So","key":"2B2B","mappings":{"default":{"default":"petit rhombe blanc"}}},{"category":"So","key":"2B2C","mappings":{"default":{"default":"ellipse horizontale noire"}}},{"category":"So","key":"2B2D","mappings":{"default":{"default":"ellipse horizontale blanche"}}},{"category":"So","key":"2B2E","mappings":{"default":{"default":"ellipse verticale noire"}}},{"category":"So","key":"2B2F","mappings":{"default":{"default":"ellipse verticale blanche"}}},{"key":"2B50","mappings":{"default":{"default":"étoile blanche moyenne"}},"category":"So"},{"key":"2B51","mappings":{"default":{"default":"petite étoile noire"}},"category":"So"},{"key":"2B52","mappings":{"default":{"default":"petite étoile blanche"}},"category":"So"},{"category":"So","key":"2B53","mappings":{"default":{"default":"pentagone noir pointant vers la droite"}}},{"category":"So","key":"2B54","mappings":{"default":{"default":"pentagone blanc pointant vers la droite"}}},{"category":"So","key":"2B55","mappings":{"default":{"default":"grand cercle gras"}}},{"category":"So","key":"2B56","mappings":{"default":{"default":"ovale gras avec ovale inscrit"}}},{"category":"So","key":"2B57","mappings":{"default":{"default":"cercle gras avec cercle inscrit"}}},{"category":"So","key":"2B58","mappings":{"default":{"default":"cercle gras"}}},{"category":"So","key":"2B59","mappings":{"default":{"default":"sautoir cerclé gras"}}}]
,
"fr/symbols/math_harpoons.js": 
[{"locale":"fr"},{"key":"21BC","mappings":{"default":{"default":"harpon gauche avec dent dressée"}},"category":"So"},{"key":"21BD","mappings":{"default":{"default":"harpon gauche avec dent baissée"}},"category":"So"},{"key":"21BE","mappings":{"default":{"default":"harpon vers le haut avec dent droite"}},"category":"So"},{"key":"21BF","mappings":{"default":{"default":"harpon vers le haut avec dent gauche"}},"category":"So"},{"key":"21C0","mappings":{"default":{"default":"harpon droit avec dent dressée"}},"category":"So"},{"key":"21C1","mappings":{"default":{"default":"harpon droit avec dent baissée"}},"category":"So"},{"key":"21C2","mappings":{"default":{"default":"harpon vers le bas avec dent droite"}},"category":"So"},{"key":"21C3","mappings":{"default":{"default":"harpon vers le bas avec dent gauche"}},"category":"So"},{"key":"21CB","mappings":{"default":{"default":"harpon gauche par dessus harpon droit"}},"category":"So"},{"key":"21CC","mappings":{"default":{"default":"harpon droit par dessus harpon gauche"}},"category":"So"},{"key":"294A","mappings":{"default":{"default":"javelot à dents gauche dressée et droite baissée"}},"category":"Sm"},{"key":"294B","mappings":{"default":{"default":"javelot à dents gauche baissée et droite dressée"}},"category":"Sm"},{"category":"Sm","key":"294C","mappings":{"default":{"default":"crampon à dents supérieure droite et inférieure gauche"}}},{"category":"Sm","key":"294D","mappings":{"default":{"default":"crampon à dents supérieure gauche et inférieure droite"}}},{"key":"294E","mappings":{"default":{"default":"javelot à dents droite et gauche dressées"}},"category":"Sm"},{"key":"294F","mappings":{"default":{"default":"javelot à dents supérieure et inférieure droites"}},"category":"Sm"},{"key":"2950","mappings":{"default":{"default":"javelot à dents droite et gauche baissées"}},"category":"Sm"},{"key":"2951","mappings":{"default":{"default":"javelot à dents supérieure et inférieure gauches"}},"category":"Sm"},{"key":"2952","mappings":{"default":{"default":"harpon gauche à dent dressée contre taquet"}},"category":"Sm"},{"key":"2953","mappings":{"default":{"default":"harpon droit à dent dressée contre taquet"}},"category":"Sm"},{"key":"2954","mappings":{"default":{"default":"harpon vers le haut à dent droite contre taquet"}},"category":"Sm"},{"key":"2955","mappings":{"default":{"default":"harpon vers le bas à dent droite contre taquet"}},"category":"Sm"},{"key":"2956","mappings":{"default":{"default":"harpon gauche à dent baissée contre taquet"}},"category":"Sm"},{"key":"2957","mappings":{"default":{"default":"harpon droit à dent baissée contre taquet"}},"category":"Sm"},{"key":"2958","mappings":{"default":{"default":"harpon vers le haut à dent gauche contre taquet"}},"category":"Sm"},{"key":"2959","mappings":{"default":{"default":"harpon vers le bas à dent gauche contre taquet"}},"category":"Sm"},{"key":"295A","mappings":{"default":{"default":"harpon gauche à dent dressée depuis taquet"}},"category":"Sm"},{"key":"295B","mappings":{"default":{"default":"harpon droit à dent dressée depuis taquet"}},"category":"Sm"},{"key":"295C","mappings":{"default":{"default":"harpon vers le haut à dent droite depuis taquet"}},"category":"Sm"},{"key":"295D","mappings":{"default":{"default":"harpon vers le bas à dent droite depuis taquet"}},"category":"Sm"},{"key":"295E","mappings":{"default":{"default":"harpon gauche à dent baissée depuis taquet"}},"category":"Sm"},{"key":"295F","mappings":{"default":{"default":"harpon droit à dent baissée depuis taquet"}},"category":"Sm"},{"key":"2960","mappings":{"default":{"default":"harpon vers le haut à dent gauche depuis taquet"}},"category":"Sm"},{"key":"2961","mappings":{"default":{"default":"harpon vers le bas à dent gauche depuis taquet"}},"category":"Sm"},{"key":"2962","mappings":{"default":{"default":"harpon gauche à dent dressée sur harpon gauche à dent baissée"}},"category":"Sm"},{"key":"2963","mappings":{"default":{"default":"harpon vers le haut à dent gauche à côté de harpon vers le haut à dent droite"}},"category":"Sm"},{"key":"2964","mappings":{"default":{"default":"harpon droit à dent dressée par dessus harpon droit à dent baissée"}},"category":"Sm"},{"key":"2965","mappings":{"default":{"default":"harpon vers le bas à dent gauche à côté de harpon vers le bas à dent droite"}},"category":"Sm"},{"key":"2966","mappings":{"default":{"default":"harpon à dent gauche dressée par dessus harpon à dent droite dressée"}},"category":"Sm"},{"key":"2967","mappings":{"default":{"default":"harpon à dent gauche baissée par dessus harpon à dent droite baissée"}},"category":"Sm"},{"key":"2968","mappings":{"default":{"default":"harpon à dent droite dressée par dessus harpon à dent gauche dressée"}},"category":"Sm"},{"key":"2969","mappings":{"default":{"default":"harpon à dent droite baissée par dessus harpon à dent gauche baissée"}},"category":"Sm"},{"key":"296A","mappings":{"default":{"default":"harpon à dent gauche dressée par dessus long trait"}},"category":"Sm"},{"key":"296B","mappings":{"default":{"default":"long trait par dessus harpon à dent gauche baissée"}},"category":"Sm"},{"key":"296C","mappings":{"default":{"default":"harpon à dent droite dressée par dessus long trait"}},"category":"Sm"},{"key":"296D","mappings":{"default":{"default":"long trait par dessus harpon à dent droite baissée"}},"category":"Sm"},{"key":"296E","mappings":{"default":{"default":"harpon vers le haut à dent gauche à côté de harpon vers le bas à dent droite"}},"category":"Sm"},{"key":"296F","mappings":{"default":{"default":"harpon vers le bas à dent gauche à côté de harpon vers le haut à dent droite"}},"category":"Sm"},{"key":"297C","mappings":{"default":{"default":"ancre gauche"}},"category":"Sm"},{"key":"297D","mappings":{"default":{"default":"ancre droite"}},"category":"Sm"},{"key":"297E","mappings":{"default":{"default":"ancre vers le haut"}},"category":"Sm"},{"key":"297F","mappings":{"default":{"default":"ancre vers le bas"}},"category":"Sm"}]
,
"fr/symbols/math_non_characters.js": 
[{"locale":"fr"},{"key":"210F","mappings":{"default":{"default":"constante de planck sur deux pi"}},"category":"Ll"},{"category":"So","key":"2114","mappings":{"default":{"default":"symbole l b barré"}}},{"key":"2116","mappings":{"default":{"default":"symbole numéro"}},"category":"So"},{"key":"2117","mappings":{"default":{"default":"copyright de programme sonore"}},"category":"So"},{"key":"211E","mappings":{"default":{"default":"ordonnances"}},"category":"So"},{"category":"So","key":"211F","mappings":{"default":{"default":"répons"}}},{"category":"So","key":"2120","mappings":{"default":{"default":"symbole anglais marque de service"}}},{"category":"So","key":"2121","mappings":{"default":{"default":"signe de téléphone"}}},{"key":"2122","mappings":{"default":{"default":"symbole anglais marque de commerce"}},"category":"So"},{"category":"So","key":"2123","mappings":{"default":{"default":"versicule"}}},{"key":"2125","mappings":{"default":{"default":"symbole once"}},"category":"So"},{"key":"2126","mappings":{"default":{"default":"ohm"}},"category":"Lu"},{"key":"2127","mappings":{"default":{"default":"ohm culbuté"}},"category":"So"},{"key":"212A","mappings":{"default":{"default":"degré kelvin"}},"category":"Lu"},{"key":"212B","mappings":{"default":{"default":"angstroms"}},"category":"Lu"},{"category":"So","key":"212E","mappings":{"default":{"default":"symbole estimé"}}},{"key":"2132","mappings":{"default":{"default":"f culbuté majuscule"}},"category":"Lu"},{"category":"Ll","key":"2139","mappings":{"default":{"default":"bureau d'information"}}},{"category":"So","key":"213A","mappings":{"default":{"default":"Q majuscule couché"}}},{"category":"So","key":"213B","mappings":{"default":{"default":"symbole télécopie"}}},{"category":"Sm","key":"2141","mappings":{"default":{"default":"G culbuté majuscule sans empattement"}}},{"category":"Sm","key":"2142","mappings":{"default":{"default":"L culbuté majuscule sans empattement"}}},{"category":"Sm","key":"2143","mappings":{"default":{"default":"L réfléchi majuscule sans empattement"}}},{"category":"Sm","key":"2144","mappings":{"default":{"default":"Y culbuté majuscule sans empattement"}}}]
,
"fr/symbols/math_symbols.js": 
[{"locale":"fr"},{"key":"0021","mappings":{"default":{"default":"factorielle"}},"category":"Po"},{"key":"0022","mappings":{"default":{"default":"petit guillemet"}},"category":"Po"},{"key":"0023","mappings":{"default":{"default":"dièse"}},"category":"Po"},{"key":"0024","mappings":{"default":{"default":"dollars"}},"category":"Sc"},{"key":"0025","mappings":{"default":{"default":"pourcent"}},"category":"Po"},{"key":"0026","mappings":{"default":{"default":"esperluette"}},"category":"Po"},{"key":"0027","mappings":{"default":{"default":"prime","alternative":"apostrophe"}},"category":"Po"},{"key":"002A","mappings":{"default":{"default":"astérisque"}},"category":"Po"},{"key":"002B","mappings":{"default":{"default":"plus"}},"category":"Sm"},{"key":"002C","mappings":{"default":{"default":"virgule"}},"category":"Po"},{"key":"002D","mappings":{"default":{"default":"moins"}},"category":"Pd"},{"key":"002E","mappings":{"default":{"default":"point"}},"category":"Po"},{"key":"002F","mappings":{"default":{"default":"barre oblique"}},"category":"Po"},{"key":"003A","mappings":{"default":{"default":"deux points"}},"category":"Po"},{"key":"003B","mappings":{"default":{"default":"point virgule"}},"category":"Po"},{"key":"003C","mappings":{"default":{"default":"inférieur à"}},"category":"Sm"},{"key":"003D","mappings":{"default":{"default":"égale"}},"category":"Sm"},{"key":"003E","mappings":{"default":{"default":"supérieur à"}},"category":"Sm"},{"key":"003F","mappings":{"default":{"default":"point d'interrogation"}},"category":"Po"},{"key":"0040","mappings":{"default":{"default":"arobase"}},"category":"Po"},{"key":"005C","mappings":{"default":{"default":"barre oblique inversée"}},"category":"Po"},{"key":"005E","mappings":{"default":{"default":"circonflexe"}},"category":"Sk"},{"key":"005F","mappings":{"default":{"default":"tiret bas"}},"category":"Pc"},{"key":"0060","mappings":{"default":{"default":"accent grave"}},"category":"Sk"},{"key":"007C","mappings":{"default":{"default":"barre verticale"}},"category":"Sm"},{"key":"007E","mappings":{"default":{"default":"tilde"}},"category":"Sm"},{"key":"00A1","mappings":{"default":{"default":"point d'exclamation renversé"}},"category":"Po"},{"key":"00A2","mappings":{"default":{"default":"centimes"}},"category":"Sc"},{"key":"00A3","mappings":{"default":{"default":"livres"}},"category":"Sc"},{"key":"00A4","mappings":{"default":{"default":"symbole monétaire"}},"category":"Sc"},{"key":"00A5","mappings":{"default":{"default":"yen"}},"category":"Sc"},{"key":"00A6","mappings":{"default":{"default":"barre déjointe"}},"category":"So"},{"key":"00A7","mappings":{"default":{"default":"paragraphe"}},"category":"Po"},{"key":"00A8","mappings":{"default":{"default":"tréma"}},"category":"Sk"},{"key":"00A9","mappings":{"default":{"default":"copyright"}},"category":"So"},{"key":"00AA","mappings":{"default":{"default":"indicateur ordinal féminin"}},"category":"Lo"},{"key":"00AB","mappings":{"default":{"default":"guillemet chevron pointant gauche"}},"category":"Pi"},{"key":"00AC","mappings":{"default":{"default":"négation"}},"category":"Sm"},{"key":"00AE","mappings":{"default":{"default":"symbole marque déposée"}},"category":"So"},{"key":"00AF","mappings":{"default":{"default":"macron"}},"category":"Sk"},{"key":"00B0","mappings":{"default":{"default":"degrés"}},"category":"So"},{"key":"00B1","mappings":{"default":{"default":"plus ou moins"}},"category":"Sm"},{"key":"00B4","mappings":{"default":{"default":"accent aigu"}},"category":"Sk"},{"key":"00B5","mappings":{"default":{"default":"symbole micro"}},"category":"Ll"},{"key":"00B6","mappings":{"default":{"default":"fin de paragraphe"}},"category":"Po"},{"key":"00B7","mappings":{"default":{"default":"point médian"}},"category":"Po"},{"key":"00B8","mappings":{"default":{"default":"cédille"}},"category":"Sk"},{"key":"00BA","mappings":{"default":{"default":"indicateur ordinal masculin"}},"category":"Lo"},{"key":"00BB","mappings":{"default":{"default":"guillemet chevron pointant droite"}},"category":"Pf"},{"key":"00BF","mappings":{"default":{"default":"point d'interrogation renversé"}},"category":"Po"},{"key":"00D7","mappings":{"default":{"default":"multiplié par"}},"category":"Sm"},{"key":"00F7","mappings":{"default":{"default":"divisé par"}},"category":"Sm"},{"key":"02D8","mappings":{"default":{"default":"brève"}},"category":"Sk"},{"key":"02D9","mappings":{"default":{"default":"point en chef"}},"category":"Sk"},{"key":"02DA","mappings":{"default":{"default":"rond en chef"}},"category":"Sk"},{"key":"02DB","mappings":{"default":{"default":"ogonek"}},"category":"Sk"},{"key":"02DC","mappings":{"default":{"default":"tilde"}},"category":"Sk"},{"key":"02DD","mappings":{"default":{"default":"double accent aigu"}},"category":"Sk"},{"key":"2010","mappings":{"default":{"default":"trait d'union"}},"category":"Pd"},{"category":"Pd","key":"2011","mappings":{"default":{"default":"trait d'union insécable"}}},{"category":"Pd","key":"2012","mappings":{"default":{"default":"tiret numérique"}}},{"key":"2013","mappings":{"default":{"default":"trait d'union insécable"}},"category":"Pd"},{"key":"2014","mappings":{"default":{"default":"tiret numérique"}},"category":"Pd"},{"key":"2015","mappings":{"default":{"default":"barre horizontalle"}},"category":"Pd"},{"key":"2016","mappings":{"default":{"default":"double ligne verticale"}},"category":"Po"},{"category":"Po","key":"2017","mappings":{"default":{"default":"double trait souscrit"}}},{"key":"2018","mappings":{"default":{"default":"guillemet apostrophe culbuté"}},"category":"Pi"},{"key":"2019","mappings":{"default":{"default":"guillemet apostrophe"}},"category":"Pf"},{"key":"201A","mappings":{"default":{"default":"guillemet virgule inférieur"}},"category":"Ps"},{"category":"Pi","key":"201B","mappings":{"default":{"default":"guillemet virgule supérieur culbuté"}}},{"key":"201C","mappings":{"default":{"default":"guillemet apostrophe double culbuté"}},"category":"Pi"},{"key":"201D","mappings":{"default":{"default":"guillemet apostrophe double"}},"category":"Pf"},{"key":"201E","mappings":{"default":{"default":"guillemet double prime"}},"category":"Ps"},{"category":"Pi","key":"201F","mappings":{"default":{"default":"guillemet virgule double supérieur culbuté"}}},{"key":"2020","mappings":{"default":{"default":"obèle"}},"category":"Po"},{"key":"2021","mappings":{"default":{"default":"double obèle"}},"category":"Po"},{"key":"2022","mappings":{"default":{"default":"puce"}},"category":"Po"},{"category":"Po","key":"2023","mappings":{"default":{"default":"puce triangulaire"}}},{"category":"Po","key":"2024","mappings":{"default":{"default":"point de conduite simple"}}},{"key":"2025","mappings":{"default":{"default":"point de conduite double"}},"category":"Po"},{"key":"2026","mappings":{"default":{"default":"points de suspension"}},"category":"Po"},{"category":"Po","key":"2027","mappings":{"default":{"default":"point de coupure de mot"}}},{"key":"2030","mappings":{"default":{"default":"symbole pour mille"}},"category":"Po"},{"key":"2031","mappings":{"default":{"default":"symbole pour dix mille"}},"category":"Po"},{"key":"2032","mappings":{"default":{"default":"prime"}},"category":"Po"},{"key":"2033","mappings":{"default":{"default":"double prime"}},"category":"Po"},{"key":"2034","mappings":{"default":{"default":"triple prime"}},"category":"Po"},{"key":"2035","mappings":{"default":{"default":"prime réfléchi"}},"category":"Po"},{"key":"2036","mappings":{"default":{"default":"double prime réfléchi"}},"category":"Po"},{"category":"Po","key":"2037","mappings":{"default":{"default":"triple prime réfléchi"}}},{"category":"Po","key":"2038","mappings":{"default":{"default":"chevron d'insertion"}}},{"key":"2039","mappings":{"default":{"default":"guillemet simple gauche"}},"category":"Pi"},{"key":"203A","mappings":{"default":{"default":"guillemet simple droite"}},"category":"Pf"},{"category":"Po","key":"203B","mappings":{"default":{"default":"marque de référence"}}},{"category":"Po","key":"203C","mappings":{"default":{"default":"double point d'exclamation"}}},{"category":"Po","key":"203D","mappings":{"default":{"default":"point exclarrogatif"}}},{"key":"203E","mappings":{"default":{"default":"tiret en chef"}},"category":"Po"},{"category":"Pc","key":"203F","mappings":{"default":{"default":"tirant souscrit"}}},{"key":"2040","mappings":{"default":{"default":"tirant en chef"}},"category":"Pc"},{"key":"2041","mappings":{"default":{"default":"lambda d'insertion"}},"category":"Po"},{"category":"Po","key":"2042","mappings":{"default":{"default":"astérisme"}}},{"key":"2043","mappings":{"default":{"default":"puce trait d'union"}},"category":"Po"},{"key":"2044","mappings":{"default":{"default":"barre de fraction"}},"category":"Sm"},{"category":"Po","key":"2047","mappings":{"default":{"default":"double point d'interrogation"}}},{"category":"Po","key":"2048","mappings":{"default":{"default":"point d'interrogation exclamation"}}},{"category":"Po","key":"2049","mappings":{"default":{"default":"point d'exclamation interrogation"}}},{"category":"Po","key":"204B","mappings":{"default":{"default":"pied de mouche réfléchi"}}},{"category":"Po","key":"204C","mappings":{"default":{"default":"puce noire tronquée à droite"}}},{"category":"Po","key":"204D","mappings":{"default":{"default":"puce noire tronquée à gauche"}}},{"category":"Po","key":"204E","mappings":{"default":{"default":"astérisque baissé"}}},{"key":"204F","mappings":{"default":{"default":"point virgule réfléchi"}},"category":"Po"},{"key":"2050","mappings":{"default":{"default":"resserrer"}},"category":"Po"},{"category":"Po","key":"2051","mappings":{"default":{"default":"deux astérisques alignés verticalement"}}},{"category":"Sm","key":"2052","mappings":{"default":{"default":"moins commercial"}}},{"category":"Po","key":"2053","mappings":{"default":{"default":"tiret ondé"}}},{"category":"Pc","key":"2054","mappings":{"default":{"default":"dos d'âne souscrit"}}},{"category":"Po","key":"2055","mappings":{"default":{"default":"point fleur"}}},{"category":"Po","key":"2056","mappings":{"default":{"default":"trois points"}}},{"key":"2057","mappings":{"default":{"default":"quadruple prime"}},"category":"Po"},{"category":"Po","key":"2058","mappings":{"default":{"default":"quatre points en losange"}}},{"category":"Po","key":"2059","mappings":{"default":{"default":"cinq points en quinconce"}}},{"category":"Po","key":"205A","mappings":{"default":{"default":"deux points en capitale"}}},{"category":"Po","key":"205B","mappings":{"default":{"default":"quatre points en croix"}}},{"category":"Po","key":"205C","mappings":{"default":{"default":"croix pointée"}}},{"category":"Po","key":"205D","mappings":{"default":{"default":"trois points vertical"}}},{"category":"Po","key":"205E","mappings":{"default":{"default":"quatre points vertical"}}},{"category":"Sm","key":"207A","mappings":{"default":{"default":"exposant signe plus"}}},{"category":"Sm","key":"207B","mappings":{"default":{"default":"exposant signe moins"}}},{"category":"Sm","key":"207C","mappings":{"default":{"default":"exposant signe égal"}}},{"category":"Ps","key":"207D","mappings":{"default":{"default":"exposant parenthèse gauche"}}},{"category":"Pe","key":"207E","mappings":{"default":{"default":"exposant parenthèse droite"}}},{"category":"Sm","key":"208A","mappings":{"default":{"default":"indice signe plus"}}},{"category":"Sm","key":"208B","mappings":{"default":{"default":"indice signe moins"}}},{"category":"Sm","key":"208C","mappings":{"default":{"default":"indice signe égal"}}},{"category":"Ps","key":"208D","mappings":{"default":{"default":"indice parenthèse gauche"}}},{"category":"Pe","key":"208E","mappings":{"default":{"default":"indice parenthèse droite"}}},{"category":"So","key":"214A","mappings":{"default":{"default":"limite de propriété"}}},{"category":"Sm","key":"214B","mappings":{"default":{"default":"perluète culbutée"}}},{"category":"So","key":"214C","mappings":{"default":{"default":"symbole per"}}},{"category":"So","key":"214D","mappings":{"default":{"default":"aktieselskab"}}},{"category":"Ll","key":"214E","mappings":{"default":{"default":"minuscule f culbuté"}}},{"key":"2200","mappings":{"default":{"default":"pour tous"}},"category":"Sm"},{"key":"2201","mappings":{"default":{"default":"complément"}},"category":"Sm"},{"key":"2203","mappings":{"default":{"default":"il existe"}},"category":"Sm"},{"key":"2204","mappings":{"default":{"default":"il n'existe pas"}},"category":"Sm"},{"key":"2205","mappings":{"default":{"default":"ensemble vide"}},"category":"Sm"},{"key":"2206","mappings":{"default":{"default":"incrément"}},"category":"Sm"},{"key":"2208","mappings":{"default":{"default":"appartient à"}},"category":"Sm"},{"key":"2209","mappings":{"default":{"default":"n'appartient pas à"}},"category":"Sm"},{"key":"220A","mappings":{"default":{"default":"appartient à"}},"category":"Sm"},{"key":"220B","mappings":{"default":{"default":"contient comme élément"}},"category":"Sm"},{"key":"220C","mappings":{"default":{"default":"ne contient pas comme élément"}},"category":"Sm"},{"key":"220D","mappings":{"default":{"default":"contient comme élément"}},"category":"Sm"},{"key":"220E","mappings":{"default":{"default":"ce qu'il fallait démontrer"}},"category":"Sm"},{"key":"220F","mappings":{"default":{"default":"produit"}},"category":"Sm"},{"key":"2210","mappings":{"default":{"default":"coproduit"}},"category":"Sm"},{"key":"2211","mappings":{"default":{"default":"sommation"}},"category":"Sm"},{"key":"2212","mappings":{"default":{"default":"moins"}},"category":"Sm"},{"key":"2213","mappings":{"default":{"default":"moins ou plus"}},"category":"Sm"},{"key":"2214","mappings":{"default":{"default":"plus pointé"}},"category":"Sm"},{"key":"2215","mappings":{"default":{"default":"division"}},"category":"Sm"},{"key":"2216","mappings":{"default":{"default":"différence d'ensembles"}},"category":"Sm"},{"key":"2217","mappings":{"default":{"default":"opérateur astérisque"}},"category":"Sm"},{"key":"2218","mappings":{"default":{"default":"opérateur rond"}},"category":"Sm"},{"key":"2219","mappings":{"default":{"default":"point médian"}},"category":"Sm"},{"key":"221A","mappings":{"default":{"default":"racine carrée"}},"category":"Sm"},{"key":"221B","mappings":{"default":{"default":"racine cubique"}},"category":"Sm"},{"key":"221C","mappings":{"default":{"default":"racine quatrième"}},"category":"Sm"},{"key":"221D","mappings":{"default":{"default":"proportionnel à"}},"category":"Sm"},{"key":"221E","mappings":{"default":{"default":"infini"}},"category":"Sm"},{"key":"221F","mappings":{"default":{"default":"angle droit"}},"category":"Sm"},{"key":"2220","mappings":{"default":{"default":"angle"}},"category":"Sm"},{"key":"2221","mappings":{"default":{"default":"angle mesuré"}},"category":"Sm"},{"key":"2222","mappings":{"default":{"default":"angle sphérique"}},"category":"Sm"},{"key":"2223","mappings":{"default":{"default":"est un diviseur de"}},"category":"Sm"},{"key":"2224","mappings":{"default":{"default":"n'est pas un diviseur de"}},"category":"Sm"},{"key":"2225","mappings":{"default":{"default":"parallèle à"}},"category":"Sm"},{"key":"2226","mappings":{"default":{"default":"non parallèle à"}},"category":"Sm"},{"key":"2227","mappings":{"default":{"default":"et logique"}},"category":"Sm"},{"key":"2228","mappings":{"default":{"default":"ou logique"}},"category":"Sm"},{"key":"2229","mappings":{"default":{"default":"intersection"}},"category":"Sm"},{"key":"222A","mappings":{"default":{"default":"union"}},"category":"Sm"},{"key":"222B","mappings":{"default":{"default":"intégrale"}},"category":"Sm"},{"key":"222C","mappings":{"default":{"default":"intégrale double"}},"category":"Sm"},{"key":"222D","mappings":{"default":{"default":"intégrale triple"}},"category":"Sm"},{"key":"222E","mappings":{"default":{"default":"intégrale de contour"}},"category":"Sm"},{"key":"222F","mappings":{"default":{"default":"intégrale de surface"}},"category":"Sm"},{"key":"2230","mappings":{"default":{"default":"intégrale de volume"}},"category":"Sm"},{"key":"2231","mappings":{"default":{"default":"intégrale en sens négatif"}},"category":"Sm"},{"key":"2232","mappings":{"default":{"default":"intégrale de contour en sens négatif"}},"category":"Sm"},{"key":"2233","mappings":{"default":{"default":"intégrale de contour en sens positif"}},"category":"Sm"},{"key":"2234","mappings":{"default":{"default":"par conséquent"}},"category":"Sm"},{"key":"2235","mappings":{"default":{"default":"parce que"}},"category":"Sm"},{"key":"2236","mappings":{"default":{"default":"rapport"}},"category":"Sm"},{"key":"2237","mappings":{"default":{"default":"proportion"}},"category":"Sm"},{"key":"2238","mappings":{"default":{"default":"moins pointé"}},"category":"Sm"},{"key":"2239","mappings":{"default":{"default":"excès"}},"category":"Sm"},{"key":"223A","mappings":{"default":{"default":"proportion géométrique"}},"category":"Sm"},{"key":"223B","mappings":{"default":{"default":"homothétique"}},"category":"Sm"},{"key":"223C","mappings":{"default":{"default":"opérateur tilde"}},"category":"Sm"},{"key":"223D","mappings":{"default":{"default":"opérateur tilde renversé"}},"category":"Sm"},{"key":"223E","mappings":{"default":{"default":"s couché renversé"}},"category":"Sm"},{"key":"223F","mappings":{"default":{"default":"sinusoïde"}},"category":"Sm"},{"key":"2240","mappings":{"default":{"default":"produit couronne"}},"category":"Sm"},{"key":"2241","mappings":{"default":{"default":"non tilde"}},"category":"Sm"},{"key":"2242","mappings":{"default":{"default":"moins tilde"}},"category":"Sm"},{"key":"2243","mappings":{"default":{"default":"asymptotiquement égal à"}},"category":"Sm"},{"key":"2244","mappings":{"default":{"default":"non asymptotiquement égal à"}},"category":"Sm"},{"key":"2245","mappings":{"default":{"default":"approximativement égal à"}},"category":"Sm"},{"key":"2246","mappings":{"default":{"default":"approximativement mais non strictement égal à"}},"category":"Sm"},{"key":"2247","mappings":{"default":{"default":"ni approximativement ni strictement égal à"}},"category":"Sm"},{"key":"2248","mappings":{"default":{"default":"presque égal à"}},"category":"Sm"},{"key":"2249","mappings":{"default":{"default":"non presque égal à"}},"category":"Sm"},{"key":"224A","mappings":{"default":{"default":"presque égal ou égal à"}},"category":"Sm"},{"key":"224B","mappings":{"default":{"default":"triple tilde"}},"category":"Sm"},{"key":"224C","mappings":{"default":{"default":"entièrement égal à"}},"category":"Sm"},{"key":"224D","mappings":{"default":{"default":"équivalent à"}},"category":"Sm"},{"key":"224E","mappings":{"default":{"default":"géométriquement équivalent à"}},"category":"Sm"},{"key":"224F","mappings":{"default":{"default":"différence entre"}},"category":"Sm"},{"key":"2250","mappings":{"default":{"default":"tend vers la limite"}},"category":"Sm"},{"key":"2251","mappings":{"default":{"default":"géométriquement égal à"}},"category":"Sm"},{"key":"2252","mappings":{"default":{"default":"approximativement égal à ou image de"}},"category":"Sm"},{"key":"2253","mappings":{"default":{"default":"image de ou approximativement égal à"}},"category":"Sm"},{"key":"2254","mappings":{"default":{"default":"deux points égal"}},"category":"Sm"},{"key":"2255","mappings":{"default":{"default":"égal deux points"}},"category":"Sm"},{"key":"2256","mappings":{"default":{"default":"rond dans égal"}},"category":"Sm"},{"key":"2257","mappings":{"default":{"default":"égal avec rond en chef"}},"category":"Sm"},{"key":"2258","mappings":{"default":{"default":"correspond à"}},"category":"Sm"},{"key":"2259","mappings":{"default":{"default":"estime"}},"category":"Sm"},{"key":"225A","mappings":{"default":{"default":"équiangulaire à"}},"category":"Sm"},{"key":"225B","mappings":{"default":{"default":"égal avec étoile en chef"}},"category":"Sm"},{"key":"225C","mappings":{"default":{"default":"égal delta"}},"category":"Sm"},{"key":"225D","mappings":{"default":{"default":"égal par définition à"}},"category":"Sm"},{"key":"225E","mappings":{"default":{"default":"mesuré par"}},"category":"Sm"},{"key":"225F","mappings":{"default":{"default":"égalité en doute"}},"category":"Sm"},{"key":"2260","mappings":{"default":{"default":"pas égal à"}},"category":"Sm"},{"key":"2261","mappings":{"default":{"default":"identique à"}},"category":"Sm"},{"key":"2262","mappings":{"default":{"default":"non identique à"}},"category":"Sm"},{"key":"2263","mappings":{"default":{"default":"strictement équivalent à"}},"category":"Sm"},{"key":"2264","mappings":{"default":{"default":"plus petit ou égal à"}},"category":"Sm"},{"key":"2265","mappings":{"default":{"default":"plus grand ou égal à"}},"category":"Sm"},{"key":"2266","mappings":{"default":{"default":"plus petit que par dessus égal à"}},"category":"Sm"},{"key":"2267","mappings":{"default":{"default":"plus grand que par dessus égal à"}},"category":"Sm"},{"key":"2268","mappings":{"default":{"default":"plus petit mais pas égal à"}},"category":"Sm"},{"key":"2269","mappings":{"default":{"default":"plus grand mais pas égal à"}},"category":"Sm"},{"key":"226A","mappings":{"default":{"default":"beaucoup plus petit que"}},"category":"Sm"},{"key":"226B","mappings":{"default":{"default":"beaucoup plus grand que"}},"category":"Sm"},{"key":"226C","mappings":{"default":{"default":"entre"}},"category":"Sm"},{"key":"226D","mappings":{"default":{"default":"non équivalent à"}},"category":"Sm"},{"key":"226E","mappings":{"default":{"default":"pas plus petit que"}},"category":"Sm"},{"key":"226F","mappings":{"default":{"default":"pas plus grand que"}},"category":"Sm"},{"key":"2270","mappings":{"default":{"default":"ni plus petit ni égal à"}},"category":"Sm"},{"key":"2271","mappings":{"default":{"default":"ni plus grand ni égal à"}},"category":"Sm"},{"key":"2272","mappings":{"default":{"default":"plus petit ou équivalent à"}},"category":"Sm"},{"key":"2273","mappings":{"default":{"default":"plus grand ou équivalent à"}},"category":"Sm"},{"key":"2274","mappings":{"default":{"default":"ni plus petit ni équivalent à"}},"category":"Sm"},{"key":"2275","mappings":{"default":{"default":"ni plus grand ni équivalent à"}},"category":"Sm"},{"key":"2276","mappings":{"default":{"default":"plus petit ou plus grand que"}},"category":"Sm"},{"key":"2277","mappings":{"default":{"default":"plus grand ou plus petit que"}},"category":"Sm"},{"key":"2278","mappings":{"default":{"default":"ni plus petit ni plus grand que"}},"category":"Sm"},{"key":"2279","mappings":{"default":{"default":"ni plus grand ni plus petit que"}},"category":"Sm"},{"key":"227A","mappings":{"default":{"default":"précède"}},"category":"Sm"},{"key":"227B","mappings":{"default":{"default":"suit"}},"category":"Sm"},{"key":"227C","mappings":{"default":{"default":"précède ou est égal à"}},"category":"Sm"},{"key":"227D","mappings":{"default":{"default":"suit ou est égal à"}},"category":"Sm"},{"key":"227E","mappings":{"default":{"default":"précède ou est équivalent à"}},"category":"Sm"},{"key":"227F","mappings":{"default":{"default":"suit ou est équivalent à"}},"category":"Sm"},{"key":"2280","mappings":{"default":{"default":"ne précède pas"}},"category":"Sm"},{"key":"2281","mappings":{"default":{"default":"ne suit pas"}},"category":"Sm"},{"key":"2282","mappings":{"default":{"default":"sous ensemble de"}},"category":"Sm"},{"key":"2283","mappings":{"default":{"default":"sur ensemble de"}},"category":"Sm"},{"key":"2284","mappings":{"default":{"default":"pas un sous ensemble de"}},"category":"Sm"},{"key":"2285","mappings":{"default":{"default":"pas un sur ensemble de"}},"category":"Sm"},{"key":"2286","mappings":{"default":{"default":"sous ensemble ou égal à"}},"category":"Sm"},{"key":"2287","mappings":{"default":{"default":"sur ensemble ou égal à"}},"category":"Sm"},{"key":"2288","mappings":{"default":{"default":"ni un sous ensemble ni égal à"}},"category":"Sm"},{"key":"2289","mappings":{"default":{"default":"ni un sur ensemble ni égal à"}},"category":"Sm"},{"key":"228A","mappings":{"default":{"default":"sous ensemble mais pas égal à"}},"category":"Sm"},{"key":"228B","mappings":{"default":{"default":"sur ensemble mais pas égal à"}},"category":"Sm"},{"key":"228C","mappings":{"default":{"default":"multiensemble"}},"category":"Sm"},{"key":"228D","mappings":{"default":{"default":"multiplication de multiensemble"}},"category":"Sm"},{"key":"228E","mappings":{"default":{"default":"union de multiensemble"}},"category":"Sm"},{"key":"228F","mappings":{"default":{"default":"image carrée de"}},"category":"Sm"},{"key":"2290","mappings":{"default":{"default":"original carré de"}},"category":"Sm"},{"key":"2291","mappings":{"default":{"default":"image carrée ou égal à"}},"category":"Sm"},{"key":"2292","mappings":{"default":{"default":"original carré ou égal à"}},"category":"Sm"},{"key":"2293","mappings":{"default":{"default":"chapeau carré"}},"category":"Sm"},{"key":"2294","mappings":{"default":{"default":"coupe carrée"}},"category":"Sm"},{"key":"2295","mappings":{"default":{"default":"plus cerclé"}},"category":"Sm"},{"key":"2296","mappings":{"default":{"default":"moins cerclé"}},"category":"Sm"},{"key":"2297","mappings":{"default":{"default":"multiplié par cerclé"}},"category":"Sm"},{"key":"2298","mappings":{"default":{"default":"barre oblique de division cerclée"}},"category":"Sm"},{"key":"2299","mappings":{"default":{"default":"opérateur point cerclé"}},"category":"Sm"},{"key":"229A","mappings":{"default":{"default":"opérateur rond cerclé"}},"category":"Sm"},{"key":"229B","mappings":{"default":{"default":"opérateur astérisque cerclé"}},"category":"Sm"},{"key":"229C","mappings":{"default":{"default":"égal cerclé"}},"category":"Sm"},{"key":"229D","mappings":{"default":{"default":"tiret cerclé"}},"category":"Sm"},{"key":"229E","mappings":{"default":{"default":"plus encadré"}},"category":"Sm"},{"key":"229F","mappings":{"default":{"default":"moins encadré"}},"category":"Sm"},{"key":"22A0","mappings":{"default":{"default":"multiplié par encadré"}},"category":"Sm"},{"key":"22A1","mappings":{"default":{"default":"opérateur point encadré"}},"category":"Sm"},{"key":"22A2","mappings":{"default":{"default":"taquet droit"}},"category":"Sm"},{"key":"22A3","mappings":{"default":{"default":"taquet gauche"}},"category":"Sm"},{"key":"22A4","mappings":{"default":{"default":"taquet vers le bas"}},"category":"Sm"},{"key":"22A5","mappings":{"default":{"default":"taquet vers le haut"}},"category":"Sm"},{"key":"22A6","mappings":{"default":{"default":"assertion"}},"category":"Sm"},{"key":"22A7","mappings":{"default":{"default":"modélise"}},"category":"Sm"},{"key":"22A8","mappings":{"default":{"default":"vrai"}},"category":"Sm"},{"key":"22A9","mappings":{"default":{"default":"oblige"}},"category":"Sm"},{"key":"22AA","mappings":{"default":{"default":"barre verticale triple avec tourniquet à droite"}},"category":"Sm"},{"key":"22AB","mappings":{"default":{"default":"barre verticale double avec tourniquet à droite double"}},"category":"Sm"},{"key":"22AC","mappings":{"default":{"default":"ne prouve pas"}},"category":"Sm"},{"key":"22AD","mappings":{"default":{"default":"pas vrai"}},"category":"Sm"},{"key":"22AE","mappings":{"default":{"default":"n'oblige pas"}},"category":"Sm"},{"key":"22AF","mappings":{"default":{"default":"non barre verticale double avec tourniquet à droite double"}},"category":"Sm"},{"key":"22B0","mappings":{"default":{"default":"précède sous relation"}},"category":"Sm"},{"key":"22B1","mappings":{"default":{"default":"suit sous relation"}},"category":"Sm"},{"key":"22B2","mappings":{"default":{"default":"sous groupe normal de"}},"category":"Sm"},{"key":"22B3","mappings":{"default":{"default":"contient comme sous groupe normal"}},"category":"Sm"},{"key":"22B4","mappings":{"default":{"default":"sous groupe normal ou égal à"}},"category":"Sm"},{"key":"22B5","mappings":{"default":{"default":"contient comme sous groupe normal ou égal à"}},"category":"Sm"},{"key":"22B6","mappings":{"default":{"default":"original de"}},"category":"Sm"},{"key":"22B7","mappings":{"default":{"default":"image de"}},"category":"Sm"},{"key":"22B8","mappings":{"default":{"default":"multijection"}},"category":"Sm"},{"key":"22B9","mappings":{"default":{"default":"matrice hermitienne conjuguée"}},"category":"Sm"},{"key":"22BA","mappings":{"default":{"default":"intercale"}},"category":"Sm"},{"key":"22BB","mappings":{"default":{"default":"ou exclusif"}},"category":"Sm"},{"key":"22BC","mappings":{"default":{"default":"non et"}},"category":"Sm"},{"key":"22BD","mappings":{"default":{"default":"non ou"}},"category":"Sm"},{"key":"22BF","mappings":{"default":{"default":"triangle rectangle"}},"category":"Sm"},{"key":"22C0","mappings":{"default":{"default":"et logique de la famille"}},"category":"Sm"},{"key":"22C1","mappings":{"default":{"default":"ou logique de la famille"}},"category":"Sm"},{"key":"22C2","mappings":{"default":{"default":"intersection de la famille"}},"category":"Sm"},{"key":"22C3","mappings":{"default":{"default":"réunion de la famille"}},"category":"Sm"},{"key":"22C4","mappings":{"default":{"default":"opérateur losange"}},"category":"Sm"},{"key":"22C5","mappings":{"default":{"default":"opérateur point"}},"category":"Sm"},{"key":"22C6","mappings":{"default":{"default":"opérateur étoile"}},"category":"Sm"},{"key":"22C7","mappings":{"default":{"default":"divisé multiplié"}},"category":"Sm"},{"key":"22C8","mappings":{"default":{"default":"nœud papillon"}},"category":"Sm"},{"key":"22C9","mappings":{"default":{"default":"produit semi direct à gauche de facteur normal"}},"category":"Sm"},{"key":"22CA","mappings":{"default":{"default":"produit semi direct à droite de facteur normal"}},"category":"Sm"},{"key":"22CB","mappings":{"default":{"default":"produit semi direct à gauche"}},"category":"Sm"},{"key":"22CC","mappings":{"default":{"default":"produit semi direct à droite"}},"category":"Sm"},{"key":"22CD","mappings":{"default":{"default":"moins tilde renversé"}},"category":"Sm"},{"key":"22CE","mappings":{"default":{"default":"ou logique recourbé"}},"category":"Sm"},{"key":"22CF","mappings":{"default":{"default":"et logique recourbé"}},"category":"Sm"},{"key":"22D0","mappings":{"default":{"default":"sous ensemble double"}},"category":"Sm"},{"key":"22D1","mappings":{"default":{"default":"sur ensemble double"}},"category":"Sm"},{"key":"22D2","mappings":{"default":{"default":"intersection double"}},"category":"Sm"},{"key":"22D3","mappings":{"default":{"default":"union double"}},"category":"Sm"},{"key":"22D4","mappings":{"default":{"default":"fourche"}},"category":"Sm"},{"key":"22D5","mappings":{"default":{"default":"égal et parallèle à"}},"category":"Sm"},{"key":"22D6","mappings":{"default":{"default":"plus petit que pointé"}},"category":"Sm"},{"key":"22D7","mappings":{"default":{"default":"plus grand que pointé"}},"category":"Sm"},{"key":"22D8","mappings":{"default":{"default":"considérablement plus petit que"}},"category":"Sm"},{"key":"22D9","mappings":{"default":{"default":"considérablement plus grand que"}},"category":"Sm"},{"key":"22DA","mappings":{"default":{"default":"plus petit ou égal ou plus grand que"}},"category":"Sm"},{"key":"22DB","mappings":{"default":{"default":"plus grand ou égal ou plus petit que"}},"category":"Sm"},{"key":"22DC","mappings":{"default":{"default":"égal ou plus petit que"}},"category":"Sm"},{"key":"22DD","mappings":{"default":{"default":"égal à deux lignes ou supérieur à"}},"category":"Sm"},{"key":"22DE","mappings":{"default":{"default":"égal ou précède"}},"category":"Sm"},{"key":"22DF","mappings":{"default":{"default":"égal ou suit"}},"category":"Sm"},{"key":"22E0","mappings":{"default":{"default":"ni précédant ni égal à"}},"category":"Sm"},{"key":"22E1","mappings":{"default":{"default":"ni suivant ni égal à"}},"category":"Sm"},{"key":"22E2","mappings":{"default":{"default":"ni image carrée ni égal à"}},"category":"Sm"},{"key":"22E3","mappings":{"default":{"default":"ni original carré ni égal à"}},"category":"Sm"},{"key":"22E4","mappings":{"default":{"default":"image carré ou différent de"}},"category":"Sm"},{"key":"22E5","mappings":{"default":{"default":"original carré ou différent de"}},"category":"Sm"},{"key":"22E6","mappings":{"default":{"default":"plus petit mais non équivalent à"}},"category":"Sm"},{"key":"22E7","mappings":{"default":{"default":"plus grand mais non équivalent à"}},"category":"Sm"},{"key":"22E8","mappings":{"default":{"default":"précédant mais non équivalent à"}},"category":"Sm"},{"key":"22E9","mappings":{"default":{"default":"suivant mais non équivalent à"}},"category":"Sm"},{"key":"22EA","mappings":{"default":{"default":"pas un sous groupe normal de"}},"category":"Sm"},{"key":"22EB","mappings":{"default":{"default":"ne contient pas comme sous groupe normal"}},"category":"Sm"},{"key":"22EC","mappings":{"default":{"default":"ni sous groupe normal ni égal à"}},"category":"Sm"},{"key":"22ED","mappings":{"default":{"default":"ni égal ni contenant comme sous  groupe normal"}},"category":"Sm"},{"key":"22EE","mappings":{"default":{"default":"trois points suspendus"}},"category":"Sm"},{"key":"22EF","mappings":{"default":{"default":"trois points médians"}},"category":"Sm"},{"key":"22F0","mappings":{"default":{"default":"trois points diagonaux vers le coin haut à droite"}},"category":"Sm"},{"key":"22F1","mappings":{"default":{"default":"trois points diagonaux vers le coin bas à droite"}},"category":"Sm"},{"key":"22F2","mappings":{"default":{"default":"appartient à avec long trait horizontal"}},"category":"Sm"},{"key":"22F3","mappings":{"default":{"default":"appartient à avec barre verticale au bout du trait horizontal"}},"category":"Sm"},{"key":"22F4","mappings":{"default":{"default":"petit appartient à avec barre verticale au bout du trait horizontal"}},"category":"Sm"},{"key":"22F5","mappings":{"default":{"default":"appartient à avec point en chef"}},"category":"Sm"},{"key":"22F6","mappings":{"default":{"default":"appartient à avec trait en chef"}},"category":"Sm"},{"key":"22F7","mappings":{"default":{"default":"petit appartient à avec trait en chef"}},"category":"Sm"},{"key":"22F8","mappings":{"default":{"default":"appartient à avec trait souscrit"}},"category":"Sm"},{"key":"22F9","mappings":{"default":{"default":"appartient à avec deux traits horizontaux"}},"category":"Sm"},{"key":"22FA","mappings":{"default":{"default":"contient avec long trait horizontal"}},"category":"Sm"},{"key":"22FB","mappings":{"default":{"default":"contient avec barre verticale au bout du trait horizontal"}},"category":"Sm"},{"key":"22FC","mappings":{"default":{"default":"petit contient avec barre verticale au bout du trait horizontal"}},"category":"Sm"},{"key":"22FD","mappings":{"default":{"default":"contient avec trait en chef"}},"category":"Sm"},{"key":"22FE","mappings":{"default":{"default":"petit contient avec trait en chef"}},"category":"Sm"},{"key":"22FF","mappings":{"default":{"default":"appartient à un sac en notation z"}},"category":"Sm"},{"key":"2300","mappings":{"default":{"default":"diamètre"}},"category":"So"},{"key":"2302","mappings":{"default":{"default":"maison"}},"category":"So"},{"key":"2305","mappings":{"default":{"default":"projective"}},"category":"So"},{"key":"2306","mappings":{"default":{"default":"perspective"}},"category":"So"},{"category":"So","key":"2307","mappings":{"default":{"default":"ligne ondulée"}}},{"key":"2310","mappings":{"default":{"default":"négation réfléchi"}},"category":"So"},{"category":"So","key":"2311","mappings":{"default":{"default":"pastille carrée"}}},{"key":"2312","mappings":{"default":{"default":"arc"}},"category":"So"},{"key":"2313","mappings":{"default":{"default":"segment"}},"category":"So"},{"category":"So","key":"2314","mappings":{"default":{"default":"secteur"}}},{"category":"So","key":"2795","mappings":{"default":{"default":"plus gras"}}},{"category":"So","key":"2796","mappings":{"default":{"default":"moins gras"}}},{"category":"So","key":"2797","mappings":{"default":{"default":"division gras"}}},{"category":"So","key":"27B0","mappings":{"default":{"default":"boucle recourbée"}}},{"category":"So","key":"27BF","mappings":{"default":{"default":"double boucle recourbée"}}},{"key":"27C1","mappings":{"default":{"default":"petit triangle blanc inscrit dans triangle blanc"}},"category":"Sm"},{"key":"27C2","mappings":{"default":{"default":"perpendiculaire à"}},"category":"Sm"},{"key":"27C3","mappings":{"default":{"default":"sous ensemble ouvert"}},"category":"Sm"},{"key":"27C4","mappings":{"default":{"default":"sur ensemble ouvert"}},"category":"Sm"},{"key":"27C7","mappings":{"default":{"default":"ou avec point inscrit"}},"category":"Sm"},{"key":"27C8","mappings":{"default":{"default":"sous ensemble précédé d'une barre oblique inversée"}},"category":"Sm"},{"key":"27C9","mappings":{"default":{"default":"sur ensemble suivi d'une barre oblique"}},"category":"Sm"},{"key":"27CA","mappings":{"default":{"default":"barre verticale À une traverse"}},"category":"Sm"},{"category":"Sm","key":"27CB","mappings":{"default":{"default":"diagonale mathématique ascendante"}}},{"key":"27CC","mappings":{"default":{"default":"grande division"}},"category":"Sm"},{"category":"Sm","key":"27CD","mappings":{"default":{"default":"diagonale mathématique descendante"}}},{"category":"Sm","key":"27CE","mappings":{"default":{"default":"et logique encadré"}}},{"category":"Sm","key":"27CF","mappings":{"default":{"default":"ou logique encadré"}}},{"category":"Sm","key":"27D0","mappings":{"default":{"default":"losange blanc à point centré"}}},{"key":"27D1","mappings":{"default":{"default":"et pointé"}},"category":"Sm"},{"key":"27D2","mappings":{"default":{"default":"appartient À ouvert vers le haut"}},"category":"Sm"},{"key":"27D3","mappings":{"default":{"default":"coin inférieur droit pointé"}},"category":"Sm"},{"key":"27D4","mappings":{"default":{"default":"coin supérieur gauche pointé"}},"category":"Sm"},{"key":"27D5","mappings":{"default":{"default":"jointure externe gauche"}},"category":"Sm"},{"key":"27D6","mappings":{"default":{"default":"jointure externe droite"}},"category":"Sm"},{"key":"27D7","mappings":{"default":{"default":"jointure externe complète"}},"category":"Sm"},{"key":"27D8","mappings":{"default":{"default":"grand taquet vers le haut"}},"category":"Sm"},{"key":"27D9","mappings":{"default":{"default":"grand taquet vers le bas"}},"category":"Sm"},{"key":"27DA","mappings":{"default":{"default":"double tourniquet bilatéral"}},"category":"Sm"},{"key":"27DB","mappings":{"default":{"default":"tourniquet bilatéral"}},"category":"Sm"},{"key":"27DC","mappings":{"default":{"default":"multijection gauche"}},"category":"Sm"},{"key":"27DD","mappings":{"default":{"default":"long taquet droit"}},"category":"Sm"},{"key":"27DE","mappings":{"default":{"default":"long taquet gauche"}},"category":"Sm"},{"key":"27DF","mappings":{"default":{"default":"taquet vers le haut surmonté d'un cercle"}},"category":"Sm"},{"key":"27E0","mappings":{"default":{"default":"losange coupé"}},"category":"Sm"},{"key":"27E1","mappings":{"default":{"default":"losange concave blanc"}},"category":"Sm"},{"key":"27E2","mappings":{"default":{"default":"losange concave blanc avec trait à gauche"}},"category":"Sm"},{"key":"27E3","mappings":{"default":{"default":"losange concave blanc avec trait à droite"}},"category":"Sm"},{"key":"27E4","mappings":{"default":{"default":"carré blanc avec trait à gauche"}},"category":"Sm"},{"key":"27E5","mappings":{"default":{"default":"carré blanc avec trait à droite"}},"category":"Sm"},{"category":"Sm","key":"292B","mappings":{"default":{"default":"diagonale montante sur diagonale descendante"}}},{"category":"Sm","key":"292C","mappings":{"default":{"default":"diagonale descendante sur diagonale montante"}}},{"category":"Sm","key":"2980","mappings":{"default":{"default":"délimiteur triple barre verticale"}}},{"category":"Sm","key":"2981","mappings":{"default":{"default":"boulet"}}},{"category":"Sm","key":"2982","mappings":{"default":{"default":"deux points de la notation z"}}},{"category":"Sm","key":"2999","mappings":{"default":{"default":"clôture pointillée"}}},{"key":"299A","mappings":{"default":{"default":"ligne verticale en zigzag"}},"category":"Sm"},{"key":"29B0","mappings":{"default":{"default":"ensemble vide réfléchi"}},"category":"Sm"},{"key":"29B1","mappings":{"default":{"default":"ensemble vide barre en chef"}},"category":"Sm"},{"key":"29B2","mappings":{"default":{"default":"ensemble vide petit cercle en chef"}},"category":"Sm"},{"key":"29B5","mappings":{"default":{"default":"cercle à barre horizontale"}},"category":"Sm"},{"key":"29B6","mappings":{"default":{"default":"barre verticale cerclée"}},"category":"Sm"},{"key":"29B7","mappings":{"default":{"default":"parallèles cerclées"}},"category":"Sm"},{"category":"Sm","key":"29B8","mappings":{"default":{"default":"barre oblique inversée cerclée"}}},{"key":"29B9","mappings":{"default":{"default":"perpendiculaire cerclé"}},"category":"Sm"},{"category":"Sm","key":"29BA","mappings":{"default":{"default":"cercle divisé par une barre horizontale et une barre verticale dans la moitié supérieure"}}},{"key":"29BB","mappings":{"default":{"default":"cercle superposé d'un x"}},"category":"Sm"},{"key":"29BC","mappings":{"default":{"default":"division pivoté en sens antihoraire cerclé"}},"category":"Sm"},{"key":"29BE","mappings":{"default":{"default":"puce blanche cerclée"}},"category":"Sm"},{"key":"29BF","mappings":{"default":{"default":"puce cerclée"}},"category":"Sm"},{"key":"29C0","mappings":{"default":{"default":"inférieur à cerclé"}},"category":"Sm"},{"key":"29C1","mappings":{"default":{"default":"supérieur à cerclé"}},"category":"Sm"},{"key":"29C2","mappings":{"default":{"default":"cercle avec petit cercle à droite"}},"category":"Sm"},{"key":"29C3","mappings":{"default":{"default":"cercle avec deux petits traits horizontaux à droite"}},"category":"Sm"},{"key":"29C4","mappings":{"default":{"default":"oblique encadrée"}},"category":"Sm"},{"key":"29C5","mappings":{"default":{"default":"oblique inversée encadrée"}},"category":"Sm"},{"category":"Sm","key":"29C6","mappings":{"default":{"default":"astérisque encadré"}}},{"category":"Sm","key":"29C7","mappings":{"default":{"default":"petite cercle encadré"}}},{"category":"Sm","key":"29C8","mappings":{"default":{"default":"carré encadré"}}},{"key":"29C9","mappings":{"default":{"default":"carrés se chevauchant"}},"category":"Sm"},{"category":"Sm","key":"29CA","mappings":{"default":{"default":"triangle pointé en chef"}}},{"category":"Sm","key":"29CB","mappings":{"default":{"default":"triangle à barre souscrite"}}},{"category":"Sm","key":"29CC","mappings":{"default":{"default":"s inscrit dans triangle"}}},{"key":"29CD","mappings":{"default":{"default":"triangle à empattements inférieurs"}},"category":"Sm"},{"key":"29CE","mappings":{"default":{"default":"triangle droit par dessus triangle gauche"}},"category":"Sm"},{"key":"29CF","mappings":{"default":{"default":"triangle gauche à gauche d'une barre verticale"}},"category":"Sm"},{"key":"29D0","mappings":{"default":{"default":"triangle droit à droite d'une barre verticale"}},"category":"Sm"},{"category":"Sm","key":"29D1","mappings":{"default":{"default":"nœud papillon à aile gauche noire"}}},{"category":"Sm","key":"29D2","mappings":{"default":{"default":"nœud papillon à aile droite noire"}}},{"category":"Sm","key":"29D3","mappings":{"default":{"default":"nœud papillon noir"}}},{"category":"Sm","key":"29D4","mappings":{"default":{"default":"multiplication à moitié gauche noircie"}}},{"category":"Sm","key":"29D5","mappings":{"default":{"default":"multiplication à moitié droite noircie"}}},{"category":"Sm","key":"29D6","mappings":{"default":{"default":"sablier blanc"}}},{"category":"Sm","key":"29D7","mappings":{"default":{"default":"sablier noir"}}},{"key":"29DC","mappings":{"default":{"default":"infini incomplet"}},"category":"Sm"},{"category":"Sm","key":"29DD","mappings":{"default":{"default":"lorgnon"}}},{"key":"29DE","mappings":{"default":{"default":"infini nié par une barre verticale"}},"category":"Sm"},{"category":"Sm","key":"29DF","mappings":{"default":{"default":"multijection à deux têtes"}}},{"category":"Sm","key":"29E0","mappings":{"default":{"default":"carré ombré"}}},{"category":"Sm","key":"29E1","mappings":{"default":{"default":"augmente avec"}}},{"category":"Sm","key":"29E2","mappings":{"default":{"default":"produit de permutation"}}},{"key":"29E3","mappings":{"default":{"default":"égale à et parallèle à incliné"}},"category":"Sm"},{"key":"29E4","mappings":{"default":{"default":"égale à et parallèle à incliné surmontés d'un tilde"}},"category":"Sm"},{"key":"29E5","mappings":{"default":{"default":"identique à et parallèle à incliné"}},"category":"Sm"},{"category":"Sm","key":"29E6","mappings":{"default":{"default":"gleich stark"}}},{"category":"Sm","key":"29E7","mappings":{"default":{"default":"thermodynamique"}}},{"category":"Sm","key":"29E8","mappings":{"default":{"default":"triangle pointe vers le bas à moitié gauche noire"}}},{"category":"Sm","key":"29E9","mappings":{"default":{"default":"triangle pointe vers le bas à moitié droite noire"}}},{"key":"29EB","mappings":{"default":{"default":"losange fuselé noir"}},"category":"Sm"},{"category":"Sm","key":"29EE","mappings":{"default":{"default":"barre d'erreur à carré blanc"}}},{"category":"Sm","key":"29EF","mappings":{"default":{"default":"barre d'erreur à carré noir"}}},{"category":"Sm","key":"29F0","mappings":{"default":{"default":"barre d'erreur à losange blanc"}}},{"category":"Sm","key":"29F1","mappings":{"default":{"default":"barre d'erreur à losange noir"}}},{"category":"Sm","key":"29F2","mappings":{"default":{"default":"barre d'erreur à cercle blanc"}}},{"category":"Sm","key":"29F3","mappings":{"default":{"default":"barre d'erreur à cercle noir"}}},{"key":"29F4","mappings":{"default":{"default":"règle différée"}},"category":"Sm"},{"category":"Sm","key":"29F5","mappings":{"default":{"default":"opérateur barre oblique inversée"}}},{"key":"29F6","mappings":{"default":{"default":"barre oblique avec barre en chef"}},"category":"Sm"},{"category":"Sm","key":"29F7","mappings":{"default":{"default":"barre oblique inversée à traverse horizontale"}}},{"category":"Sm","key":"29F8","mappings":{"default":{"default":"grande barre oblique"}}},{"category":"Sm","key":"29F9","mappings":{"default":{"default":"grande barre oblique inversée"}}},{"category":"Sm","key":"29FA","mappings":{"default":{"default":"double plus"}}},{"category":"Sm","key":"29FB","mappings":{"default":{"default":"triple plus"}}},{"category":"Sm","key":"29FE","mappings":{"default":{"default":"tiny"}}},{"category":"Sm","key":"29FF","mappings":{"default":{"default":"miny"}}},{"category":"Sm","key":"2A00","mappings":{"default":{"default":"opérateur point cerclé n aire"}}},{"category":"Sm","key":"2A01","mappings":{"default":{"default":"opérateur plus cerclé n aire"}}},{"category":"Sm","key":"2A02","mappings":{"default":{"default":"opérateur multiplié par cerclé n aire"}}},{"category":"Sm","key":"2A03","mappings":{"default":{"default":"opérateur union n aire pointé"}}},{"category":"Sm","key":"2A04","mappings":{"default":{"default":"opérateur union n aire avec plus"}}},{"category":"Sm","key":"2A05","mappings":{"default":{"default":"opérateur intersection carré n aire"}}},{"category":"Sm","key":"2A06","mappings":{"default":{"default":"opérateur union carré n aire"}}},{"category":"Sm","key":"2A07","mappings":{"default":{"default":"opérateur deux et logiques"}}},{"category":"Sm","key":"2A08","mappings":{"default":{"default":"opérateur deux ou logiques"}}},{"category":"Sm","key":"2A09","mappings":{"default":{"default":"opérateur multiplié par n aire"}}},{"category":"Sm","key":"2A0A","mappings":{"default":{"default":"sommation modulo deux"}}},{"category":"Sm","key":"2A0B","mappings":{"default":{"default":"sommation avec intégrale"}}},{"key":"2A0C","mappings":{"default":{"default":"intégrale quadruple"}},"category":"Sm"},{"key":"2A0D","mappings":{"default":{"default":"intégrale à partie finie"}},"category":"Sm"},{"category":"Sm","key":"2A0E","mappings":{"default":{"default":"intégrale à deux barres horizontales"}}},{"category":"Sm","key":"2A0F","mappings":{"default":{"default":"moyenne d'intégrale à barre oblique inversée"}}},{"key":"2A10","mappings":{"default":{"default":"fonction de circulation"}},"category":"Sm"},{"key":"2A11","mappings":{"default":{"default":"intégrale en sens positif"}},"category":"Sm"},{"key":"2A12","mappings":{"default":{"default":"intégrale de ligne à chemin rectangulaire autour du pôle"}},"category":"Sm"},{"key":"2A13","mappings":{"default":{"default":"intégrale de ligne à chemin semi circulaire autour du pôle"}},"category":"Sm"},{"key":"2A14","mappings":{"default":{"default":"intégrale de ligne évitant le pôle"}},"category":"Sm"},{"key":"2A15","mappings":{"default":{"default":"intégrale autour d'un opérateur point"}},"category":"Sm"},{"key":"2A16","mappings":{"default":{"default":"intégrale quaternion"}},"category":"Sm"},{"category":"Sm","key":"2A18","mappings":{"default":{"default":"intégrale au signe multiplié par"}}},{"category":"Sm","key":"2A19","mappings":{"default":{"default":"intégrale à signe intersection"}}},{"category":"Sm","key":"2A1A","mappings":{"default":{"default":"intégrale à signe union"}}},{"category":"Sm","key":"2A1B","mappings":{"default":{"default":"intégrale à barre en chef"}}},{"category":"Sm","key":"2A1C","mappings":{"default":{"default":"intégrale à barre souscrite"}}},{"category":"Sm","key":"2A1D","mappings":{"default":{"default":"jointure"}}},{"category":"Sm","key":"2A1E","mappings":{"default":{"default":"gros opérateur triangle gauche"}}},{"category":"Sm","key":"2A1F","mappings":{"default":{"default":"composition de schémas en notation z"}}},{"category":"Sm","key":"2A20","mappings":{"default":{"default":"tubage de schémas en notation z"}}},{"category":"Sm","key":"2A21","mappings":{"default":{"default":"projection de schémas en notation z"}}},{"key":"2A22","mappings":{"default":{"default":"plus surmonté d'un petit cercle"}},"category":"Sm"},{"key":"2A23","mappings":{"default":{"default":"plus surmonté d'un circonflexe"}},"category":"Sm"},{"key":"2A24","mappings":{"default":{"default":"plus surmonté d'un tilde"}},"category":"Sm"},{"key":"2A25","mappings":{"default":{"default":"plus à point souscrit"}},"category":"Sm"},{"key":"2A26","mappings":{"default":{"default":"plus à tilde souscrit"}},"category":"Sm"},{"key":"2A27","mappings":{"default":{"default":"plus à chiffre deux souscrit"}},"category":"Sm"},{"category":"Sm","key":"2A28","mappings":{"default":{"default":"plus à triangle noir"}}},{"key":"2A29","mappings":{"default":{"default":"moins surmonté d'une virgule"}},"category":"Sm"},{"key":"2A2A","mappings":{"default":{"default":"moins à point souscrit"}},"category":"Sm"},{"category":"Sm","key":"2A2B","mappings":{"default":{"default":"moins à points descendants"}}},{"category":"Sm","key":"2A2C","mappings":{"default":{"default":"moins à points ascendants"}}},{"key":"2A2D","mappings":{"default":{"default":"plus dans demi cercle gauche"}},"category":"Sm"},{"key":"2A2E","mappings":{"default":{"default":"plus dans demi cercle droit"}},"category":"Sm"},{"key":"2A2F","mappings":{"default":{"default":"produit vectoriel"}},"category":"Sm"},{"key":"2A30","mappings":{"default":{"default":"multiplication à point en chef"}},"category":"Sm"},{"key":"2A31","mappings":{"default":{"default":"multiplication à barre souscrite"}},"category":"Sm"},{"category":"Sm","key":"2A32","mappings":{"default":{"default":"produit semi direct fermé en bas"}}},{"key":"2A33","mappings":{"default":{"default":"produit fusionné"}},"category":"Sm"},{"key":"2A34","mappings":{"default":{"default":"multiplication dans demi cercle gauche"}},"category":"Sm"},{"key":"2A35","mappings":{"default":{"default":"multiplication dans demi cercle droit"}},"category":"Sm"},{"key":"2A36","mappings":{"default":{"default":"multiplication cerclé circonflexe"}},"category":"Sm"},{"key":"2A37","mappings":{"default":{"default":"multiplication doublement cerclé"}},"category":"Sm"},{"key":"2A38","mappings":{"default":{"default":"division cerclé"}},"category":"Sm"},{"key":"2A39","mappings":{"default":{"default":"plus dans triangle"}},"category":"Sm"},{"key":"2A3A","mappings":{"default":{"default":"moins dans triangle"}},"category":"Sm"},{"key":"2A3B","mappings":{"default":{"default":"multiplication dans triangle"}},"category":"Sm"},{"key":"2A3C","mappings":{"default":{"default":"produit interieur"}},"category":"Sm"},{"category":"Sm","key":"2A3D","mappings":{"default":{"default":"produit intérieur à droite"}}},{"category":"Sm","key":"2A3E","mappings":{"default":{"default":"composition relationnelle en notation z"}}},{"key":"2A3F","mappings":{"default":{"default":"amalgamation ou coproduit"}},"category":"Sm"},{"key":"2A40","mappings":{"default":{"default":"intersection pointée"}},"category":"Sm"},{"category":"Sm","key":"2A41","mappings":{"default":{"default":"union à signe moins"}}},{"key":"2A42","mappings":{"default":{"default":"union à barre en chef"}},"category":"Sm"},{"key":"2A43","mappings":{"default":{"default":"intersection à barre en chef"}},"category":"Sm"},{"key":"2A44","mappings":{"default":{"default":"intersection avec et logique"}},"category":"Sm"},{"key":"2A45","mappings":{"default":{"default":"union avec ou logique"}},"category":"Sm"},{"key":"2A46","mappings":{"default":{"default":"union par dessus intersection"}},"category":"Sm"},{"key":"2A47","mappings":{"default":{"default":"intersection par dessus union"}},"category":"Sm"},{"key":"2A48","mappings":{"default":{"default":"union par dessus bar par dessus intersection"}},"category":"Sm"},{"key":"2A49","mappings":{"default":{"default":"intersection par dessus trait par dessus union"}},"category":"Sm"},{"key":"2A4A","mappings":{"default":{"default":"deux unions soudées côte à côte"}},"category":"Sm"},{"key":"2A4B","mappings":{"default":{"default":"deux intersections soudées côte à côte"}},"category":"Sm"},{"key":"2A4C","mappings":{"default":{"default":"union fermée à empattements"}},"category":"Sm"},{"key":"2A4D","mappings":{"default":{"default":"intersection fermée à empattements"}},"category":"Sm"},{"category":"Sm","key":"2A4E","mappings":{"default":{"default":"deux intersections carrées emboîtées"}}},{"category":"Sm","key":"2A4F","mappings":{"default":{"default":"deux unions carrées emboîtées"}}},{"key":"2A50","mappings":{"default":{"default":"union fermée à empattements et produit fusionné"}},"category":"Sm"},{"category":"Sm","key":"2A51","mappings":{"default":{"default":"et logique à point en chef"}}},{"category":"Sm","key":"2A52","mappings":{"default":{"default":"ou logique à point en chef"}}},{"key":"2A53","mappings":{"default":{"default":"double et logique"}},"category":"Sm"},{"key":"2A54","mappings":{"default":{"default":"double ou logique"}},"category":"Sm"},{"key":"2A55","mappings":{"default":{"default":"deux et logiques entrecroisés"}},"category":"Sm"},{"key":"2A56","mappings":{"default":{"default":"deux ou logiques entrecroisés"}},"category":"Sm"},{"key":"2A57","mappings":{"default":{"default":"grand ou pentu"}},"category":"Sm"},{"key":"2A58","mappings":{"default":{"default":"grand et pentu"}},"category":"Sm"},{"category":"Sm","key":"2A59","mappings":{"default":{"default":"et et ou logiques entrecroisés"}}},{"key":"2A5A","mappings":{"default":{"default":"et logique à hampe médiane"}},"category":"Sm"},{"key":"2A5B","mappings":{"default":{"default":"ou logique à hampe médiane"}},"category":"Sm"},{"key":"2A5C","mappings":{"default":{"default":"et logique à tiret horizontal"}},"category":"Sm"},{"key":"2A5D","mappings":{"default":{"default":"ou logique à tiret horizontal"}},"category":"Sm"},{"category":"Sm","key":"2A5E","mappings":{"default":{"default":"et logique à deux barres en chef"}}},{"key":"2A5F","mappings":{"default":{"default":"et logique à barre souscrite"}},"category":"Sm"},{"category":"Sm","key":"2A60","mappings":{"default":{"default":"et logique à deux barres souscrites"}}},{"category":"Sm","key":"2A61","mappings":{"default":{"default":"petit v à barre souscrite"}}},{"category":"Sm","key":"2A62","mappings":{"default":{"default":"ou logique à deux barres en chef"}}},{"category":"Sm","key":"2A63","mappings":{"default":{"default":"ou logique à deux barres souscrites"}}},{"category":"Sm","key":"2A64","mappings":{"default":{"default":"antirestriction de domaine en notation z"}}},{"category":"Sm","key":"2A65","mappings":{"default":{"default":"antirestriction de codomaine en notation z"}}},{"key":"2A66","mappings":{"default":{"default":"égal point souscrit"}},"category":"Sm"},{"category":"Sm","key":"2A67","mappings":{"default":{"default":"identique à surmonté d'un point"}}},{"category":"Sm","key":"2A68","mappings":{"default":{"default":"deux barres verticales à trois traverses"}}},{"category":"Sm","key":"2A69","mappings":{"default":{"default":"trois barres verticales à trois traverses"}}},{"key":"2A6A","mappings":{"default":{"default":"opérateur tilde point en chef"}},"category":"Sm"},{"category":"Sm","key":"2A6B","mappings":{"default":{"default":"opérateur tilde à points ascendants"}}},{"category":"Sm","key":"2A6C","mappings":{"default":{"default":"similaire à moins similaire à"}}},{"key":"2A6D","mappings":{"default":{"default":"congruent point en chef"}},"category":"Sm"},{"category":"Sm","key":"2A6E","mappings":{"default":{"default":"Égal astérisque en chef"}}},{"key":"2A6F","mappings":{"default":{"default":"presque égal à circonflexe"}},"category":"Sm"},{"category":"Sm","key":"2A70","mappings":{"default":{"default":"approximativement égal à ou égal à"}}},{"key":"2A71","mappings":{"default":{"default":"plus signe égal en chef"}},"category":"Sm"},{"key":"2A72","mappings":{"default":{"default":"égal à signe plus en chef"}},"category":"Sm"},{"key":"2A73","mappings":{"default":{"default":"tilde signe égal en chef"}},"category":"Sm"},{"key":"2A74","mappings":{"default":{"default":"double deux points égal à"}},"category":"Sm"},{"key":"2A75","mappings":{"default":{"default":"deux signes égal à consécutifs"}},"category":"Sm"},{"category":"Sm","key":"2A76","mappings":{"default":{"default":"trois signes égal à consécutifs"}}},{"key":"2A77","mappings":{"default":{"default":"égal à deux points en chef deux points souscrits"}},"category":"Sm"},{"key":"2A78","mappings":{"default":{"default":"équivalent quatre points en chef"}},"category":"Sm"},{"key":"2A79","mappings":{"default":{"default":"inférieur à avec cercle inscrit"}},"category":"Sm"},{"key":"2A7A","mappings":{"default":{"default":"supérieur à avec cercle inscrit"}},"category":"Sm"},{"key":"2A7B","mappings":{"default":{"default":"inférieur à point d'interrogation en chef"}},"category":"Sm"},{"key":"2A7C","mappings":{"default":{"default":"supérieur à point d'interrogation en chef"}},"category":"Sm"},{"key":"2A7D","mappings":{"default":{"default":"plus petit ou égal à pentu"}},"category":"Sm"},{"key":"2A7E","mappings":{"default":{"default":"supérieur à ou égal à pentu"}},"category":"Sm"},{"key":"2A7F","mappings":{"default":{"default":"inférieur à ou égal à pentu point inscrit"}},"category":"Sm"},{"key":"2A80","mappings":{"default":{"default":"supérieur à ou égal à pentu point inscrit"}},"category":"Sm"},{"key":"2A81","mappings":{"default":{"default":"inférieur à ou égal à pentu point en chef"}},"category":"Sm"},{"key":"2A82","mappings":{"default":{"default":"supérieur à ou égal à pentu point en chef"}},"category":"Sm"},{"key":"2A83","mappings":{"default":{"default":"inférieur à ou égal à pentu point en chef droit"}},"category":"Sm"},{"key":"2A84","mappings":{"default":{"default":"supérieur à ou égal à pentu point en chef gauche"}},"category":"Sm"},{"category":"Sm","key":"2A85","mappings":{"default":{"default":"inférieur à ou approximatif"}}},{"category":"Sm","key":"2A86","mappings":{"default":{"default":"supérieur à ou approximatif"}}},{"category":"Sm","key":"2A87","mappings":{"default":{"default":"inférieur à et pas égal à une ligne"}}},{"category":"Sm","key":"2A88","mappings":{"default":{"default":"supérieur à et pas égal à une ligne"}}},{"key":"2A89","mappings":{"default":{"default":"inférieur à et non approximatif"}},"category":"Sm"},{"key":"2A8A","mappings":{"default":{"default":"supérieur à et non approximatif"}},"category":"Sm"},{"category":"Sm","key":"2A8B","mappings":{"default":{"default":"inférieur à par dessus égal à deux lignes par dessus supérieur à"}}},{"category":"Sm","key":"2A8C","mappings":{"default":{"default":"supérieur à par dessus égal à deux lignes par dessus inférieur à"}}},{"key":"2A8D","mappings":{"default":{"default":"inférieur à par dessus similaire à ou égal à"}},"category":"Sm"},{"key":"2A8E","mappings":{"default":{"default":"supérieur à par dessus similaire à ou égal à"}},"category":"Sm"},{"key":"2A8F","mappings":{"default":{"default":"inférieur à par dessus similaire à par dessus supérieur à"}},"category":"Sm"},{"key":"2A90","mappings":{"default":{"default":"supérieur à par dessus similaire à par dessus inférieur à"}},"category":"Sm"},{"key":"2A91","mappings":{"default":{"default":"inférieur à par dessus supérieur à par dessus égal à deux lignes"}},"category":"Sm"},{"key":"2A92","mappings":{"default":{"default":"supérieur à par dessus inférieur à par dessus égal à deux lignes"}},"category":"Sm"},{"key":"2A93","mappings":{"default":{"default":"inférieur à par dessus égal à pentu par dessus supérieur à par dessus égal à pentu"}},"category":"Sm"},{"key":"2A94","mappings":{"default":{"default":"supérieur à par dessus égal à pentu par dessus inférieur à par dessus égal à pentu"}},"category":"Sm"},{"category":"Sm","key":"2A95","mappings":{"default":{"default":"Égal à incliné ou inférieur à"}}},{"category":"Sm","key":"2A96","mappings":{"default":{"default":"Égal à incliné ou supérieur à"}}},{"key":"2A97","mappings":{"default":{"default":"égal à pentu ou inférieur à point inscrit"}},"category":"Sm"},{"key":"2A98","mappings":{"default":{"default":"égal à pentu ou supérieur à point inscrit"}},"category":"Sm"},{"key":"2A99","mappings":{"default":{"default":"égal à deux lignes ou inférieur à"}},"category":"Sm"},{"key":"2A9A","mappings":{"default":{"default":"égal à deux lignes ou supérieur à"}},"category":"Sm"},{"category":"Sm","key":"2A9B","mappings":{"default":{"default":"inférieur à ou égal à à deux lignes inclinées"}}},{"category":"Sm","key":"2A9C","mappings":{"default":{"default":"supérieur à ou égal à à deux lignes inclinées"}}},{"key":"2A9D","mappings":{"default":{"default":"similaire à ou inférieur à"}},"category":"Sm"},{"key":"2A9E","mappings":{"default":{"default":"similaire à ou supérieur à"}},"category":"Sm"},{"key":"2A9F","mappings":{"default":{"default":"similaire à par dessus inférieur à par dessus signe égal"}},"category":"Sm"},{"key":"2AA0","mappings":{"default":{"default":"similaire à par dessus supérieur à par dessus signe égal"}},"category":"Sm"},{"key":"2AA1","mappings":{"default":{"default":"deux inférieur à emboîtés"}},"category":"Sm"},{"key":"2AA2","mappings":{"default":{"default":"deux supérieur à emboîtés"}},"category":"Sm"},{"category":"Sm","key":"2AA3","mappings":{"default":{"default":"deux inférieur à emboîtés avec barre souscrite"}}},{"key":"2AA4","mappings":{"default":{"default":"deux supérieur à entrecroisés"}},"category":"Sm"},{"key":"2AA5","mappings":{"default":{"default":"supérieur à à côté de inférieur à"}},"category":"Sm"},{"key":"2AA6","mappings":{"default":{"default":"inférieur à fermé d'un arc"}},"category":"Sm"},{"key":"2AA7","mappings":{"default":{"default":"supérieur à fermé d'un arc"}},"category":"Sm"},{"key":"2AA8","mappings":{"default":{"default":"inférieur à fermé d'un arc par dessus égal à pentu"}},"category":"Sm"},{"key":"2AA9","mappings":{"default":{"default":"supérieur à fermé d'un arc par dessus égal à pentu"}},"category":"Sm"},{"key":"2AAA","mappings":{"default":{"default":"plus petit que en fourche"}},"category":"Sm"},{"key":"2AAB","mappings":{"default":{"default":"plus grand que en fourche"}},"category":"Sm"},{"key":"2AAC","mappings":{"default":{"default":"plus petit ou égal que en fourche"}},"category":"Sm"},{"key":"2AAD","mappings":{"default":{"default":"plus grand ou égal que en fourche"}},"category":"Sm"},{"key":"2AAE","mappings":{"default":{"default":"égal et dos d'âne"}},"category":"Sm"},{"key":"2AAF","mappings":{"default":{"default":"précède par dessus signe égal à une ligne"}},"category":"Sm"},{"category":"Sm","key":"2AB0","mappings":{"default":{"default":"suit par dessus signe égal à une ligne"}}},{"category":"Sm","key":"2AB1","mappings":{"default":{"default":"précède par dessus pas égal à une ligne"}}},{"category":"Sm","key":"2AB2","mappings":{"default":{"default":"suit par dessus pas égal à une ligne"}}},{"category":"Sm","key":"2AB3","mappings":{"default":{"default":"précède par dessus signe égal"}}},{"category":"Sm","key":"2AB4","mappings":{"default":{"default":"suit par dessus signe égal"}}},{"key":"2AB5","mappings":{"default":{"default":"précède par dessus pas égal à"}},"category":"Sm"},{"key":"2AB6","mappings":{"default":{"default":"suit par dessus pas égal à"}},"category":"Sm"},{"category":"Sm","key":"2AB7","mappings":{"default":{"default":"précède par dessus presque égal à"}}},{"category":"Sm","key":"2AB8","mappings":{"default":{"default":"suit par dessus presque égal à"}}},{"category":"Sm","key":"2AB9","mappings":{"default":{"default":"précède par dessus non presque égal à"}}},{"category":"Sm","key":"2ABA","mappings":{"default":{"default":"suit par dessus non presque égal à"}}},{"key":"2ABB","mappings":{"default":{"default":"double précède"}},"category":"Sm"},{"key":"2ABC","mappings":{"default":{"default":"double suit"}},"category":"Sm"},{"key":"2ABD","mappings":{"default":{"default":"sous ensemble pointé"}},"category":"Sm"},{"key":"2ABE","mappings":{"default":{"default":"sur ensemble pointé"}},"category":"Sm"},{"key":"2ABF","mappings":{"default":{"default":"sous ensemble plus souscrit"}},"category":"Sm"},{"key":"2AC0","mappings":{"default":{"default":"sur ensemble plus souscrit"}},"category":"Sm"},{"key":"2AC1","mappings":{"default":{"default":"sous ensemble à signe de multiplication souscrit"}},"category":"Sm"},{"key":"2AC2","mappings":{"default":{"default":"sur ensemble à signe de multiplication souscrit"}},"category":"Sm"},{"key":"2AC3","mappings":{"default":{"default":"sous ensemble de ou égal à point en chef"}},"category":"Sm"},{"key":"2AC4","mappings":{"default":{"default":"sur ensemble de ou égal à point en chef"}},"category":"Sm"},{"category":"Sm","key":"2AC5","mappings":{"default":{"default":"sous ensemble de par dessus signe égal"}}},{"category":"Sm","key":"2AC6","mappings":{"default":{"default":"sur ensemble de par dessus signe égal"}}},{"key":"2AC7","mappings":{"default":{"default":"sous ensemble de par dessus opérateur tilde"}},"category":"Sm"},{"key":"2AC8","mappings":{"default":{"default":"sur ensemble de par dessus opérateur tilde"}},"category":"Sm"},{"category":"Sm","key":"2AC9","mappings":{"default":{"default":"sous ensemble de par dessus presque égal à"}}},{"category":"Sm","key":"2ACA","mappings":{"default":{"default":"sur ensemble de par dessus presque égal à"}}},{"category":"Sm","key":"2ACB","mappings":{"default":{"default":"sous ensemble de par dessus pas égal à"}}},{"category":"Sm","key":"2ACC","mappings":{"default":{"default":"sur ensemble de par dessus pas égal à"}}},{"category":"Sm","key":"2ACD","mappings":{"default":{"default":"opérateur boîte carrée ouverte gauche"}}},{"category":"Sm","key":"2ACE","mappings":{"default":{"default":"opérateur boîte carrée ouverte droite"}}},{"key":"2ACF","mappings":{"default":{"default":"sous ensemble clos"}},"category":"Sm"},{"key":"2AD0","mappings":{"default":{"default":"sur ensemble clos"}},"category":"Sm"},{"key":"2AD1","mappings":{"default":{"default":"sous ensemble clos ou égal à"}},"category":"Sm"},{"key":"2AD2","mappings":{"default":{"default":"sur ensemble clos ou égal à"}},"category":"Sm"},{"key":"2AD3","mappings":{"default":{"default":"sous ensemble par dessus sur ensemble"}},"category":"Sm"},{"key":"2AD4","mappings":{"default":{"default":"sur ensemble par dessus sous ensemble"}},"category":"Sm"},{"key":"2AD5","mappings":{"default":{"default":"sous ensemble par dessus sous ensemble"}},"category":"Sm"},{"key":"2AD6","mappings":{"default":{"default":"sur ensemble par dessus sur ensemble"}},"category":"Sm"},{"key":"2AD7","mappings":{"default":{"default":"sur ensemble à côté de sous ensemble"}},"category":"Sm"},{"key":"2AD8","mappings":{"default":{"default":"sur ensemble chaîné à sous ensemble"}},"category":"Sm"},{"key":"2AD9","mappings":{"default":{"default":"appartient à ouvert vers le bas"}},"category":"Sm"},{"key":"2ADA","mappings":{"default":{"default":"fourche surmontée d'un t"}},"category":"Sm"},{"key":"2ADB","mappings":{"default":{"default":"intersection transversale"}},"category":"Sm"},{"category":"Sm","key":"2ADC","mappings":{"default":{"default":"bifurcation (non indépendant)"}}},{"category":"Sm","key":"2ADD","mappings":{"default":{"default":"non bifurcation (indépendant)"}}},{"category":"Sm","key":"2ADE","mappings":{"default":{"default":"taquet gauche court"}}},{"category":"Sm","key":"2ADF","mappings":{"default":{"default":"taquet court vers le bas"}}},{"category":"Sm","key":"2AE0","mappings":{"default":{"default":"taquet court vers le haut"}}},{"category":"Sm","key":"2AE1","mappings":{"default":{"default":"perpendiculaire à s"}}},{"category":"Sm","key":"2AE2","mappings":{"default":{"default":"triple tourniquet droit à barre verticale"}}},{"category":"Sm","key":"2AE3","mappings":{"default":{"default":"tourniquet gauche à double barre verticale"}}},{"key":"2AE4","mappings":{"default":{"default":"double tourniquet gauche à barre verticale"}},"category":"Sm"},{"category":"Sm","key":"2AE5","mappings":{"default":{"default":"double tourniquet gauche à double barre verticale"}}},{"key":"2AE6","mappings":{"default":{"default":"double barre verticale gauche à traverse"}},"category":"Sm"},{"key":"2AE7","mappings":{"default":{"default":"taquet court vers le bas avec barre en chef"}},"category":"Sm"},{"key":"2AE8","mappings":{"default":{"default":"taquet court vers le haut avec barre souscrite"}},"category":"Sm"},{"key":"2AE9","mappings":{"default":{"default":"taquet court vers le haut par dessus taquet court vers le bas"}},"category":"Sm"},{"category":"Sm","key":"2AEA","mappings":{"default":{"default":"double taquet vers le bas"}}},{"key":"2AEB","mappings":{"default":{"default":"double taquet vers le haut"}},"category":"Sm"},{"key":"2AEC","mappings":{"default":{"default":"négation à deux traits"}},"category":"Sm"},{"key":"2AED","mappings":{"default":{"default":"négation à deux traits réfléchi"}},"category":"Sm"},{"key":"2AEE","mappings":{"default":{"default":"n'est pas un diviseur de à barre de négation réfléchie"}},"category":"Sm"},{"key":"2AEF","mappings":{"default":{"default":"ligne verticale cercle en chef"}},"category":"Sm"},{"key":"2AF0","mappings":{"default":{"default":"ligne verticale cercle souscrit"}},"category":"Sm"},{"key":"2AF1","mappings":{"default":{"default":"taquet vers le bas surmontant un cercle"}},"category":"Sm"},{"key":"2AF2","mappings":{"default":{"default":"parallèlle à vertical à une traverse"}},"category":"Sm"},{"key":"2AF3","mappings":{"default":{"default":"parallèle à avec opérateur tilde"}},"category":"Sm"},{"category":"Sm","key":"2AF4","mappings":{"default":{"default":"relation binaire triple barre verticale"}}},{"category":"Sm","key":"2AF5","mappings":{"default":{"default":"triple barre verticale à une traverse"}}},{"category":"Sm","key":"2AF6","mappings":{"default":{"default":"opérateur trois points"}}},{"category":"Sm","key":"2AF7","mappings":{"default":{"default":"trois inférieur à emboîtés"}}},{"category":"Sm","key":"2AF8","mappings":{"default":{"default":"trois supérieur à emboîtés"}}},{"category":"Sm","key":"2AF9","mappings":{"default":{"default":"inférieur à ou égal à et deux lignes inclinées"}}},{"category":"Sm","key":"2AFA","mappings":{"default":{"default":"supérieur à ou égal à et deux lignes inclinées"}}},{"category":"Sm","key":"2AFB","mappings":{"default":{"default":"relation binaire triple oblique"}}},{"category":"Sm","key":"2AFC","mappings":{"default":{"default":"grand opérateur à trois barres verticales"}}},{"category":"Sm","key":"2AFD","mappings":{"default":{"default":"opérateur double oblique"}}},{"category":"Sm","key":"2AFE","mappings":{"default":{"default":"barre verticale blanche"}}},{"category":"Sm","key":"2AFF","mappings":{"default":{"default":"barre verticale blanche n aire"}}},{"category":"Pd","key":"301C","mappings":{"default":{"default":"trait d'union en esse"}}},{"category":"Po","key":"FE10","mappings":{"default":{"default":"forme de présentation de virgule verticale"}}},{"category":"Po","key":"FE13","mappings":{"default":{"default":"forme de présentation de deux points vertical"}}},{"category":"Po","key":"FE14","mappings":{"default":{"default":"forme de présentation de point virgule vertical"}}},{"category":"Po","key":"FE15","mappings":{"default":{"default":"forme de présentation de point d'exclamation vertical"}}},{"category":"Po","key":"FE16","mappings":{"default":{"default":"forme de présentation de point d'interrogation vertical"}}},{"category":"Po","key":"FE19","mappings":{"default":{"default":"forme de présentation de points de suspension verticaux"}}},{"category":"Po","key":"FE30","mappings":{"default":{"default":"forme de présentation de point de conduite double vertical"}}},{"category":"Pd","key":"FE31","mappings":{"default":{"default":"forme de présentation de tiret cadratin vertical"}}},{"category":"Pd","key":"FE32","mappings":{"default":{"default":"forme de présentation de tiret demi cadratin vertical"}}},{"category":"Pc","key":"FE33","mappings":{"default":{"default":"forme de présentation de tiret bas vertical"}}},{"category":"Pc","key":"FE34","mappings":{"default":{"default":"forme de présentation de tiret bas ondulé vertical"}}},{"category":"Po","key":"FE45","mappings":{"default":{"default":"point sésame"}}},{"category":"Po","key":"FE46","mappings":{"default":{"default":"point sésame ajouré"}}},{"category":"Po","key":"FE49","mappings":{"default":{"default":"tiret haut en pointillés"}}},{"category":"Po","key":"FE4A","mappings":{"default":{"default":"tiret haut à point central"}}},{"category":"Po","key":"FE4B","mappings":{"default":{"default":"tiret haut ondulé"}}},{"category":"Po","key":"FE4C","mappings":{"default":{"default":"tiret haut double ondulé"}}},{"category":"Pc","key":"FE4D","mappings":{"default":{"default":"tiret bas avec pointillés"}}},{"category":"Pc","key":"FE4E","mappings":{"default":{"default":"tiret bas à point central"}}},{"category":"Pc","key":"FE4F","mappings":{"default":{"default":"tiret bas ondulé"}}},{"category":"Po","key":"FE50","mappings":{"default":{"default":"virgule minuscule"}}},{"category":"Po","key":"FE52","mappings":{"default":{"default":"point minuscule"}}},{"category":"Po","key":"FE54","mappings":{"default":{"default":"point virgule minuscule"}}},{"category":"Po","key":"FE55","mappings":{"default":{"default":"deux points minuscule"}}},{"category":"Po","key":"FE56","mappings":{"default":{"default":"point d'interrogation minuscule"}}},{"category":"Po","key":"FE57","mappings":{"default":{"default":"point d'exclamation minuscule"}}},{"category":"Pd","key":"FE58","mappings":{"default":{"default":"trait d'union cadratin minuscule"}}},{"category":"Po","key":"FE5F","mappings":{"default":{"default":"croisillon minuscule"}}},{"category":"Po","key":"FE60","mappings":{"default":{"default":"perluète minuscule"}}},{"category":"Po","key":"FE61","mappings":{"default":{"default":"astérisque minuscule"}}},{"category":"Sm","key":"FE62","mappings":{"default":{"default":"plus minuscule"}}},{"category":"Pd","key":"FE63","mappings":{"default":{"default":"tiret minuscule"}}},{"category":"Sm","key":"FE64","mappings":{"default":{"default":"inférieur à minuscule"}}},{"category":"Sm","key":"FE65","mappings":{"default":{"default":"supérieur à minuscule"}}},{"category":"Sm","key":"FE66","mappings":{"default":{"default":"égal à minuscule"}}},{"key":"FE68","mappings":{"default":{"default":"integer divide"}},"category":"Po"},{"category":"Sc","key":"FE69","mappings":{"default":{"default":"symbole dollar minuscule"}}},{"category":"Po","key":"FE6A","mappings":{"default":{"default":"symbole pour cent minuscule"}}},{"category":"Po","key":"FE6B","mappings":{"default":{"default":"arrobe minuscule"}}},{"category":"Po","key":"FF01","mappings":{"default":{"default":"point d'exclamation"}}},{"category":"Po","key":"FF02","mappings":{"default":{"default":"guillemet"}}},{"category":"Po","key":"FF03","mappings":{"default":{"default":"croisillon"}}},{"category":"Sc","key":"FF04","mappings":{"default":{"default":"symbole dollar"}}},{"category":"Po","key":"FF05","mappings":{"default":{"default":"symbole pour cent"}}},{"category":"Po","key":"FF06","mappings":{"default":{"default":"perluète"}}},{"category":"Po","key":"FF07","mappings":{"default":{"default":"apostrophe"}}},{"category":"Po","key":"FF0A","mappings":{"default":{"default":"astérisque"}}},{"category":"Sm","key":"FF0B","mappings":{"default":{"default":"plus"}}},{"category":"Po","key":"FF0C","mappings":{"default":{"default":"virgule"}}},{"category":"Pd","key":"FF0D","mappings":{"default":{"default":"tiret"}}},{"category":"Po","key":"FF0E","mappings":{"default":{"default":"point"}}},{"category":"Po","key":"FF0F","mappings":{"default":{"default":"barre oblique"}}},{"category":"Po","key":"FF1A","mappings":{"default":{"default":"deux points colon"}}},{"category":"Po","key":"FF1B","mappings":{"default":{"default":"point virgule"}}},{"category":"Sm","key":"FF1C","mappings":{"default":{"default":"inférieur à"}}},{"category":"Sm","key":"FF1D","mappings":{"default":{"default":"égal à"}}},{"category":"Sm","key":"FF1E","mappings":{"default":{"default":"supérieur à"}}},{"category":"Po","key":"FF1F","mappings":{"default":{"default":"point d'interrogation"}}},{"category":"Po","key":"FF20","mappings":{"default":{"default":"arrobe"}}},{"category":"Po","key":"FF3C","mappings":{"default":{"default":"barre oblique inversée"}}},{"category":"Sk","key":"FF3E","mappings":{"default":{"default":"accent circonflexe"}}},{"category":"Pc","key":"FF3F","mappings":{"default":{"default":"tiret bas"}}},{"category":"Sk","key":"FF40","mappings":{"default":{"default":"accent grave"}}},{"category":"Sm","key":"FF5C","mappings":{"default":{"default":"barre verticale"}}},{"category":"Sm","key":"FF5E","mappings":{"default":{"default":"tilde"}}},{"category":"Sc","key":"FFE0","mappings":{"default":{"default":"symbole centime"}}},{"category":"Sc","key":"FFE1","mappings":{"default":{"default":"symbole livre"}}},{"category":"Sm","key":"FFE2","mappings":{"default":{"default":"négation"}}},{"category":"Sk","key":"FFE3","mappings":{"default":{"default":"macron *"}}},{"category":"So","key":"FFE4","mappings":{"default":{"default":"ligne brisée"}}},{"category":"Sc","key":"FFE5","mappings":{"default":{"default":"symbole yen"}}},{"category":"Sc","key":"FFE6","mappings":{"default":{"default":"symbole won"}}},{"category":"So","key":"FFE8","mappings":{"default":{"default":"ligne verticale mince"}}},{"category":"So","key":"FFED","mappings":{"default":{"default":"carré noir"}}},{"category":"So","key":"FFEE","mappings":{"default":{"default":"cercle blanc"}}}]
,
"fr/symbols/math_whitespace.js": 
[{"locale":"fr"},{"category":"Zs","key":"0020","mappings":{"default":{"default":"espace"}}},{"key":"00A0","mappings":{"default":{"default":" "}},"category":"Zs"},{"key":"00AD","mappings":{"default":{"default":"trait d'union conditionnel"}},"category":"Cf"},{"category":"Zs","key":"2000","mappings":{"default":{"default":"demi cadratin"}}},{"category":"Zs","key":"2001","mappings":{"default":{"default":"cadratin"}}},{"key":"2002","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2003","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2004","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2005","mappings":{"default":{"default":""}},"category":"Zs"},{"category":"Zs","key":"2006","mappings":{"default":{"default":"sixième de cadratin"}}},{"key":"2007","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2008","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"2009","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"200A","mappings":{"default":{"default":""}},"category":"Zs"},{"key":"200B","mappings":{"default":{"default":""}},"category":"Cf"},{"key":"200C","mappings":{"default":{"default":"antiliant sans chasse"}},"category":"Cf"},{"key":"200D","mappings":{"default":{"default":"liant sans chasse"}},"category":"Cf"},{"key":"200E","mappings":{"default":{"default":"marque gauche à droite"}},"category":"Cf"},{"key":"200F","mappings":{"default":{"default":"marque droite à gauche"}},"category":"Cf"},{"category":"Zl","key":"2028","mappings":{"default":{"default":"séparateur de lignes"}}},{"category":"Zp","key":"2029","mappings":{"default":{"default":"séparateur de paragraphes"}}},{"category":"Cf","key":"202A","mappings":{"default":{"default":"enchâssement gauche à droite"}}},{"category":"Cf","key":"202B","mappings":{"default":{"default":"enchâssement droite à gauche"}}},{"category":"Cf","key":"202C","mappings":{"default":{"default":"dépilement de formatage directionnel"}}},{"category":"Cf","key":"202D","mappings":{"default":{"default":"forçage gauche à droite"}}},{"category":"Cf","key":"202E","mappings":{"default":{"default":"forçage droite à gauche"}}},{"category":"Zs","key":"202F","mappings":{"default":{"default":"espace insécable étroite"}}},{"key":"205F","mappings":{"default":{"default":"espace moyenne mathématique"}},"category":"Zs"},{"key":"2060","mappings":{"default":{"default":""}},"category":"Cf"},{"key":"2061","mappings":{"default":{"default":"de"}},"category":"Cf"},{"key":"2062","mappings":{"default":{"default":" "}},"category":"Cf"},{"key":"2063","mappings":{"default":{"default":""}},"category":"Cf"},{"category":"Cf","key":"2064","mappings":{"default":{"default":"plus invisible"}}},{"category":"Cf","key":"206A","mappings":{"default":{"default":"inhibiteur d'échange symétrique"}}},{"category":"Cf","key":"206B","mappings":{"default":{"default":"activateur d'échange symétrique"}}},{"category":"Cf","key":"206E","mappings":{"default":{"default":"sélecteur de formes numérales nationales"}}},{"category":"Cf","key":"206F","mappings":{"default":{"default":"sélecteur de formes numérales de référence"}}},{"key":"FEFF","mappings":{"default":{"default":"espace ultrafine"}},"category":"Cf"},{"category":"Cf","key":"FFF9","mappings":{"default":{"default":"ancre d'annotation interlinéaire"}}},{"category":"Cf","key":"FFFA","mappings":{"default":{"default":"séparateur d'annotation interlinéaire"}}},{"category":"Cf","key":"FFFB","mappings":{"default":{"default":"terminateur d'annotation interlinéaire"}}}]
,
"fr/symbols/other_stars.js": 
[{"locale":"fr"},{"category":"So","key":"23E8","mappings":{"default":{"default":"symbole exposant décimal"}}},{"key":"2605","mappings":{"default":{"default":"étoile noire"}},"category":"So"},{"key":"2606","mappings":{"default":{"default":"étoile blanche"}},"category":"So"},{"category":"So","key":"26AA","mappings":{"default":{"default":"cercle moyen blanc"}}},{"category":"So","key":"26AB","mappings":{"default":{"default":"cercle moyen noir"}}},{"category":"So","key":"2705","mappings":{"default":{"default":"signe de vérification blanc gras"}}},{"key":"2713","mappings":{"default":{"default":"signe de vérification"}},"category":"So"},{"category":"So","key":"2714","mappings":{"default":{"default":"gros signe de vérification"}}},{"category":"So","key":"2715","mappings":{"default":{"default":"x de multiplication"}}},{"category":"So","key":"2716","mappings":{"default":{"default":"gros x de multiplication"}}},{"key":"2717","mappings":{"default":{"default":"x de bulletin de vote"}},"category":"So"},{"category":"So","key":"2718","mappings":{"default":{"default":"gros x de bulletin de vote"}}},{"category":"So","key":"271B","mappings":{"default":{"default":"croix percée d'un carré"}}},{"category":"So","key":"271C","mappings":{"default":{"default":"grosse croix percée d'un carré"}}},{"key":"2720","mappings":{"default":{"default":"croix de malte"}},"category":"So"},{"category":"So","key":"2721","mappings":{"default":{"default":"Étoile de david"}}},{"category":"So","key":"2722","mappings":{"default":{"default":"croix larmée"}}},{"category":"So","key":"2723","mappings":{"default":{"default":"croix pommetée"}}},{"category":"So","key":"2724","mappings":{"default":{"default":"grosse croix pommetée"}}},{"category":"So","key":"2725","mappings":{"default":{"default":"croix tréflée"}}},{"category":"So","key":"2726","mappings":{"default":{"default":"Étoile noire à quatre branches"}}},{"category":"So","key":"2727","mappings":{"default":{"default":"Étoile blanche à quatre branches"}}},{"category":"So","key":"2728","mappings":{"default":{"default":"scintillements"}}},{"category":"So","key":"2729","mappings":{"default":{"default":"Étoile blanche à contour accentué"}}},{"category":"So","key":"272A","mappings":{"default":{"default":"Étoile blanche cerclée"}}},{"category":"So","key":"272B","mappings":{"default":{"default":"molette noire"}}},{"category":"So","key":"272C","mappings":{"default":{"default":"molette blanche"}}},{"category":"So","key":"272D","mappings":{"default":{"default":"Étoile noire avec contour"}}},{"category":"So","key":"272E","mappings":{"default":{"default":"Étoile noire avec gros contour"}}},{"category":"So","key":"272F","mappings":{"default":{"default":"Étoile rayonnante"}}},{"category":"So","key":"2730","mappings":{"default":{"default":"Étoile blanche ombrée"}}},{"category":"So","key":"2731","mappings":{"default":{"default":"gros astérisque"}}},{"category":"So","key":"2732","mappings":{"default":{"default":"astérisque percé"}}},{"category":"So","key":"2733","mappings":{"default":{"default":"astérisque à huit branches"}}},{"category":"So","key":"2734","mappings":{"default":{"default":"Étoile noire à huit branches"}}},{"category":"So","key":"2735","mappings":{"default":{"default":"Étoile rayonnante à huit branches"}}},{"key":"2736","mappings":{"default":{"default":"étoile noire à six branches"}},"category":"So"},{"category":"So","key":"2739","mappings":{"default":{"default":"Étoile noire à douze branches"}}},{"category":"So","key":"273A","mappings":{"default":{"default":"astérisque à seize branches"}}},{"category":"So","key":"273B","mappings":{"default":{"default":"astérisque larmé"}}},{"category":"So","key":"273C","mappings":{"default":{"default":"astérisque larmé percé"}}},{"key":"273D","mappings":{"default":{"default":"gros astérisque larmé"}},"category":"So"},{"category":"So","key":"273E","mappings":{"default":{"default":"sixtefeuille blanche et noire"}}},{"category":"So","key":"273F","mappings":{"default":{"default":"quintefeuille noire"}}},{"category":"So","key":"2740","mappings":{"default":{"default":"quintefeuille blanche"}}},{"category":"So","key":"2741","mappings":{"default":{"default":"double quartefeuille noire avec contour"}}},{"category":"So","key":"2742","mappings":{"default":{"default":"Étoile cerclée percée à huit branches"}}},{"category":"So","key":"2743","mappings":{"default":{"default":"gros astérisque rayonnant larmé"}}},{"category":"So","key":"2744","mappings":{"default":{"default":"flocon de neige"}}},{"category":"So","key":"2745","mappings":{"default":{"default":"flocon de neige à trois folioles transpercé"}}},{"category":"So","key":"2746","mappings":{"default":{"default":"gros flocon de neige à chevrons"}}},{"category":"So","key":"2747","mappings":{"default":{"default":"Étincellement"}}},{"category":"So","key":"2748","mappings":{"default":{"default":"gros étincellement"}}},{"category":"So","key":"2749","mappings":{"default":{"default":"astérisque pommeté"}}},{"category":"So","key":"274A","mappings":{"default":{"default":"astérisque hélice à huit branches larmées"}}},{"category":"So","key":"274B","mappings":{"default":{"default":"gros astérisque hélice à huit branches larmées"}}},{"category":"So","key":"274C","mappings":{"default":{"default":"croix grasse"}}},{"category":"So","key":"274D","mappings":{"default":{"default":"cercle blanc ombré"}}}]
,
"fr/units/energy.js": 
[{"locale":"fr"},{"key":"W","mappings":{"default":{"default":"watts","singular":"watt","dual":""}},"category":"energy","names":["W","w"]},{"key":"J","mappings":{"default":{"default":"joules","singular":"joule","dual":""}},"category":"energy","names":["J"]},{"key":"N","mappings":{"default":{"default":"newtons","singular":"newton","dual":""}},"category":"energy","names":["N"]},{"key":"A","mappings":{"default":{"default":"ampères","singular":"ampère","dual":""}},"category":"energy","names":["A"]},{"key":"V","mappings":{"default":{"default":"volts","singular":"volt","dual":""}},"category":"energy","names":["V"]},{"key":"Ω","mappings":{"default":{"default":"ohms","singular":"ohm","dual":""}},"category":"energy","names":["Ω","Ohm"]}]
,
"fr/units/length.js": 
[{"locale":"fr"},{"key":"m","mappings":{"default":{"default":"mètres","singular":"mètre","dual":""}},"category":"Length","names":["m"]},{"key":"ft","mappings":{"default":{"default":"pieds","singular":"pied","dual":""}},"category":"Length","names":["ft","ft."]},{"key":"in","mappings":{"default":{"default":"pouces","singular":"pouce","dual":""}},"category":"Length","names":["in","in."]},{"key":"mi","mappings":{"default":{"default":"miles","singular":"mile","dual":""}},"category":"Length","names":["mi","mi."]},{"key":"yd","mappings":{"default":{"default":"yards","singular":"yard","dual":""}},"category":"Length","names":["yd","yd."]}]
,
"fr/units/memory.js": 
[{"locale":"fr"}]
,
"fr/units/other.js": 
[{"locale":"fr"}]
,
"fr/units/speed.js": 
[{"locale":"fr"},{"key":"mph","mappings":{"default":{"default":"miles par heure","singular":"mile par heure","dual":""}},"names":["mph"]}]
,
"fr/units/temperature.js": 
[{"locale":"fr"},{"key":"F","mappings":{"default":{"default":"farads","singular":"farad","dual":""}},"names":["F","F.","°F"]},{"key":"C","mappings":{"default":{"default":"coulombs","singular":"coulomb","dual":""}},"names":["C","°C"]},{"key":"K","mappings":{"default":{"default":"kelvins","singular":"kelvin","dual":""}},"names":["K","°K"]}]
,
"fr/units/time.js": 
[{"locale":"fr"},{"key":"s","mappings":{"default":{"default":"secondes","singular":"seconde","dual":""}},"category":"time","names":["s"]}]
,
"fr/units/volume.js": 
[{"locale":"fr"},{"key":"bbl","mappings":{"default":{"default":"barils","singular":"baril","dual":""}},"category":"volume","names":["bbl.","bbl"]},{"key":"gal","mappings":{"default":{"default":"gallons","singular":"gallon","dual":""}},"category":"volume","names":["gal","gal."]},{"key":"pt","mappings":{"default":{"default":"pintes","singular":"pinte","dual":""}},"category":"volume","names":["pt","pt."]},{"key":"qt","mappings":{"default":{"default":"quarts","singular":"quart","dual":""}},"category":"volume","names":["qt","qt."]},{"key":"tbsp","mappings":{"default":{"default":"cuillères de table","singular":"cuillèe de table","dual":""}},"category":"volume","names":["tbsp","tbsp."]},{"key":"tsp","mappings":{"default":{"default":"cuillèes à thé","singular":"cuillère à thé","dual":""}},"category":"volume","names":["tsp","tsp."]},{"key":"l","mappings":{"default":{"default":"litres","singular":"litre","dual":""}},"category":"volume","names":["l"]}]
,
"fr/units/weight.js": 
[{"locale":"fr"},{"key":"lb","mappings":{"default":{"default":"livres","singular":"livre","dual":""}},"names":["lb","lb."]},{"key":"oz","mappings":{"default":{"default":"onces","singular":"oce","dual":""}},"names":["oz","oz."]},{"key":"gr","mappings":{"default":{"default":"grains","singular":"grain","dual":""}},"names":["g","gr"]},{"key":"t","mappings":{"default":{"default":"tonnes","singular":"tonne","dual":""}},"names":["t","T"]}]
}

